--[[
******************************************************************************************
QuestLevelDisplay 5.4.0
Description: Adds levels to quests where they are displayed.

Author: Sindragosa
******************************************************************************************
]]--

local _G = _G
local GetNumQuestLogEntries = GetNumQuestLogEntries
local GetQuestLogTitle = GetQuestLogTitle
local GetQuestLink = GetQuestLink
local GetNumActiveQuests = GetNumActiveQuests
local GetNumAvailableQuests = GetNumAvailableQuests
local GetActiveLevel = GetActiveLevel
local GetAvailableLevel = GetAvailableLevel
local GetTitleText = GetTitleText
local GetGossipActiveQuests = GetGossipActiveQuests
local GetGossipAvailableQuests = GetGossipAvailableQuests
local GetNumQuestWatches = GetNumQuestWatches
local GetQuestIndexForWatch = GetQuestIndexForWatch
local GetQuestLogSpecialItemInfo = GetQuestLogSpecialItemInfo
local GetQuestLogSelection = GetQuestLogSelection
local QuestMapUpdateAllQuests = QuestMapUpdateAllQuests
local QuestPOIGetQuestIDByVisibleIndex = QuestPOIGetQuestIDByVisibleIndex
local select = select
local strmatch = strmatch
local NORMAL_FONT_COLOR = NORMAL_FONT_COLOR
local InCombatLockdown = InCombatLockdown

local settings = {
	--hideNoLevelQuests = true,
	--showNoLevelAsterisk = true,
	--showMarkerDaily = true,
	--showMarkerRepeatable = true,
	clearOldMarkers = true,
	showReputations = true,
};

local QuestLevelData

local function GetQuestLevel(index, isLink)
	if settings.hideNoLevelQuests then
		return strmatch(isLink and index or GetQuestLink(index) or "", "quest:%d+:(%d+)")
	else
		return strmatch(isLink and index or GetQuestLink(index) or "", "quest:%d+:(-?%d+)")
	end
end

--[[ Quest Log ]]--
local tagFormat = "  [%d%s] %s"
local tags = {Elite = "+", Group = "g", Dungeon = "d", Raid = "r", PvP = "p", Heroic = "h", ["Raid (10)"] = "r", ["Raid (25)"] = "r", Daily = "\226\128\162", Repeatable = "\226\136\158"}

function QuestLevelDisplay_QuestLog_Update()
    local buttons = QuestLogScrollFrame.buttons
    local numButtons = #buttons
    local scrollOffset = HybridScrollFrame_GetOffset(QuestLogScrollFrame)
    local numEntries = GetNumQuestLogEntries()
    local questIndex, questLogTitle
    local titleText, level, tagName, groupSize, isHeader, _, isComplete, isDaily, questID
    for i=1, numButtons do
        questIndex = i + scrollOffset
        questLogTitle = buttons[i]
        if questIndex <= numEntries then
            titleText, level, tagName, groupSize, isHeader, _, isComplete, isDaily, questID = GetQuestLogTitle(questIndex)
            if (not isHeader) and titleText and GetQuestLevel(questIndex) then
				local suffix = ""
				if (tags[tagName]) then suffix = tags[tagName] end
				if (tagName == "Group" and groupSize > 0) then suffix = suffix .. groupSize end
				if (settings.showMarkerDaily and isDaily) then suffix = suffix .. "\226\128\162" end
				if (settings.showNoLevelAsterisk and GetQuestLevel(questIndex) == "-1") then
					questLogTitle:SetFormattedText("  [*%s] %s", suffix, titleText)
				else
					questLogTitle:SetFormattedText(tagFormat, level, suffix, titleText)
				end
				if (settings.clearOldMarkers and (tags[tagName] or settings.showMarkerDaily and isDaily)) and not isComplete then questLogTitle.tag:SetText("") end
                QuestLogTitleButton_Resize(questLogTitle)
            end
        end
    end
end

-- this handles initial display
hooksecurefunc("QuestLog_Update", QuestLevelDisplay_QuestLog_Update)
-- and this handles scrolling the quest list
hooksecurefunc(QuestLogScrollFrame, "update", QuestLevelDisplay_QuestLog_Update)


--[[ Quest Watch ]]--
local ITEM_WIDTH = WATCHFRAME_ITEM_WIDTH + WATCHFRAMELINES_FONTSPACING
WatchFrame_AddObjectiveHandler(function()
	local maxWidth = 0
	local i = 1

	for index = 1, GetNumQuestWatches() do
		local index = GetQuestIndexForWatch(index)
		local level = index and GetQuestLevel(index)

		if level then
			local title = GetQuestLogTitle(index) or ""
			local itemWidth = GetQuestLogSpecialItemInfo(index) and ITEM_WIDTH or 0

			while i <= #WATCHFRAME_QUESTLINES do
				local line = WATCHFRAME_QUESTLINES[i].text
				local text = line:GetText() or ""

				if strmatch(text, title) then
					line:SetFormattedText("[%d] %s", level, text)
					maxWidth = max(maxWidth, line:GetWidth() + itemWidth)
					break
				else
					i = i + 1
				end
			end
		end
	end

	return 0, maxWidth, 0, 0
end)

--[[local function QuestLevelDisplay_WatchFrame_SetWidth()
	WATCHFRAME_EXPANDEDWIDTH = WATCHFRAME_EXPANDEDWIDTH + 10
	WATCHFRAME_MAXLINEWIDTH = WATCHFRAME_MAXLINEWIDTH + 10

	if WatchFrame:IsShown() and not WatchFrame.collapsed then
		WatchFrame:SetWidth(WATCHFRAME_EXPANDEDWIDTH)
		WatchFrame_Update()
	end
end
hooksecurefunc("WatchFrame_SetWidth", QuestLevelDisplay_WatchFrame_SetWidth)]]--
WatchFrameHeader:HookScript("OnEnter", function(self)
	if not InCombatLockdown() then
		WatchFrame:SetFrameStrata("HIGH");
	end
end)
WatchFrameHeader:HookScript("OnLeave", function(self)
	if not InCombatLockdown() then
		WatchFrame:SetFrameStrata("LOW");
	end
end)

--[[ Gossip Window ]]--
--title1, level1, isLowLevel1, isDaily1, isRepeatable1[, title2, level2, isLowLevel2, isDaily2, isRepeatable2] = GetGossipAvailableQuests()
--title1, level1, isLowLevel1, isComplete1[, title2, level2, isLowLevel2, isComplete2] = GetGossipActiveQuests()
local function HookGossipLines(func, n)
	hooksecurefunc(func, function(...)
		local start = GossipFrame.buttonIndex - select("#", ...) / n - 1

		for i = start, GossipFrame.buttonIndex - 2 do
			local level = select((i - start) * n + 2, ...)

			if level > -1 then
				local line = _G["GossipTitleButton"..i]
				line:SetFormattedText("[%d] %s", level, line:GetText())
			end
		end
	end)
end

HookGossipLines("GossipFrameAvailableQuestsUpdate", 6)
HookGossipLines("GossipFrameActiveQuestsUpdate", 5)


--[[ Quest Greeting ]]--
local function QuestFrameGreetingPanel_OnShow()
	local numActiveQuests = GetNumActiveQuests()

	for i = 1, numActiveQuests + GetNumAvailableQuests() do
		local level = i > numActiveQuests and GetAvailableLevel(i - numActiveQuests) or GetActiveLevel(i)
		local line = _G["QuestTitleButton"..i]

		line:SetFormattedText("[%d] %s", level, line:GetText())
	end
end
QuestFrameGreetingPanel:HookScript("OnShow", QuestFrameGreetingPanel_OnShow)

local selectedQuestLevel
local function QuestLevelDisplay_SelectActiveQuest(index)
	selectedQuestLevel = GetActiveLevel(index)
end
local function QuestLevelDisplay_SelectAvailableQuest(index)
	selectedQuestLevel = GetAvailableLevel(index)
end
local function QuestLevelDisplay_SelectGossipActiveQuest(index)
	selectedQuestLevel = select((index - 1) * 5 + 2, GetGossipActiveQuests())
end
local function QuestLevelDisplay_SelectGossipAvailableQuest(index)
	selectedQuestLevel = select((index - 1) * 6 + 2, GetGossipAvailableQuests())
end
hooksecurefunc("SelectActiveQuest", QuestLevelDisplay_SelectActiveQuest)
hooksecurefunc("SelectAvailableQuest", QuestLevelDisplay_SelectAvailableQuest)
hooksecurefunc("SelectGossipActiveQuest", QuestLevelDisplay_SelectGossipActiveQuest)
hooksecurefunc("SelectGossipAvailableQuest", QuestLevelDisplay_SelectGossipAvailableQuest)

--[[ Quest Detail ]]--
local function QuestFrameDetailPanel_OnShow()
	local questTitleText = GetTitleText()
	local questLevel = selectedQuestLevel
	if not questLevel then
		questLevel = QuestLevelData[GetQuestID()]
	end

	if questTitleText and questLevel and questLevel > -1 then
		QuestInfoTitleHeader:SetFormattedText("[%d] %s", questLevel, questTitleText)
	end
	selectedQuestLevel = nil
end

--[[ Quest Progress ]]--
local function QuestFrameProgressPanel_OnShow()
	local questTitleText = GetTitleText()
	local questLevel = selectedQuestLevel
	if not questLevel then
		questLevel = QuestLevelData[GetQuestID()]
	end

	if questTitleText and questLevel and questLevel > -1 then
		QuestProgressTitleText:SetFormattedText("[%d] %s", questLevel, questTitleText)
	end
	selectedQuestLevel = nil
end

QuestFrameDetailPanel:HookScript("OnShow", QuestFrameDetailPanel_OnShow)
QuestFrameProgressPanel:HookScript("OnShow", QuestFrameProgressPanel_OnShow)
QuestFrameRewardPanel:HookScript("OnShow", QuestFrameDetailPanel_OnShow)


--[[ WorldMap Quest Detail ]]--
local function QuestLevelDisplay_WorldMapFrame_SelectQuestFrame(questFrame)
	--if WORLDMAP_SETTINGS.size ~= WORLDMAP_QUESTLIST_SIZE then return end
	local questTitleText = GetQuestLogTitle(questFrame.questLogIndex)
	local questLevel = questFrame.level

	if questTitleText and questLevel and questLevel > -1 then
		QuestInfoTitleHeader:SetFormattedText("[%d] %s", questLevel, questTitleText)
	end
end

--[[ WorldMap Quest Frame ]]--
local function QuestLevelDisplay_WorldMapFrame_UpdateQuests()
	if WORLDMAP_SETTINGS.size ~= WORLDMAP_QUESTLIST_SIZE then return end
	local questFrame
	local questCount = 0
	local title, level, tagName, groupSize, isHeader, _, isComplete, isDaily, questID
	local numEntries = QuestMapUpdateAllQuests()
	for i = 1, numEntries do
		local questId, questLogIndex = QuestPOIGetQuestIDByVisibleIndex(i)
		if (questLogIndex and questLogIndex > 0) then
			questCount = questCount + 1
			title, level, tagName, groupSize, isHeader, _, isComplete, isDaily, questID = GetQuestLogTitle(questLogIndex)
			questFrame = _G["WorldMapQuestFrame"..questCount]
			if (questFrame and level and level > 0) then
				local suffix = ""
				if (tags[tagName]) then suffix = tags[tagName] end
				if (tagName == "Group" and groupSize > 0) then suffix = suffix .. groupSize end
				questFrame.title:SetFormattedText(tagFormat, level, suffix, title)
			end
		end
	end
end
hooksecurefunc("WorldMapFrame_SelectQuestFrame", QuestLevelDisplay_WorldMapFrame_SelectQuestFrame)
hooksecurefunc("WorldMapFrame_UpdateQuests", QuestLevelDisplay_WorldMapFrame_UpdateQuests)

--[[ WorldMap Quest POI Tooltip ]]--
local function QuestLevelDisplay_WorldMapQuestPOI_SetTooltip(poiButton, questLogIndex, numObjectives)
	local title, level = GetQuestLogTitle(questLogIndex)

	if title and level and level > -1 then
		WorldMapTooltipTextLeft1:SetFormattedText("[%d] %s", level, title)
		if (MAP_QUEST_DIFFICULTY == "1") then
			local color = GetQuestDifficultyColor(level)
			WorldMapTooltipTextLeft1:SetTextColor(color.r, color.g, color.b)
		else
			WorldMapTooltipTextLeft1:SetTextColor(NORMAL_FONT_COLOR.r, NORMAL_FONT_COLOR.g, NORMAL_FONT_COLOR.b)
		end
		WorldMapTooltip:Show()
	end
end

hooksecurefunc("WorldMapQuestPOI_SetTooltip", QuestLevelDisplay_WorldMapQuestPOI_SetTooltip)

local function FixCompareTooltips(poiButton, questLogIndex, numObjectives)
	WorldMapCompareTooltip1:SetFrameLevel(WorldMapFrame:GetFrameLevel() + 5)
	WorldMapCompareTooltip2:SetFrameLevel(WorldMapFrame:GetFrameLevel() + 5)
	WorldMapCompareTooltip3:SetFrameLevel(WorldMapFrame:GetFrameLevel() + 5)
end
WorldMapFrame:HookScript("OnShow", FixCompareTooltips)


if (settings.showReputations) then
	local QuestFrame_GetMaterial = QuestFrame_GetMaterial
	local QuestInfo_DoReputations = QuestInfo_DoReputations
	local GetMaterialTextColors = GetMaterialTextColors
	local GetNumQuestLogRewards = GetNumQuestLogRewards
	local GetNumQuestLogChoices = GetNumQuestLogChoices
	local GetNumQuestLogRewardCurrencies = GetNumQuestLogRewardCurrencies
	local GetQuestLogRewardXP = GetQuestLogRewardXP
	local GetNumQuestRewards = GetNumQuestRewards
	local GetNumQuestChoices = GetNumQuestChoices
	local GetNumRewardCurrencies = GetNumRewardCurrencies
	local GetRewardXP = GetRewardXP

	--[[ ShowRewards ]]--
	local function QuestLevelDisplay_ShowRewards()
		if not settings.showReputations then return end
		local textColor = GetMaterialTextColors(QuestFrame_GetMaterial())
		QuestInfoReputationText:SetTextColor(textColor[1], textColor[2], textColor[3])
		for i = 1, MAX_REPUTATIONS do
			_G["QuestInfoReputation"..i.."Faction"]:SetTextColor(textColor[1], textColor[2], textColor[3])
		end

		local numQuestRewards, numQuestChoices, numQuestCurrencies, xp, skillName, skillIcon, skillPoints
		if (QuestInfoFrame.questLog) then
			numQuestRewards = GetNumQuestLogRewards()
			numQuestChoices = GetNumQuestLogChoices()
			numQuestCurrencies = GetNumQuestLogRewardCurrencies()
			skillName, skillIcon, skillPoints = GetQuestLogRewardSkillPoints()
			xp = GetQuestLogRewardXP()
		else
			numQuestRewards = GetNumQuestRewards()
			numQuestChoices = GetNumQuestChoices()
			numQuestCurrencies = GetNumRewardCurrencies()
			skillName, skillIcon, skillPoints = GetRewardSkillPoints()
			xp = GetRewardXP()
		end

		if numQuestRewards > 0 or numQuestCurrencies > 0 or (skillPoints and skillPoints > 0) then
			local numQuestItem = (numQuestRewards + (numQuestRewards % 2) - 1)
			if numQuestCurrencies > 0 then
				numQuestItem = numQuestRewards + numQuestChoices + (numQuestCurrencies + (numQuestCurrencies % 2) - 1)
			end
			if numQuestRewards == 0 and numQuestItem < 0 and xp > 0 then
				QuestInfo_DoReputations(QuestInfoXPFrame)
			else
				QuestInfo_DoReputations(_G["QuestInfoItem"..numQuestItem])
			end
		elseif xp > 0 then
			QuestInfo_DoReputations(QuestInfoXPFrame)
		else
			QuestInfo_DoReputations(QuestInfoItemReceiveText)
		end
	end
	hooksecurefunc("QuestInfo_Display", QuestLevelDisplay_ShowRewards)
end


--[[ Tooltip Links ]]--
hooksecurefunc("ChatFrame_OnHyperlinkShow", function(self, link, text, button)
	if (link and link:find("quest:") and ItemRefTooltip:IsShown()) then
		local level = strmatch(link, "quest:%d+:(%d+)")
		if level then
			local line = _G["ItemRefTooltipTextLeft1"]
			line:SetFormattedText("[%d] %s", level, line:GetText() or "")
			ItemRefTooltip:Show()
		end
	end
end)

QuestLevelData = {
	[2] = 23,
	[11] = 10,
	[16] = 1,
	[23] = 24,
	[24] = 24,
	[25] = 25,
	[35] = 10,
	[37] = 10,
	[40] = 10,
	[45] = 10,
	[46] = 10,
	[47] = 7,
	[52] = 10,
	[54] = 5,
	[59] = 10,
	[60] = 7,
	[62] = 7,
	[71] = 10,
	[76] = 10,
	[83] = 10,
	[84] = 6,
	[85] = 6,
	[86] = 6,
	[87] = 8,
	[88] = 9,
	[106] = 6,
	[107] = 6,
	[111] = 6,
	[112] = 7,
	[114] = 7,
	[123] = 10,
	[147] = 10,
	[176] = 11,
	[182] = 4,
	[184] = 10,
	[185] = 25,
	[186] = 26,
	[187] = 27,
	[188] = 28,
	[190] = 25,
	[191] = 26,
	[192] = 27,
	[193] = 28,
	[194] = 25,
	[195] = 26,
	[196] = 27,
	[197] = 28,
	[208] = 29,
	[216] = 23,
	[218] = 5,
	[239] = 10,
	[264] = 15,
	[270] = 29,
	[273] = 15,
	[291] = 10,
	[301] = 15,
	[302] = 15,
	[308] = 7,
	[309] = 15,
	[311] = 7,
	[313] = 7,
	[314] = 8,
	[315] = 6,
	[317] = 6,
	[318] = 7,
	[319] = 8,
	[320] = 8,
	[325] = 29,
	[332] = 2,
	[333] = 2,
	[334] = 2,
	[335] = 30,
	[336] = 30,
	[351] = 48,
	[353] = 15,
	[384] = 6,
	[397] = 30,
	[400] = 5,
	[403] = 1,
	[412] = 6,
	[432] = 9,
	[433] = 10,
	[454] = 15,
	[475] = 6,
	[476] = 6,
	[483] = 8,
	[485] = 35,
	[486] = 9,
	[487] = 9,
	[488] = 5,
	[489] = 6,
	[543] = 40,
	[579] = 1,
	[583] = 25,
	[647] = 30,
	[648] = 48,
	[743] = 8,
	[744] = 10,
	[749] = 8,
	[751] = 8,
	[761] = 6,
	[764] = 10,
	[765] = 12,
	[768] = 8,
	[769] = 10,
	[770] = 12,
	[773] = 10,
	[824] = 27,
	[833] = 10,
	[834] = 9,
	[835] = 9,
	[836] = 35,
	[840] = 10,
	[844] = 12,
	[845] = 13,
	[848] = 15,
	[850] = 14,
	[851] = 16,
	[852] = 19,
	[855] = 18,
	[858] = 18,
	[861] = 10,
	[863] = 18,
	[865] = 18,
	[866] = 16,
	[867] = 17,
	[869] = 15,
	[870] = 13,
	[871] = 12,
	[872] = 12,
	[875] = 16,
	[876] = 18,
	[877] = 16,
	[880] = 14,
	[881] = 13,
	[887] = 16,
	[891] = 15,
	[895] = 16,
	[899] = 12,
	[903] = 13,
	[905] = 14,
	[918] = 9,
	[919] = 9,
	[922] = 9,
	[923] = 9,
	[927] = 12,
	[929] = 6,
	[930] = 9,
	[931] = 9,
	[932] = 7,
	[933] = 9,
	[935] = 11,
	[937] = 10,
	[938] = 10,
	[941] = 12,
	[996] = 55,
	[997] = 9,
	[998] = 55,
	[1036] = 60,
	[1097] = 15,
	[1168] = 41,
	[1201] = 35,
	[1202] = 35,
	[1204] = 36,
	[1205] = 41,
	[1222] = 37,
	[1258] = 36,
	[1270] = 37,
	[1271] = 37,
	[1338] = 14,
	[1392] = 39,
	[1393] = 38,
	[1431] = 30,
	[1432] = 30,
	[1433] = 33,
	[1434] = 33,
	[1436] = 33,
	[1442] = 22,
	[1453] = 30,
	[1454] = 30,
	[1455] = 30,
	[1456] = 30,
	[1467] = 40,
	[1578] = 12,
	[1581] = 8,
	[1582] = 18,
	[1618] = 16,
	[1655] = 22,
	[1918] = 27,
	[2039] = 15,
	[2158] = 5,
	[2159] = 5,
	[2206] = 10,
	[2278] = 40,
	[2280] = 40,
	[2383] = 3,
	[2399] = 10,
	[2438] = 6,
	[2459] = 6,
	[2499] = 10,
	[2518] = 10,
	[2523] = 55,
	[2541] = 8,
	[2561] = 10,
	[2751] = 32,
	[2752] = 32,
	[2753] = 36,
	[2754] = 36,
	[2755] = 36,
	[2945] = 34,
	[2947] = 34,
	[2948] = 35,
	[2949] = 34,
	[2950] = 35,
	[2951] = 30,
	[2952] = 30,
	[2953] = 30,
	[2963] = 50,
	[2965] = 50,
	[3087] = 3,
	[3088] = 3,
	[3089] = 3,
	[3090] = 3,
	[3091] = 3,
	[3092] = 3,
	[3093] = 3,
	[3094] = 3,
	[3095] = 3,
	[3096] = 3,
	[3097] = 3,
	[3098] = 3,
	[3099] = 3,
	[3100] = 3,
	[3101] = 3,
	[3102] = 3,
	[3103] = 3,
	[3104] = 3,
	[3105] = 3,
	[3106] = 3,
	[3107] = 3,
	[3108] = 3,
	[3109] = 3,
	[3110] = 3,
	[3115] = 3,
	[3116] = 3,
	[3117] = 3,
	[3118] = 3,
	[3119] = 3,
	[3120] = 3,
	[3361] = 3,
	[3363] = 55,
	[3721] = 50,
	[3861] = 1,
	[4021] = 20,
	[4083] = 55,
	[4103] = 55,
	[4104] = 55,
	[4105] = 55,
	[4106] = 55,
	[4107] = 55,
	[4108] = 55,
	[4109] = 55,
	[4110] = 55,
	[4111] = 55,
	[4112] = 55,
	[4117] = 55,
	[4119] = 55,
	[4295] = 1,
	[4443] = 55,
	[4447] = 55,
	[4494] = 53,
	[4512] = 52,
	[4513] = 54,
	[4601] = 30,
	[4602] = 30,
	[4603] = 30,
	[4604] = 30,
	[4605] = 30,
	[4606] = 30,
	[4621] = 60,
	[4785] = 37,
	[4970] = 60,
	[4976] = 40,
	[5041] = 12,
	[5201] = 60,
	[5421] = 34,
	[5501] = 32,
	[5545] = 10,
	[5561] = 34,
	[5581] = 35,
	[5713] = 15,
	[5821] = 33,
	[5882] = 55,
	[5883] = 55,
	[5884] = 55,
	[5885] = 55,
	[5886] = 55,
	[5887] = 55,
	[5888] = 55,
	[5889] = 55,
	[5890] = 55,
	[5891] = 55,
	[5943] = 35,
	[5981] = 60,
	[6031] = 55,
	[6032] = 55,
	[6132] = 34,
	[6134] = 39,
	[6142] = 35,
	[6143] = 36,
	[6321] = 7,
	[6322] = 7,
	[6323] = 7,
	[6324] = 7,
	[6341] = 7,
	[6342] = 7,
	[6343] = 7,
	[6344] = 7,
	[6361] = 7,
	[6362] = 7,
	[6363] = 7,
	[6364] = 7,
	[6365] = 7,
	[6384] = 7,
	[6385] = 7,
	[6386] = 7,
	[6387] = 7,
	[6388] = 7,
	[6391] = 7,
	[6392] = 7,
	[6441] = 22,
	[6442] = 19,
	[6462] = 23,
	[6482] = 24,
	[6503] = 21,
	[6544] = 24,
	[6546] = 25,
	[6563] = 22,
	[6607] = 45,
	[6608] = 45,
	[6609] = 45,
	[6610] = 45,
	[6611] = 45,
	[6612] = 45,
	[6621] = 25,
	[6623] = 45,
	[6625] = 45,
	[6641] = 23,
	[6642] = 60,
	[6643] = 60,
	[6644] = 60,
	[6645] = 60,
	[6646] = 60,
	[6661] = 12,
	[6662] = 12,
	[6701] = 60,
	[6922] = 30,
	[7383] = 9,
	[7493] = 60,
	[7497] = 60,
	[7604] = 60,
	[7660] = 1,
	[7661] = 1,
	[7662] = 1,
	[7663] = 1,
	[7673] = 1,
	[7674] = 1,
	[7677] = 1,
	[7678] = 1,
	[7737] = 50,
	[7761] = 60,
	[7781] = 60,
	[7782] = 60,
	[7783] = 60,
	[7784] = 60,
	[7785] = 60,
	[7786] = 60,
	[7787] = 60,
	[7810] = 55,
	[7838] = 55,
	[7848] = 60,
	[7863] = 34,
	[7864] = 44,
	[7865] = 70,
	[7866] = 34,
	[7867] = 44,
	[7868] = 70,
	[8105] = 55,
	[8114] = 60,
	[8115] = 60,
	[8120] = 55,
	[8121] = 60,
	[8122] = 60,
	[8249] = 60,
	[8260] = 34,
	[8261] = 44,
	[8262] = 70,
	[8263] = 34,
	[8264] = 44,
	[8265] = 70,
	[8277] = 55,
	[8278] = 56,
	[8279] = 56,
	[8280] = 55,
	[8281] = 56,
	[8282] = 56,
	[8283] = 56,
	[8284] = 56,
	[8285] = 56,
	[8287] = 56,
	[8304] = 56,
	[8306] = 56,
	[8307] = 56,
	[8308] = 56,
	[8309] = 56,
	[8310] = 56,
	[8313] = 56,
	[8314] = 56,
	[8317] = 56,
	[8318] = 56,
	[8319] = 56,
	[8320] = 56,
	[8321] = 56,
	[8323] = 56,
	[8324] = 56,
	[8325] = 1,
	[8326] = 3,
	[8327] = 3,
	[8328] = 3,
	[8329] = 3,
	[8330] = 4,
	[8334] = 4,
	[8335] = 5,
	[8336] = 4,
	[8338] = 4,
	[8345] = 4,
	[8346] = 3,
	[8347] = 5,
	[8350] = 5,
	[8368] = 19,
	[8446] = 60,
	[8447] = 60,
	[8463] = 5,
	[8468] = 6,
	[8470] = 55,
	[8472] = 5,
	[8473] = 9,
	[8474] = 10,
	[8475] = 6,
	[8476] = 10,
	[8477] = 10,
	[8479] = 11,
	[8480] = 7,
	[8481] = 55,
	[8482] = 6,
	[8483] = 7,
	[8486] = 6,
	[8487] = 9,
	[8488] = 9,
	[8490] = 10,
	[8491] = 7,
	[8544] = 60,
	[8556] = 60,
	[8557] = 60,
	[8558] = 60,
	[8559] = 60,
	[8560] = 60,
	[8561] = 60,
	[8562] = 60,
	[8563] = 3,
	[8564] = 3,
	[8579] = 60,
	[8592] = 60,
	[8593] = 60,
	[8594] = 60,
	[8595] = 60,
	[8596] = 60,
	[8602] = 60,
	[8603] = 60,
	[8621] = 60,
	[8622] = 60,
	[8623] = 60,
	[8624] = 60,
	[8625] = 60,
	[8626] = 60,
	[8627] = 60,
	[8628] = 60,
	[8629] = 60,
	[8630] = 60,
	[8631] = 60,
	[8632] = 60,
	[8633] = 60,
	[8634] = 60,
	[8637] = 60,
	[8638] = 60,
	[8639] = 60,
	[8640] = 60,
	[8641] = 60,
	[8655] = 60,
	[8656] = 60,
	[8657] = 60,
	[8658] = 60,
	[8659] = 60,
	[8660] = 60,
	[8661] = 60,
	[8662] = 60,
	[8663] = 60,
	[8664] = 60,
	[8665] = 60,
	[8666] = 60,
	[8667] = 60,
	[8668] = 60,
	[8669] = 60,
	[8689] = 60,
	[8690] = 60,
	[8691] = 60,
	[8692] = 60,
	[8693] = 60,
	[8694] = 60,
	[8695] = 60,
	[8696] = 60,
	[8697] = 60,
	[8698] = 60,
	[8699] = 60,
	[8700] = 60,
	[8701] = 60,
	[8702] = 60,
	[8703] = 60,
	[8704] = 60,
	[8705] = 60,
	[8706] = 60,
	[8707] = 60,
	[8708] = 60,
	[8709] = 60,
	[8710] = 60,
	[8711] = 60,
	[8712] = 60,
	[8747] = 60,
	[8748] = 60,
	[8749] = 60,
	[8750] = 60,
	[8751] = 60,
	[8752] = 60,
	[8753] = 60,
	[8754] = 60,
	[8755] = 60,
	[8756] = 60,
	[8757] = 60,
	[8758] = 60,
	[8759] = 60,
	[8760] = 60,
	[8761] = 60,
	[8764] = 60,
	[8765] = 60,
	[8766] = 60,
	[8784] = 60,
	[8789] = 60,
	[8790] = 60,
	[8791] = 60,
	[8798] = 60,
	[8801] = 60,
	[8802] = 60,
	[8884] = 7,
	[8885] = 9,
	[8886] = 8,
	[8887] = 8,
	[8888] = 10,
	[8889] = 10,
	[8890] = 10,
	[8891] = 10,
	[8892] = 7,
	[8894] = 10,
	[8895] = 6,
	[9035] = 6,
	[9062] = 6,
	[9064] = 6,
	[9066] = 6,
	[9067] = 9,
	[9076] = 8,
	[9119] = 5,
	[9130] = 7,
	[9133] = 7,
	[9134] = 7,
	[9135] = 7,
	[9138] = 10,
	[9139] = 11,
	[9140] = 14,
	[9143] = 12,
	[9144] = 10,
	[9145] = 12,
	[9146] = 12,
	[9147] = 10,
	[9148] = 10,
	[9149] = 13,
	[9150] = 12,
	[9151] = 20,
	[9152] = 11,
	[9155] = 14,
	[9156] = 21,
	[9157] = 12,
	[9158] = 14,
	[9159] = 15,
	[9160] = 11,
	[9161] = 16,
	[9162] = 16,
	[9163] = 14,
	[9164] = 20,
	[9166] = 16,
	[9167] = 21,
	[9169] = 16,
	[9170] = 20,
	[9171] = 15,
	[9172] = 16,
	[9173] = 15,
	[9174] = 13,
	[9175] = 15,
	[9176] = 17,
	[9180] = 15,
	[9192] = 14,
	[9193] = 17,
	[9199] = 17,
	[9207] = 14,
	[9212] = 17,
	[9214] = 18,
	[9215] = 20,
	[9216] = 16,
	[9217] = 16,
	[9218] = 18,
	[9219] = 18,
	[9220] = 20,
	[9250] = 60,
	[9251] = 60,
	[9252] = 9,
	[9253] = 10,
	[9254] = 9,
	[9255] = 9,
	[9256] = 7,
	[9257] = 60,
	[9258] = 10,
	[9269] = 60,
	[9270] = 60,
	[9271] = 60,
	[9272] = 55,
	[9274] = 12,
	[9275] = 19,
	[9276] = 18,
	[9277] = 19,
	[9279] = 1,
	[9280] = 1,
	[9281] = 18,
	[9282] = 16,
	[9283] = 2,
	[9287] = 3,
	[9288] = 3,
	[9289] = 3,
	[9290] = 3,
	[9291] = 3,
	[9293] = 2,
	[9294] = 3,
	[9303] = 4,
	[9305] = 4,
	[9309] = 5,
	[9311] = 5,
	[9312] = 5,
	[9313] = 5,
	[9314] = 5,
	[9315] = 11,
	[9327] = 10,
	[9328] = 21,
	[9329] = 10,
	[9340] = 62,
	[9345] = 61,
	[9349] = 61,
	[9351] = 61,
	[9352] = 6,
	[9355] = 61,
	[9356] = 61,
	[9358] = 9,
	[9359] = 10,
	[9360] = 11,
	[9361] = 61,
	[9362] = 60,
	[9363] = 11,
	[9366] = 62,
	[9369] = 1,
	[9370] = 62,
	[9371] = 2,
	[9372] = 63,
	[9373] = 61,
	[9374] = 62,
	[9375] = 63,
	[9376] = 63,
	[9381] = 63,
	[9383] = 63,
	[9385] = 63,
	[9387] = 63,
	[9390] = 62,
	[9391] = 62,
	[9392] = 3,
	[9393] = 3,
	[9394] = 10,
	[9395] = 9,
	[9396] = 62,
	[9397] = 62,
	[9398] = 62,
	[9399] = 63,
	[9400] = 62,
	[9401] = 62,
	[9402] = 10,
	[9403] = 10,
	[9404] = 10,
	[9405] = 62,
	[9406] = 62,
	[9407] = 61,
	[9409] = 2,
	[9410] = 62,
	[9415] = 56,
	[9416] = 56,
	[9417] = 63,
	[9418] = 63,
	[9419] = 56,
	[9420] = 62,
	[9421] = 3,
	[9422] = 56,
	[9423] = 62,
	[9424] = 63,
	[9426] = 62,
	[9427] = 62,
	[9430] = 63,
	[9436] = 26,
	[9437] = 37,
	[9442] = 63,
	[9447] = 63,
	[9452] = 6,
	[9453] = 6,
	[9454] = 6,
	[9455] = 7,
	[9456] = 8,
	[9457] = 26,
	[9463] = 6,
	[9466] = 63,
	[9472] = 62,
	[9473] = 8,
	[9483] = 62,
	[9487] = 16,
	[9488] = 16,
	[9490] = 63,
	[9498] = 62,
	[9499] = 62,
	[9505] = 8,
	[9506] = 7,
	[9512] = 7,
	[9513] = 8,
	[9514] = 8,
	[9515] = 10,
	[9523] = 8,
	[9527] = 10,
	[9528] = 10,
	[9530] = 9,
	[9531] = 9,
	[9537] = 9,
	[9538] = 8,
	[9539] = 10,
	[9540] = 10,
	[9541] = 10,
	[9542] = 10,
	[9543] = 63,
	[9544] = 10,
	[9545] = 63,
	[9548] = 17,
	[9549] = 17,
	[9550] = 16,
	[9557] = 16,
	[9558] = 62,
	[9559] = 10,
	[9560] = 10,
	[9561] = 16,
	[9562] = 10,
	[9563] = 62,
	[9564] = 11,
	[9565] = 10,
	[9566] = 10,
	[9567] = 14,
	[9569] = 18,
	[9570] = 12,
	[9571] = 10,
	[9573] = 11,
	[9574] = 14,
	[9576] = 12,
	[9578] = 18,
	[9579] = 18,
	[9580] = 16,
	[9581] = 11,
	[9582] = 10,
	[9584] = 14,
	[9585] = 18,
	[9594] = 14,
	[9595] = 11,
	[9602] = 9,
	[9603] = 7,
	[9604] = 7,
	[9605] = 7,
	[9606] = 7,
	[9612] = 8,
	[9616] = 7,
	[9620] = 14,
	[9621] = 21,
	[9622] = 11,
	[9623] = 11,
	[9624] = 12,
	[9625] = 11,
	[9626] = 21,
	[9627] = 21,
	[9628] = 14,
	[9629] = 13,
	[9630] = 70,
	[9631] = 70,
	[9632] = 15,
	[9634] = 11,
	[9635] = 60,
	[9636] = 60,
	[9637] = 70,
	[9638] = 70,
	[9639] = 70,
	[9640] = 70,
	[9641] = 15,
	[9642] = 15,
	[9643] = 15,
	[9644] = 70,
	[9645] = 70,
	[9646] = 17,
	[9647] = 16,
	[9648] = 14,
	[9649] = 18,
	[9663] = 12,
	[9666] = 13,
	[9667] = 13,
	[9668] = 13,
	[9669] = 19,
	[9670] = 19,
	[9671] = 18,
	[9672] = 18,
	[9674] = 18,
	[9676] = 3,
	[9680] = 70,
	[9682] = 18,
	[9683] = 19,
	[9687] = 18,
	[9688] = 19,
	[9689] = 21,
	[9693] = 15,
	[9694] = 15,
	[9696] = 16,
	[9697] = 63,
	[9698] = 16,
	[9699] = 16,
	[9700] = 16,
	[9701] = 63,
	[9702] = 64,
	[9703] = 17,
	[9704] = 5,
	[9705] = 5,
	[9706] = 18,
	[9708] = 63,
	[9709] = 64,
	[9711] = 18,
	[9716] = 63,
	[9718] = 63,
	[9720] = 64,
	[9724] = 64,
	[9726] = 64,
	[9727] = 64,
	[9728] = 64,
	[9729] = 65,
	[9730] = 64,
	[9731] = 63,
	[9732] = 63,
	[9739] = 63,
	[9740] = 18,
	[9741] = 18,
	[9742] = 63,
	[9743] = 64,
	[9744] = 64,
	[9746] = 18,
	[9747] = 62,
	[9748] = 18,
	[9752] = 63,
	[9753] = 20,
	[9756] = 20,
	[9758] = 10,
	[9759] = 20,
	[9760] = 20,
	[9761] = 20,
	[9762] = 20,
	[9769] = 62,
	[9770] = 62,
	[9771] = 62,
	[9772] = 62,
	[9773] = 61,
	[9774] = 62,
	[9775] = 62,
	[9776] = 64,
	[9777] = 62,
	[9778] = 64,
	[9779] = 16,
	[9780] = 62,
	[9781] = 62,
	[9782] = 62,
	[9783] = 62,
	[9784] = 64,
	[9785] = 64,
	[9786] = 62,
	[9787] = 62,
	[9788] = 62,
	[9789] = 66,
	[9790] = 62,
	[9791] = 62,
	[9792] = 64,
	[9793] = 62,
	[9794] = 65,
	[9795] = 65,
	[9796] = 62,
	[9797] = 64,
	[9798] = 5,
	[9799] = 3,
	[9800] = 65,
	[9801] = 62,
	[9802] = 63,
	[9803] = 62,
	[9804] = 65,
	[9805] = 65,
	[9806] = 64,
	[9807] = 64,
	[9808] = 64,
	[9809] = 64,
	[9810] = 66,
	[9811] = 21,
	[9812] = 21,
	[9813] = 21,
	[9814] = 64,
	[9815] = 66,
	[9816] = 64,
	[9817] = 63,
	[9818] = 65,
	[9819] = 65,
	[9820] = 64,
	[9821] = 66,
	[9822] = 64,
	[9823] = 64,
	[9824] = 70,
	[9825] = 70,
	[9826] = 70,
	[9827] = 62,
	[9828] = 62,
	[9829] = 70,
	[9830] = 64,
	[9831] = 70,
	[9832] = 70,
	[9833] = 64,
	[9834] = 64,
	[9835] = 64,
	[9836] = 70,
	[9837] = 70,
	[9838] = 70,
	[9839] = 64,
	[9840] = 70,
	[9841] = 64,
	[9842] = 64,
	[9843] = 70,
	[9844] = 70,
	[9845] = 64,
	[9846] = 62,
	[9847] = 64,
	[9848] = 64,
	[9849] = 67,
	[9850] = 67,
	[9851] = 67,
	[9852] = 68,
	[9853] = 67,
	[9854] = 65,
	[9855] = 67,
	[9856] = 67,
	[9857] = 65,
	[9858] = 66,
	[9859] = 66,
	[9860] = 70,
	[9861] = 67,
	[9862] = 67,
	[9863] = 66,
	[9864] = 67,
	[9865] = 67,
	[9866] = 67,
	[9867] = 67,
	[9868] = 67,
	[9869] = 66,
	[9870] = 66,
	[9871] = 67,
	[9872] = 67,
	[9873] = 67,
	[9874] = 67,
	[9875] = 63,
	[9877] = 20,
	[9878] = 67,
	[9879] = 67,
	[9882] = 66,
	[9883] = 66,
	[9884] = 70,
	[9885] = 70,
	[9886] = 70,
	[9887] = 70,
	[9888] = 65,
	[9889] = 65,
	[9890] = 65,
	[9891] = 65,
	[9892] = 67,
	[9893] = 67,
	[9894] = 62,
	[9895] = 62,
	[9896] = 62,
	[9897] = 65,
	[9898] = 62,
	[9899] = 62,
	[9900] = 67,
	[9901] = 62,
	[9902] = 64,
	[9903] = 64,
	[9904] = 64,
	[9905] = 64,
	[9906] = 65,
	[9907] = 66,
	[9910] = 65,
	[9911] = 64,
	[9912] = 62,
	[9913] = 66,
	[9914] = 66,
	[9915] = 66,
	[9916] = 66,
	[9917] = 65,
	[9918] = 65,
	[9919] = 64,
	[9920] = 65,
	[9921] = 65,
	[9922] = 66,
	[9923] = 65,
	[9924] = 66,
	[9925] = 66,
	[9927] = 66,
	[9928] = 66,
	[9931] = 66,
	[9932] = 66,
	[9933] = 66,
	[9934] = 66,
	[9935] = 66,
	[9936] = 66,
	[9937] = 67,
	[9938] = 67,
	[9939] = 66,
	[9940] = 66,
	[9944] = 67,
	[9945] = 67,
	[9946] = 67,
	[9948] = 67,
	[9951] = 64,
	[9954] = 67,
	[9955] = 67,
	[9956] = 67,
	[9957] = 63,
	[9960] = 63,
	[9961] = 63,
	[9962] = 67,
	[9967] = 67,
	[9968] = 63,
	[9970] = 67,
	[9971] = 63,
	[9972] = 67,
	[9973] = 67,
	[9977] = 68,
	[9978] = 63,
	[9979] = 63,
	[9982] = 68,
	[9983] = 68,
	[9986] = 64,
	[9987] = 64,
	[9990] = 64,
	[9991] = 68,
	[9992] = 63,
	[9993] = 63,
	[9994] = 64,
	[9995] = 64,
	[9996] = 64,
	[9997] = 64,
	[9998] = 63,
	[9999] = 68,
	[10000] = 63,
	[10001] = 68,
	[10002] = 64,
	[10003] = 64,
	[10004] = 68,
	[10005] = 63,
	[10006] = 63,
	[10007] = 64,
	[10008] = 64,
	[10009] = 68,
	[10010] = 68,
	[10011] = 68,
	[10012] = 64,
	[10013] = 64,
	[10016] = 64,
	[10017] = 64,
	[10018] = 64,
	[10019] = 64,
	[10020] = 64,
	[10021] = 64,
	[10022] = 64,
	[10023] = 64,
	[10024] = 65,
	[10025] = 65,
	[10026] = 64,
	[10027] = 64,
	[10028] = 63,
	[10030] = 65,
	[10031] = 65,
	[10033] = 65,
	[10034] = 65,
	[10035] = 65,
	[10036] = 65,
	[10037] = 64,
	[10038] = 64,
	[10039] = 64,
	[10040] = 65,
	[10041] = 65,
	[10042] = 65,
	[10043] = 65,
	[10044] = 68,
	[10045] = 68,
	[10047] = 61,
	[10050] = 61,
	[10051] = 64,
	[10052] = 64,
	[10055] = 61,
	[10057] = 61,
	[10058] = 61,
	[10063] = 17,
	[10064] = 18,
	[10065] = 17,
	[10066] = 18,
	[10067] = 19,
	[10068] = 3,
	[10069] = 3,
	[10070] = 3,
	[10071] = 3,
	[10072] = 3,
	[10073] = 3,
	[10074] = 67,
	[10075] = 67,
	[10076] = 67,
	[10077] = 67,
	[10078] = 61,
	[10079] = 61,
	[10081] = 68,
	[10082] = 68,
	[10085] = 68,
	[10086] = 61,
	[10087] = 61,
	[10093] = 63,
	[10096] = 62,
	[10099] = 61,
	[10101] = 68,
	[10102] = 68,
	[10103] = 61,
	[10104] = 62,
	[10105] = 62,
	[10106] = 60,
	[10107] = 66,
	[10108] = 66,
	[10109] = 66,
	[10110] = 60,
	[10111] = 66,
	[10112] = 64,
	[10113] = 65,
	[10114] = 65,
	[10115] = 64,
	[10116] = 64,
	[10117] = 64,
	[10118] = 64,
	[10119] = 61,
	[10120] = 61,
	[10121] = 61,
	[10123] = 61,
	[10124] = 61,
	[10129] = 62,
	[10132] = 63,
	[10134] = 63,
	[10136] = 63,
	[10140] = 61,
	[10141] = 61,
	[10142] = 61,
	[10143] = 61,
	[10144] = 62,
	[10146] = 62,
	[10159] = 63,
	[10160] = 61,
	[10161] = 61,
	[10162] = 62,
	[10163] = 62,
	[10166] = 10,
	[10167] = 68,
	[10168] = 68,
	[10170] = 68,
	[10171] = 68,
	[10172] = 68,
	[10173] = 68,
	[10174] = 68,
	[10176] = 68,
	[10180] = 69,
	[10182] = 68,
	[10183] = 68,
	[10184] = 68,
	[10185] = 68,
	[10186] = 68,
	[10188] = 69,
	[10189] = 68,
	[10190] = 68,
	[10191] = 68,
	[10192] = 69,
	[10193] = 68,
	[10194] = 68,
	[10197] = 68,
	[10198] = 68,
	[10199] = 68,
	[10200] = 68,
	[10201] = 65,
	[10202] = 70,
	[10203] = 69,
	[10204] = 68,
	[10205] = 69,
	[10206] = 68,
	[10208] = 62,
	[10209] = 69,
	[10210] = 65,
	[10211] = 65,
	[10213] = 61,
	[10220] = 61,
	[10221] = 68,
	[10222] = 69,
	[10223] = 69,
	[10224] = 68,
	[10225] = 68,
	[10226] = 68,
	[10227] = 67,
	[10228] = 67,
	[10229] = 61,
	[10230] = 61,
	[10231] = 67,
	[10232] = 69,
	[10233] = 69,
	[10234] = 69,
	[10235] = 69,
	[10236] = 61,
	[10237] = 69,
	[10238] = 61,
	[10239] = 69,
	[10240] = 69,
	[10241] = 68,
	[10242] = 60,
	[10243] = 68,
	[10245] = 68,
	[10246] = 68,
	[10247] = 69,
	[10248] = 69,
	[10249] = 69,
	[10250] = 61,
	[10251] = 67,
	[10252] = 67,
	[10253] = 67,
	[10254] = 60,
	[10255] = 63,
	[10256] = 69,
	[10257] = 70,
	[10258] = 61,
	[10261] = 68,
	[10262] = 68,
	[10263] = 68,
	[10264] = 68,
	[10265] = 69,
	[10266] = 69,
	[10267] = 69,
	[10268] = 69,
	[10269] = 69,
	[10270] = 70,
	[10271] = 70,
	[10272] = 70,
	[10273] = 70,
	[10274] = 70,
	[10275] = 70,
	[10276] = 70,
	[10277] = 68,
	[10278] = 61,
	[10279] = 66,
	[10280] = 70,
	[10281] = 70,
	[10282] = 68,
	[10286] = 62,
	[10287] = 62,
	[10288] = 61,
	[10289] = 61,
	[10290] = 70,
	[10291] = 61,
	[10293] = 69,
	[10294] = 61,
	[10295] = 63,
	[10296] = 70,
	[10297] = 70,
	[10299] = 68,
	[10300] = 69,
	[10301] = 69,
	[10302] = 2,
	[10303] = 4,
	[10304] = 4,
	[10305] = 69,
	[10306] = 69,
	[10307] = 69,
	[10308] = 68,
	[10309] = 68,
	[10310] = 70,
	[10311] = 70,
	[10312] = 69,
	[10313] = 68,
	[10314] = 69,
	[10315] = 70,
	[10316] = 69,
	[10317] = 70,
	[10318] = 70,
	[10319] = 69,
	[10320] = 69,
	[10321] = 69,
	[10322] = 70,
	[10323] = 70,
	[10324] = 8,
	[10325] = 65,
	[10326] = 65,
	[10327] = 65,
	[10328] = 70,
	[10329] = 68,
	[10330] = 69,
	[10331] = 69,
	[10332] = 69,
	[10333] = 69,
	[10334] = 69,
	[10335] = 70,
	[10336] = 70,
	[10337] = 69,
	[10338] = 70,
	[10339] = 70,
	[10340] = 60,
	[10341] = 70,
	[10342] = 68,
	[10343] = 69,
	[10344] = 60,
	[10345] = 70,
	[10346] = 62,
	[10347] = 62,
	[10348] = 69,
	[10349] = 63,
	[10350] = 10,
	[10351] = 63,
	[10353] = 70,
	[10355] = 62,
	[10365] = 70,
	[10367] = 62,
	[10368] = 62,
	[10369] = 62,
	[10372] = 16,
	[10380] = 70,
	[10381] = 70,
	[10382] = 61,
	[10384] = 70,
	[10385] = 70,
	[10388] = 61,
	[10389] = 61,
	[10390] = 61,
	[10391] = 61,
	[10392] = 61,
	[10393] = 61,
	[10394] = 61,
	[10395] = 61,
	[10396] = 61,
	[10397] = 61,
	[10399] = 61,
	[10400] = 63,
	[10403] = 62,
	[10405] = 70,
	[10406] = 70,
	[10407] = 70,
	[10408] = 70,
	[10409] = 70,
	[10410] = 70,
	[10411] = 70,
	[10412] = 65,
	[10413] = 70,
	[10414] = 70,
	[10415] = 70,
	[10416] = 70,
	[10417] = 68,
	[10418] = 68,
	[10419] = 70,
	[10420] = 70,
	[10421] = 70,
	[10422] = 70,
	[10423] = 69,
	[10424] = 69,
	[10425] = 70,
	[10426] = 69,
	[10427] = 69,
	[10428] = 10,
	[10429] = 69,
	[10430] = 69,
	[10431] = 70,
	[10432] = 70,
	[10433] = 69,
	[10434] = 69,
	[10435] = 69,
	[10436] = 69,
	[10437] = 70,
	[10438] = 70,
	[10439] = 70,
	[10440] = 69,
	[10442] = 61,
	[10443] = 61,
	[10444] = 64,
	[10446] = 65,
	[10447] = 65,
	[10448] = 64,
	[10449] = 60,
	[10450] = 60,
	[10451] = 70,
	[10455] = 66,
	[10456] = 66,
	[10457] = 66,
	[10458] = 70,
	[10460] = 70,
	[10461] = 70,
	[10462] = 70,
	[10463] = 70,
	[10464] = 70,
	[10465] = 70,
	[10466] = 70,
	[10467] = 70,
	[10468] = 70,
	[10469] = 70,
	[10470] = 70,
	[10471] = 70,
	[10472] = 70,
	[10473] = 70,
	[10474] = 70,
	[10475] = 70,
	[10476] = 67,
	[10477] = 68,
	[10478] = 68,
	[10479] = 67,
	[10480] = 70,
	[10481] = 70,
	[10482] = 58,
	[10483] = 58,
	[10484] = 58,
	[10485] = 60,
	[10486] = 66,
	[10487] = 66,
	[10488] = 66,
	[10489] = 66,
	[10502] = 66,
	[10503] = 66,
	[10504] = 66,
	[10505] = 66,
	[10506] = 66,
	[10507] = 70,
	[10508] = 70,
	[10509] = 70,
	[10510] = 66,
	[10511] = 66,
	[10512] = 66,
	[10513] = 70,
	[10514] = 70,
	[10515] = 70,
	[10516] = 66,
	[10517] = 67,
	[10518] = 67,
	[10519] = 70,
	[10521] = 70,
	[10522] = 70,
	[10523] = 70,
	[10524] = 66,
	[10525] = 66,
	[10526] = 67,
	[10527] = 70,
	[10528] = 70,
	[10537] = 70,
	[10538] = 60,
	[10540] = 70,
	[10541] = 70,
	[10542] = 66,
	[10543] = 67,
	[10544] = 66,
	[10545] = 66,
	[10546] = 70,
	[10547] = 70,
	[10550] = 70,
	[10551] = 65,
	[10552] = 65,
	[10553] = 65,
	[10554] = 65,
	[10555] = 66,
	[10556] = 66,
	[10557] = 64,
	[10562] = 69,
	[10563] = 69,
	[10564] = 69,
	[10565] = 66,
	[10566] = 66,
	[10567] = 66,
	[10568] = 70,
	[10569] = 69,
	[10570] = 70,
	[10571] = 70,
	[10572] = 69,
	[10573] = 69,
	[10574] = 70,
	[10575] = 70,
	[10576] = 70,
	[10577] = 70,
	[10578] = 70,
	[10579] = 70,
	[10580] = 67,
	[10581] = 67,
	[10582] = 69,
	[10583] = 69,
	[10584] = 67,
	[10585] = 69,
	[10586] = 69,
	[10587] = 70,
	[10588] = 70,
	[10589] = 69,
	[10594] = 67,
	[10595] = 69,
	[10596] = 69,
	[10597] = 69,
	[10598] = 69,
	[10599] = 69,
	[10600] = 69,
	[10601] = 69,
	[10602] = 69,
	[10603] = 69,
	[10604] = 69,
	[10606] = 69,
	[10607] = 68,
	[10608] = 67,
	[10609] = 67,
	[10611] = 69,
	[10612] = 69,
	[10613] = 69,
	[10614] = 66,
	[10615] = 64,
	[10617] = 66,
	[10618] = 65,
	[10619] = 70,
	[10620] = 67,
	[10621] = 69,
	[10622] = 70,
	[10623] = 69,
	[10624] = 69,
	[10625] = 69,
	[10626] = 69,
	[10627] = 69,
	[10628] = 70,
	[10629] = 61,
	[10630] = 61,
	[10632] = 67,
	[10633] = 70,
	[10634] = 70,
	[10635] = 70,
	[10636] = 70,
	[10637] = 70,
	[10639] = 70,
	[10640] = 70,
	[10641] = 70,
	[10642] = 69,
	[10643] = 69,
	[10644] = 70,
	[10645] = 70,
	[10646] = 70,
	[10647] = 70,
	[10648] = 70,
	[10649] = 70,
	[10650] = 70,
	[10651] = 70,
	[10652] = 69,
	[10653] = 70,
	[10654] = 70,
	[10655] = 70,
	[10656] = 70,
	[10657] = 67,
	[10658] = 70,
	[10659] = 70,
	[10660] = 69,
	[10661] = 69,
	[10662] = 69,
	[10663] = 69,
	[10664] = 69,
	[10665] = 69,
	[10666] = 69,
	[10667] = 70,
	[10668] = 70,
	[10669] = 70,
	[10670] = 70,
	[10671] = 67,
	[10672] = 69,
	[10673] = 70,
	[10674] = 67,
	[10675] = 68,
	[10676] = 70,
	[10677] = 69,
	[10678] = 70,
	[10679] = 70,
	[10680] = 70,
	[10681] = 70,
	[10682] = 67,
	[10683] = 70,
	[10684] = 70,
	[10685] = 70,
	[10686] = 70,
	[10687] = 70,
	[10688] = 70,
	[10689] = 70,
	[10690] = 66,
	[10691] = 70,
	[10692] = 70,
	[10701] = 68,
	[10702] = 69,
	[10703] = 69,
	[10704] = 70,
	[10705] = 70,
	[10706] = 70,
	[10707] = 70,
	[10708] = 70,
	[10709] = 67,
	[10710] = 64,
	[10711] = 64,
	[10712] = 64,
	[10713] = 67,
	[10714] = 67,
	[10715] = 67,
	[10717] = 67,
	[10718] = 67,
	[10719] = 67,
	[10720] = 67,
	[10721] = 67,
	[10722] = 68,
	[10723] = 68,
	[10724] = 67,
	[10725] = 70,
	[10726] = 70,
	[10727] = 70,
	[10728] = 70,
	[10729] = 70,
	[10730] = 70,
	[10731] = 70,
	[10732] = 70,
	[10733] = 70,
	[10734] = 70,
	[10735] = 70,
	[10736] = 70,
	[10738] = 70,
	[10739] = 70,
	[10740] = 70,
	[10741] = 70,
	[10742] = 70,
	[10744] = 70,
	[10745] = 70,
	[10747] = 68,
	[10748] = 68,
	[10749] = 67,
	[10750] = 70,
	[10751] = 70,
	[10753] = 67,
	[10754] = 70,
	[10759] = 69,
	[10760] = 69,
	[10761] = 69,
	[10762] = 70,
	[10763] = 70,
	[10764] = 70,
	[10765] = 70,
	[10766] = 69,
	[10767] = 69,
	[10768] = 70,
	[10769] = 70,
	[10770] = 67,
	[10771] = 67,
	[10772] = 70,
	[10773] = 70,
	[10774] = 70,
	[10775] = 70,
	[10776] = 70,
	[10777] = 69,
	[10778] = 69,
	[10780] = 69,
	[10781] = 70,
	[10782] = 69,
	[10783] = 67,
	[10784] = 67,
	[10785] = 67,
	[10786] = 68,
	[10791] = 64,
	[10792] = 61,
	[10793] = 70,
	[10795] = 67,
	[10796] = 67,
	[10797] = 67,
	[10798] = 67,
	[10799] = 67,
	[10800] = 67,
	[10801] = 67,
	[10802] = 68,
	[10803] = 68,
	[10804] = 70,
	[10805] = 67,
	[10806] = 70,
	[10807] = 70,
	[10808] = 69,
	[10809] = 60,
	[10810] = 68,
	[10811] = 70,
	[10812] = 68,
	[10813] = 62,
	[10814] = 70,
	[10816] = 70,
	[10817] = 70,
	[10818] = 67,
	[10819] = 68,
	[10820] = 68,
	[10821] = 68,
	[10822] = 70,
	[10823] = 70,
	[10824] = 70,
	[10825] = 68,
	[10826] = 70,
	[10827] = 70,
	[10828] = 70,
	[10829] = 68,
	[10830] = 68,
	[10834] = 62,
	[10835] = 61,
	[10836] = 70,
	[10837] = 70,
	[10838] = 61,
	[10839] = 64,
	[10840] = 65,
	[10842] = 65,
	[10843] = 68,
	[10845] = 68,
	[10846] = 67,
	[10847] = 62,
	[10848] = 64,
	[10849] = 63,
	[10850] = 70,
	[10851] = 67,
	[10852] = 64,
	[10853] = 67,
	[10854] = 70,
	[10855] = 69,
	[10856] = 69,
	[10857] = 69,
	[10858] = 70,
	[10859] = 67,
	[10860] = 67,
	[10861] = 64,
	[10862] = 63,
	[10863] = 63,
	[10864] = 61,
	[10865] = 68,
	[10866] = 70,
	[10867] = 68,
	[10868] = 62,
	[10869] = 62,
	[10870] = 70,
	[10873] = 65,
	[10874] = 65,
	[10875] = 61,
	[10876] = 63,
	[10877] = 66,
	[10878] = 63,
	[10879] = 65,
	[10880] = 64,
	[10881] = 64,
	[10883] = 70,
	[10884] = 70,
	[10885] = 70,
	[10886] = 70,
	[10887] = 64,
	[10888] = 70,
	[10889] = 65,
	[10893] = 67,
	[10894] = 67,
	[10895] = 60,
	[10896] = 65,
	[10898] = 65,
	[10900] = 70,
	[10903] = 61,
	[10904] = 68,
	[10908] = 63,
	[10909] = 61,
	[10910] = 68,
	[10911] = 68,
	[10912] = 68,
	[10913] = 65,
	[10914] = 65,
	[10915] = 65,
	[10916] = 61,
	[10917] = 65,
	[10918] = 65,
	[10919] = 61,
	[10920] = 65,
	[10921] = 65,
	[10922] = 65,
	[10923] = 65,
	[10924] = 69,
	[10926] = 65,
	[10927] = 65,
	[10928] = 65,
	[10929] = 65,
	[10930] = 65,
	[10935] = 61,
	[10936] = 61,
	[10937] = 62,
	[10938] = 70,
	[10939] = 70,
	[10940] = 70,
	[10941] = 70,
	[10944] = 70,
	[10946] = 70,
	[10947] = 70,
	[10948] = 70,
	[10949] = 70,
	[10957] = 70,
	[10958] = 70,
	[10959] = 70,
	[10969] = 70,
	[10970] = 70,
	[10971] = 70,
	[10972] = 70,
	[10973] = 70,
	[10974] = 70,
	[10975] = 70,
	[10976] = 70,
	[10977] = 70,
	[10981] = 70,
	[10982] = 70,
	[10983] = 70,
	[10984] = 70,
	[10985] = 70,
	[10989] = 70,
	[10995] = 70,
	[10996] = 70,
	[10997] = 70,
	[10998] = 70,
	[11000] = 70,
	[11002] = 70,
	[11003] = 70,
	[11004] = 70,
	[11005] = 70,
	[11006] = 70,
	[11007] = 70,
	[11008] = 70,
	[11009] = 70,
	[11010] = 70,
	[11012] = 70,
	[11013] = 70,
	[11014] = 70,
	[11015] = 70,
	[11016] = 70,
	[11017] = 70,
	[11018] = 70,
	[11019] = 70,
	[11020] = 70,
	[11021] = 70,
	[11022] = 70,
	[11023] = 70,
	[11024] = 70,
	[11025] = 70,
	[11026] = 70,
	[11028] = 70,
	[11029] = 70,
	[11030] = 70,
	[11031] = 70,
	[11032] = 70,
	[11033] = 70,
	[11034] = 70,
	[11035] = 70,
	[11036] = 67,
	[11037] = 67,
	[11038] = 67,
	[11039] = 67,
	[11040] = 67,
	[11041] = 70,
	[11042] = 67,
	[11043] = 67,
	[11044] = 67,
	[11045] = 67,
	[11046] = 67,
	[11047] = 67,
	[11048] = 67,
	[11049] = 70,
	[11050] = 70,
	[11051] = 70,
	[11053] = 70,
	[11054] = 70,
	[11055] = 70,
	[11056] = 70,
	[11057] = 70,
	[11058] = 70,
	[11059] = 70,
	[11061] = 70,
	[11062] = 70,
	[11063] = 70,
	[11064] = 70,
	[11065] = 70,
	[11066] = 70,
	[11067] = 70,
	[11068] = 70,
	[11069] = 70,
	[11070] = 70,
	[11071] = 70,
	[11072] = 70,
	[11073] = 70,
	[11074] = 70,
	[11075] = 70,
	[11076] = 70,
	[11077] = 70,
	[11078] = 70,
	[11079] = 70,
	[11080] = 70,
	[11081] = 70,
	[11082] = 70,
	[11083] = 70,
	[11084] = 70,
	[11085] = 70,
	[11086] = 70,
	[11089] = 70,
	[11090] = 70,
	[11091] = 70,
	[11092] = 70,
	[11093] = 70,
	[11094] = 70,
	[11095] = 70,
	[11096] = 70,
	[11097] = 70,
	[11098] = 70,
	[11099] = 70,
	[11100] = 70,
	[11101] = 70,
	[11102] = 70,
	[11103] = 70,
	[11104] = 70,
	[11105] = 70,
	[11106] = 70,
	[11107] = 70,
	[11108] = 70,
	[11109] = 70,
	[11110] = 70,
	[11111] = 70,
	[11112] = 70,
	[11113] = 70,
	[11114] = 70,
	[11119] = 70,
	[11129] = 7,
	[11135] = 80,
	[11153] = 71,
	[11154] = 71,
	[11155] = 71,
	[11157] = 71,
	[11165] = 70,
	[11167] = 71,
	[11168] = 71,
	[11170] = 71,
	[11175] = 71,
	[11176] = 71,
	[11182] = 71,
	[11187] = 71,
	[11188] = 71,
	[11190] = 71,
	[11196] = 85,
	[11199] = 71,
	[11202] = 71,
	[11208] = 39,
	[11211] = 39,
	[11212] = 37,
	[11213] = 37,
	[11215] = 39,
	[11216] = 70,
	[11218] = 71,
	[11220] = 80,
	[11221] = 71,
	[11224] = 71,
	[11227] = 71,
	[11228] = 70,
	[11229] = 71,
	[11230] = 71,
	[11231] = 71,
	[11232] = 71,
	[11233] = 71,
	[11234] = 71,
	[11235] = 71,
	[11236] = 72,
	[11237] = 72,
	[11238] = 72,
	[11239] = 71,
	[11240] = 71,
	[11241] = 71,
	[11243] = 70,
	[11244] = 70,
	[11245] = 71,
	[11246] = 71,
	[11247] = 71,
	[11248] = 71,
	[11249] = 72,
	[11250] = 72,
	[11251] = 71,
	[11253] = 71,
	[11254] = 71,
	[11255] = 70,
	[11256] = 71,
	[11257] = 71,
	[11258] = 71,
	[11259] = 71,
	[11260] = 72,
	[11261] = 72,
	[11262] = 71,
	[11263] = 71,
	[11264] = 72,
	[11265] = 71,
	[11266] = 72,
	[11267] = 72,
	[11268] = 71,
	[11269] = 71,
	[11270] = 71,
	[11271] = 71,
	[11272] = 71,
	[11273] = 70,
	[11274] = 70,
	[11275] = 71,
	[11276] = 70,
	[11277] = 71,
	[11278] = 71,
	[11279] = 71,
	[11280] = 71,
	[11281] = 71,
	[11282] = 71,
	[11283] = 71,
	[11284] = 71,
	[11285] = 71,
	[11286] = 71,
	[11287] = 71,
	[11288] = 71,
	[11289] = 71,
	[11290] = 70,
	[11291] = 70,
	[11292] = 70,
	[11295] = 71,
	[11296] = 72,
	[11297] = 71,
	[11298] = 71,
	[11299] = 71,
	[11300] = 71,
	[11301] = 71,
	[11302] = 70,
	[11303] = 71,
	[11304] = 71,
	[11305] = 71,
	[11306] = 71,
	[11307] = 71,
	[11308] = 71,
	[11309] = 71,
	[11310] = 71,
	[11311] = 71,
	[11312] = 71,
	[11313] = 71,
	[11314] = 71,
	[11315] = 71,
	[11316] = 71,
	[11317] = 71,
	[11319] = 71,
	[11322] = 71,
	[11323] = 71,
	[11324] = 71,
	[11325] = 71,
	[11326] = 71,
	[11327] = 71,
	[11328] = 71,
	[11329] = 70,
	[11330] = 71,
	[11331] = 71,
	[11332] = 71,
	[11333] = 71,
	[11343] = 71,
	[11344] = 71,
	[11346] = 71,
	[11348] = 71,
	[11349] = 71,
	[11350] = 71,
	[11351] = 71,
	[11352] = 71,
	[11355] = 72,
	[11358] = 72,
	[11359] = 72,
	[11364] = 70,
	[11365] = 72,
	[11366] = 72,
	[11367] = 72,
	[11371] = 70,
	[11376] = 70,
	[11377] = 70,
	[11379] = 70,
	[11380] = 70,
	[11381] = 70,
	[11383] = 70,
	[11385] = 70,
	[11387] = 70,
	[11389] = 70,
	[11390] = 71,
	[11391] = 71,
	[11392] = 80,
	[11393] = 71,
	[11394] = 71,
	[11395] = 71,
	[11396] = 71,
	[11397] = 71,
	[11398] = 71,
	[11399] = 71,
	[11406] = 70,
	[11410] = 71,
	[11414] = 71,
	[11415] = 71,
	[11416] = 71,
	[11417] = 71,
	[11418] = 70,
	[11420] = 71,
	[11421] = 71,
	[11422] = 71,
	[11423] = 71,
	[11424] = 71,
	[11426] = 71,
	[11427] = 71,
	[11428] = 71,
	[11429] = 71,
	[11430] = 71,
	[11432] = 71,
	[11433] = 71,
	[11434] = 71,
	[11436] = 71,
	[11443] = 71,
	[11448] = 71,
	[11451] = 70,
	[11453] = 72,
	[11455] = 71,
	[11456] = 71,
	[11457] = 71,
	[11458] = 71,
	[11459] = 71,
	[11460] = 71,
	[11464] = 71,
	[11465] = 71,
	[11466] = 71,
	[11467] = 71,
	[11468] = 71,
	[11469] = 71,
	[11470] = 71,
	[11471] = 71,
	[11473] = 71,
	[11474] = 71,
	[11475] = 71,
	[11476] = 71,
	[11477] = 70,
	[11478] = 71,
	[11479] = 71,
	[11480] = 71,
	[11481] = 70,
	[11482] = 70,
	[11483] = 71,
	[11484] = 71,
	[11485] = 71,
	[11489] = 71,
	[11490] = 70,
	[11491] = 71,
	[11494] = 71,
	[11495] = 71,
	[11496] = 70,
	[11497] = 70,
	[11498] = 70,
	[11500] = 70,
	[11501] = 71,
	[11502] = 70,
	[11503] = 70,
	[11504] = 71,
	[11507] = 71,
	[11508] = 71,
	[11509] = 71,
	[11510] = 71,
	[11511] = 71,
	[11512] = 71,
	[11513] = 70,
	[11514] = 70,
	[11515] = 70,
	[11516] = 70,
	[11517] = 70,
	[11519] = 71,
	[11520] = 70,
	[11521] = 70,
	[11523] = 70,
	[11524] = 70,
	[11525] = 70,
	[11526] = 70,
	[11527] = 71,
	[11529] = 71,
	[11530] = 71,
	[11531] = 70,
	[11532] = 70,
	[11533] = 70,
	[11534] = 70,
	[11535] = 70,
	[11536] = 70,
	[11537] = 70,
	[11538] = 70,
	[11539] = 70,
	[11540] = 70,
	[11541] = 70,
	[11542] = 70,
	[11543] = 70,
	[11544] = 70,
	[11545] = 70,
	[11546] = 70,
	[11547] = 70,
	[11548] = 70,
	[11549] = 70,
	[11550] = 70,
	[11554] = 70,
	[11555] = 70,
	[11556] = 70,
	[11557] = 70,
	[11559] = 71,
	[11560] = 71,
	[11561] = 71,
	[11562] = 71,
	[11563] = 71,
	[11564] = 71,
	[11565] = 71,
	[11566] = 72,
	[11567] = 71,
	[11568] = 71,
	[11569] = 71,
	[11570] = 71,
	[11571] = 71,
	[11572] = 71,
	[11573] = 71,
	[11574] = 71,
	[11575] = 71,
	[11576] = 71,
	[11582] = 71,
	[11585] = 71,
	[11586] = 71,
	[11587] = 71,
	[11590] = 71,
	[11591] = 71,
	[11592] = 72,
	[11593] = 71,
	[11594] = 71,
	[11595] = 71,
	[11596] = 71,
	[11597] = 71,
	[11598] = 71,
	[11599] = 71,
	[11600] = 71,
	[11601] = 71,
	[11602] = 71,
	[11603] = 71,
	[11604] = 71,
	[11605] = 72,
	[11606] = 71,
	[11607] = 72,
	[11608] = 71,
	[11609] = 72,
	[11610] = 72,
	[11611] = 71,
	[11612] = 72,
	[11613] = 71,
	[11614] = 71,
	[11615] = 71,
	[11616] = 71,
	[11617] = 72,
	[11618] = 71,
	[11619] = 71,
	[11620] = 71,
	[11623] = 72,
	[11624] = 71,
	[11625] = 71,
	[11626] = 71,
	[11627] = 72,
	[11628] = 72,
	[11629] = 71,
	[11630] = 72,
	[11631] = 71,
	[11632] = 71,
	[11633] = 72,
	[11634] = 71,
	[11635] = 71,
	[11636] = 71,
	[11637] = 72,
	[11638] = 71,
	[11639] = 71,
	[11640] = 72,
	[11641] = 72,
	[11642] = 71,
	[11643] = 71,
	[11644] = 71,
	[11645] = 71,
	[11646] = 71,
	[11647] = 72,
	[11648] = 71,
	[11649] = 71,
	[11650] = 71,
	[11651] = 71,
	[11652] = 71,
	[11653] = 71,
	[11654] = 72,
	[11655] = 71,
	[11656] = 71,
	[11658] = 71,
	[11659] = 72,
	[11660] = 71,
	[11661] = 71,
	[11662] = 71,
	[11663] = 71,
	[11664] = 71,
	[11665] = 70,
	[11666] = 70,
	[11667] = 70,
	[11668] = 70,
	[11669] = 70,
	[11670] = 72,
	[11671] = 71,
	[11672] = 71,
	[11673] = 72,
	[11674] = 71,
	[11675] = 71,
	[11676] = 71,
	[11677] = 71,
	[11678] = 71,
	[11679] = 71,
	[11680] = 71,
	[11681] = 71,
	[11682] = 71,
	[11683] = 71,
	[11684] = 71,
	[11685] = 71,
	[11686] = 71,
	[11687] = 72,
	[11688] = 71,
	[11689] = 71,
	[11690] = 71,
	[11691] = 70,
	[11692] = 71,
	[11693] = 71,
	[11694] = 71,
	[11695] = 71,
	[11696] = 70,
	[11697] = 71,
	[11698] = 71,
	[11699] = 72,
	[11700] = 71,
	[11701] = 71,
	[11702] = 71,
	[11703] = 71,
	[11704] = 71,
	[11705] = 71,
	[11706] = 71,
	[11707] = 71,
	[11708] = 71,
	[11709] = 71,
	[11710] = 71,
	[11711] = 71,
	[11712] = 71,
	[11713] = 71,
	[11714] = 71,
	[11715] = 71,
	[11716] = 71,
	[11717] = 71,
	[11718] = 71,
	[11719] = 71,
	[11720] = 71,
	[11721] = 71,
	[11722] = 71,
	[11723] = 71,
	[11724] = 71,
	[11725] = 71,
	[11726] = 71,
	[11727] = 71,
	[11728] = 71,
	[11729] = 71,
	[11730] = 71,
	[11733] = 71,
	[11788] = 71,
	[11789] = 71,
	[11790] = 71,
	[11791] = 71,
	[11792] = 71,
	[11793] = 71,
	[11794] = 71,
	[11795] = 71,
	[11796] = 71,
	[11797] = 71,
	[11798] = 72,
	[11864] = 72,
	[11865] = 72,
	[11866] = 72,
	[11867] = 72,
	[11868] = 72,
	[11869] = 72,
	[11870] = 72,
	[11871] = 72,
	[11872] = 72,
	[11873] = 71,
	[11875] = 70,
	[11876] = 72,
	[11877] = 70,
	[11878] = 72,
	[11879] = 72,
	[11880] = 70,
	[11881] = 71,
	[11884] = 72,
	[11885] = 70,
	[11887] = 71,
	[11888] = 71,
	[11889] = 71,
	[11890] = 71,
	[11892] = 72,
	[11893] = 71,
	[11894] = 71,
	[11895] = 71,
	[11896] = 71,
	[11897] = 71,
	[11898] = 71,
	[11899] = 71,
	[11900] = 71,
	[11901] = 71,
	[11902] = 71,
	[11903] = 71,
	[11904] = 71,
	[11905] = 71,
	[11906] = 71,
	[11907] = 71,
	[11908] = 71,
	[11909] = 72,
	[11910] = 71,
	[11911] = 71,
	[11912] = 71,
	[11913] = 71,
	[11914] = 71,
	[11916] = 71,
	[11917] = 22,
	[11918] = 71,
	[11919] = 71,
	[11920] = 71,
	[11927] = 71,
	[11928] = 71,
	[11929] = 72,
	[11930] = 72,
	[11931] = 71,
	[11932] = 71,
	[11934] = 15,
	[11936] = 71,
	[11938] = 72,
	[11940] = 71,
	[11941] = 71,
	[11942] = 72,
	[11943] = 71,
	[11944] = 72,
	[11945] = 72,
	[11946] = 71,
	[11947] = 32,
	[11948] = 43,
	[11949] = 72,
	[11950] = 72,
	[11951] = 71,
	[11952] = 51,
	[11953] = 60,
	[11955] = 70,
	[11956] = 71,
	[11957] = 71,
	[11958] = 72,
	[11959] = 73,
	[11960] = 72,
	[11961] = 72,
	[11962] = 71,
	[11963] = 71,
	[11965] = 71,
	[11967] = 71,
	[11968] = 71,
	[11969] = 71,
	[11973] = 71,
	[11977] = 72,
	[11978] = 72,
	[11979] = 72,
	[11980] = 72,
	[11981] = 75,
	[11982] = 75,
	[11983] = 72,
	[11984] = 74,
	[11985] = 75,
	[11986] = 75,
	[11988] = 75,
	[11989] = 73,
	[11990] = 74,
	[11991] = 74,
	[11993] = 75,
	[11995] = 72,
	[11996] = 72,
	[11998] = 75,
	[11999] = 72,
	[12000] = 72,
	[12002] = 75,
	[12003] = 75,
	[12004] = 73,
	[12005] = 73,
	[12006] = 72,
	[12007] = 74,
	[12008] = 72,
	[12009] = 72,
	[12010] = 75,
	[12011] = 72,
	[12013] = 73,
	[12014] = 75,
	[12016] = 72,
	[12017] = 73,
	[12019] = 72,
	[12026] = 75,
	[12027] = 74,
	[12028] = 72,
	[12029] = 74,
	[12030] = 72,
	[12031] = 72,
	[12032] = 72,
	[12033] = 72,
	[12034] = 72,
	[12035] = 71,
	[12036] = 72,
	[12037] = 74,
	[12038] = 72,
	[12039] = 72,
	[12040] = 72,
	[12041] = 72,
	[12042] = 74,
	[12043] = 74,
	[12044] = 74,
	[12045] = 74,
	[12046] = 74,
	[12047] = 74,
	[12048] = 72,
	[12049] = 74,
	[12050] = 74,
	[12052] = 74,
	[12053] = 72,
	[12054] = 75,
	[12055] = 72,
	[12056] = 72,
	[12057] = 72,
	[12058] = 75,
	[12059] = 72,
	[12060] = 72,
	[12061] = 72,
	[12063] = 72,
	[12064] = 72,
	[12065] = 72,
	[12066] = 72,
	[12067] = 72,
	[12068] = 75,
	[12069] = 73,
	[12070] = 75,
	[12071] = 72,
	[12072] = 72,
	[12073] = 75,
	[12074] = 75,
	[12075] = 74,
	[12076] = 74,
	[12077] = 74,
	[12078] = 74,
	[12079] = 74,
	[12080] = 74,
	[12081] = 75,
	[12082] = 75,
	[12083] = 72,
	[12084] = 72,
	[12085] = 72,
	[12086] = 72,
	[12088] = 72,
	[12089] = 74,
	[12090] = 74,
	[12091] = 74,
	[12092] = 72,
	[12093] = 75,
	[12094] = 75,
	[12095] = 75,
	[12096] = 72,
	[12097] = 75,
	[12098] = 72,
	[12099] = 75,
	[12100] = 72,
	[12101] = 72,
	[12102] = 73,
	[12104] = 73,
	[12105] = 74,
	[12106] = 72,
	[12107] = 72,
	[12109] = 74,
	[12110] = 72,
	[12111] = 73,
	[12112] = 74,
	[12113] = 75,
	[12114] = 75,
	[12115] = 72,
	[12116] = 75,
	[12117] = 72,
	[12118] = 72,
	[12119] = 72,
	[12120] = 75,
	[12121] = 75,
	[12122] = 72,
	[12123] = 75,
	[12124] = 75,
	[12125] = 73,
	[12126] = 73,
	[12127] = 73,
	[12128] = 75,
	[12129] = 75,
	[12130] = 75,
	[12131] = 75,
	[12132] = 73,
	[12134] = 75,
	[12136] = 73,
	[12137] = 75,
	[12138] = 75,
	[12140] = 73,
	[12141] = 71,
	[12142] = 73,
	[12143] = 73,
	[12144] = 73,
	[12145] = 73,
	[12146] = 73,
	[12147] = 73,
	[12148] = 73,
	[12149] = 73,
	[12150] = 74,
	[12151] = 74,
	[12152] = 75,
	[12153] = 75,
	[12154] = 75,
	[12157] = 72,
	[12158] = 75,
	[12159] = 75,
	[12160] = 75,
	[12161] = 75,
	[12164] = 75,
	[12165] = 75,
	[12166] = 72,
	[12167] = 72,
	[12168] = 72,
	[12169] = 72,
	[12170] = 74,
	[12171] = 72,
	[12172] = 73,
	[12173] = 73,
	[12174] = 72,
	[12175] = 74,
	[12176] = 74,
	[12177] = 74,
	[12178] = 74,
	[12180] = 75,
	[12181] = 72,
	[12182] = 72,
	[12183] = 75,
	[12184] = 75,
	[12185] = 75,
	[12188] = 72,
	[12189] = 72,
	[12190] = 74,
	[12195] = 75,
	[12196] = 75,
	[12197] = 75,
	[12198] = 75,
	[12199] = 75,
	[12200] = 72,
	[12201] = 75,
	[12202] = 75,
	[12203] = 75,
	[12204] = 75,
	[12205] = 72,
	[12206] = 72,
	[12207] = 74,
	[12208] = 74,
	[12209] = 72,
	[12210] = 73,
	[12211] = 72,
	[12212] = 74,
	[12213] = 74,
	[12214] = 72,
	[12215] = 74,
	[12216] = 74,
	[12217] = 74,
	[12218] = 72,
	[12219] = 74,
	[12220] = 74,
	[12221] = 72,
	[12222] = 74,
	[12223] = 74,
	[12224] = 73,
	[12225] = 73,
	[12226] = 73,
	[12227] = 73,
	[12229] = 74,
	[12230] = 72,
	[12231] = 75,
	[12232] = 72,
	[12234] = 72,
	[12235] = 72,
	[12236] = 75,
	[12237] = 72,
	[12238] = 75,
	[12239] = 72,
	[12240] = 72,
	[12241] = 75,
	[12242] = 74,
	[12243] = 72,
	[12244] = 74,
	[12245] = 72,
	[12246] = 74,
	[12247] = 75,
	[12248] = 75,
	[12249] = 75,
	[12250] = 75,
	[12251] = 72,
	[12252] = 72,
	[12253] = 72,
	[12254] = 72,
	[12255] = 74,
	[12256] = 74,
	[12257] = 74,
	[12258] = 72,
	[12259] = 74,
	[12260] = 72,
	[12261] = 74,
	[12262] = 74,
	[12263] = 74,
	[12264] = 74,
	[12265] = 74,
	[12266] = 74,
	[12267] = 75,
	[12268] = 74,
	[12269] = 72,
	[12270] = 74,
	[12271] = 72,
	[12272] = 72,
	[12273] = 73,
	[12274] = 73,
	[12275] = 72,
	[12276] = 72,
	[12277] = 72,
	[12279] = 75,
	[12280] = 74,
	[12281] = 72,
	[12282] = 72,
	[12283] = 72,
	[12284] = 74,
	[12285] = 73,
	[12287] = 72,
	[12288] = 74,
	[12289] = 74,
	[12290] = 72,
	[12291] = 72,
	[12292] = 74,
	[12293] = 74,
	[12294] = 74,
	[12295] = 74,
	[12296] = 74,
	[12297] = 72,
	[12298] = 72,
	[12299] = 74,
	[12300] = 74,
	[12301] = 72,
	[12302] = 74,
	[12303] = 72,
	[12304] = 72,
	[12305] = 72,
	[12307] = 74,
	[12308] = 74,
	[12309] = 72,
	[12310] = 74,
	[12311] = 72,
	[12312] = 73,
	[12314] = 74,
	[12315] = 74,
	[12316] = 74,
	[12317] = 74,
	[12319] = 73,
	[12320] = 73,
	[12321] = 73,
	[12323] = 74,
	[12324] = 74,
	[12325] = 73,
	[12326] = 73,
	[12327] = 75,
	[12328] = 75,
	[12329] = 75,
	[12330] = 75,
	[12372] = 74,
	[12411] = 75,
	[12412] = 75,
	[12413] = 74,
	[12414] = 75,
	[12415] = 75,
	[12416] = 74,
	[12417] = 74,
	[12418] = 75,
	[12419] = 75,
	[12422] = 74,
	[12423] = 74,
	[12424] = 74,
	[12425] = 75,
	[12427] = 74,
	[12428] = 74,
	[12429] = 74,
	[12430] = 75,
	[12431] = 75,
	[12432] = 74,
	[12433] = 74,
	[12434] = 74,
	[12435] = 74,
	[12436] = 74,
	[12437] = 74,
	[12438] = 74,
	[12439] = 72,
	[12440] = 72,
	[12441] = 74,
	[12442] = 74,
	[12443] = 74,
	[12444] = 74,
	[12446] = 74,
	[12447] = 74,
	[12448] = 74,
	[12449] = 74,
	[12450] = 75,
	[12451] = 74,
	[12453] = 74,
	[12454] = 74,
	[12455] = 73,
	[12456] = 74,
	[12457] = 73,
	[12458] = 74,
	[12459] = 74,
	[12460] = 74,
	[12461] = 74,
	[12462] = 73,
	[12463] = 73,
	[12464] = 73,
	[12465] = 73,
	[12466] = 73,
	[12467] = 73,
	[12468] = 74,
	[12469] = 74,
	[12470] = 75,
	[12471] = 71,
	[12472] = 73,
	[12473] = 73,
	[12474] = 73,
	[12475] = 73,
	[12476] = 73,
	[12477] = 73,
	[12478] = 73,
	[12481] = 71,
	[12482] = 71,
	[12483] = 75,
	[12484] = 74,
	[12486] = 71,
	[12487] = 74,
	[12488] = 74,
	[12489] = 76,
	[12495] = 74,
	[12496] = 74,
	[12497] = 74,
	[12498] = 74,
	[12499] = 74,
	[12500] = 74,
	[12502] = 76,
	[12503] = 76,
	[12504] = 76,
	[12505] = 76,
	[12506] = 76,
	[12507] = 76,
	[12508] = 76,
	[12509] = 76,
	[12510] = 76,
	[12511] = 73,
	[12512] = 76,
	[12513] = 68,
	[12514] = 76,
	[12516] = 76,
	[12517] = 15,
	[12518] = 35,
	[12519] = 76,
	[12520] = 76,
	[12521] = 76,
	[12522] = 76,
	[12523] = 76,
	[12524] = 76,
	[12525] = 76,
	[12526] = 76,
	[12527] = 76,
	[12528] = 77,
	[12529] = 77,
	[12530] = 77,
	[12531] = 77,
	[12532] = 77,
	[12533] = 77,
	[12534] = 77,
	[12535] = 77,
	[12536] = 77,
	[12537] = 77,
	[12538] = 77,
	[12539] = 77,
	[12540] = 77,
	[12541] = 76,
	[12542] = 74,
	[12543] = 76,
	[12544] = 76,
	[12545] = 74,
	[12546] = 78,
	[12547] = 78,
	[12548] = 78,
	[12549] = 76,
	[12550] = 76,
	[12551] = 76,
	[12552] = 76,
	[12553] = 76,
	[12554] = 76,
	[12555] = 76,
	[12556] = 76,
	[12557] = 76,
	[12558] = 76,
	[12559] = 77,
	[12560] = 76,
	[12561] = 77,
	[12562] = 76,
	[12564] = 76,
	[12565] = 76,
	[12566] = 71,
	[12567] = 76,
	[12568] = 76,
	[12569] = 76,
	[12570] = 77,
	[12571] = 77,
	[12572] = 77,
	[12573] = 77,
	[12574] = 77,
	[12575] = 77,
	[12576] = 77,
	[12577] = 77,
	[12578] = 77,
	[12579] = 77,
	[12580] = 77,
	[12581] = 77,
	[12582] = 77,
	[12583] = 76,
	[12584] = 76,
	[12585] = 76,
	[12587] = 76,
	[12588] = 76,
	[12589] = 76,
	[12591] = 76,
	[12592] = 76,
	[12593] = 55,
	[12594] = 76,
	[12595] = 77,
	[12596] = 76,
	[12597] = 76,
	[12598] = 76,
	[12599] = 76,
	[12603] = 77,
	[12604] = 76,
	[12605] = 77,
	[12606] = 76,
	[12607] = 77,
	[12608] = 78,
	[12609] = 76,
	[12610] = 76,
	[12611] = 77,
	[12612] = 77,
	[12613] = 77,
	[12614] = 77,
	[12615] = 77,
	[12617] = 77,
	[12618] = 77,
	[12619] = 55,
	[12620] = 77,
	[12621] = 77,
	[12622] = 77,
	[12623] = 77,
	[12624] = 76,
	[12627] = 77,
	[12628] = 77,
	[12629] = 75,
	[12630] = 75,
	[12631] = 75,
	[12632] = 77,
	[12633] = 75,
	[12634] = 76,
	[12635] = 77,
	[12636] = 55,
	[12637] = 75,
	[12638] = 75,
	[12639] = 77,
	[12640] = 77,
	[12641] = 55,
	[12642] = 77,
	[12643] = 75,
	[12644] = 76,
	[12645] = 76,
	[12646] = 77,
	[12647] = 77,
	[12648] = 75,
	[12649] = 75,
	[12650] = 77,
	[12651] = 77,
	[12652] = 75,
	[12653] = 77,
	[12654] = 76,
	[12655] = 77,
	[12656] = 77,
	[12657] = 55,
	[12658] = 77,
	[12659] = 77,
	[12660] = 77,
	[12661] = 75,
	[12662] = 77,
	[12663] = 75,
	[12664] = 75,
	[12665] = 77,
	[12666] = 77,
	[12667] = 77,
	[12668] = 77,
	[12669] = 75,
	[12670] = 55,
	[12671] = 77,
	[12672] = 77,
	[12673] = 75,
	[12674] = 77,
	[12675] = 77,
	[12676] = 75,
	[12677] = 75,
	[12678] = 55,
	[12679] = 55,
	[12680] = 55,
	[12681] = 77,
	[12683] = 77,
	[12684] = 77,
	[12685] = 77,
	[12686] = 75,
	[12687] = 55,
	[12688] = 76,
	[12689] = 77,
	[12690] = 75,
	[12691] = 78,
	[12692] = 77,
	[12695] = 77,
	[12696] = 77,
	[12697] = 55,
	[12698] = 55,
	[12699] = 77,
	[12700] = 55,
	[12701] = 55,
	[12702] = 77,
	[12703] = 78,
	[12704] = 77,
	[12705] = 78,
	[12706] = 55,
	[12707] = 77,
	[12708] = 77,
	[12709] = 77,
	[12710] = 75,
	[12711] = 55,
	[12712] = 77,
	[12713] = 76,
	[12714] = 55,
	[12715] = 55,
	[12716] = 55,
	[12717] = 55,
	[12718] = 55,
	[12719] = 55,
	[12720] = 55,
	[12721] = 77,
	[12722] = 55,
	[12723] = 55,
	[12724] = 55,
	[12725] = 55,
	[12726] = 80,
	[12727] = 55,
	[12728] = 71,
	[12729] = 77,
	[12730] = 78,
	[12732] = 80,
	[12733] = 55,
	[12734] = 80,
	[12735] = 80,
	[12736] = 80,
	[12737] = 80,
	[12738] = 55,
	[12739] = 55,
	[12740] = 76,
	[12741] = 80,
	[12742] = 55,
	[12743] = 55,
	[12744] = 55,
	[12745] = 55,
	[12746] = 55,
	[12747] = 55,
	[12748] = 55,
	[12749] = 55,
	[12750] = 55,
	[12751] = 55,
	[12754] = 55,
	[12755] = 55,
	[12756] = 55,
	[12757] = 55,
	[12758] = 80,
	[12759] = 78,
	[12760] = 78,
	[12761] = 78,
	[12762] = 78,
	[12763] = 75,
	[12766] = 72,
	[12767] = 72,
	[12768] = 75,
	[12769] = 75,
	[12770] = 75,
	[12778] = 55,
	[12779] = 55,
	[12789] = 75,
	[12790] = 74,
	[12791] = 74,
	[12792] = 75,
	[12793] = 75,
	[12794] = 74,
	[12795] = 75,
	[12796] = 74,
	[12797] = 78,
	[12798] = 25,
	[12799] = 75,
	[12800] = 55,
	[12801] = 55,
	[12802] = 74,
	[12803] = 78,
	[12804] = 76,
	[12805] = 77,
	[12806] = 80,
	[12807] = 80,
	[12810] = 80,
	[12813] = 80,
	[12814] = 80,
	[12815] = 80,
	[12818] = 78,
	[12819] = 78,
	[12820] = 78,
	[12821] = 78,
	[12822] = 78,
	[12823] = 78,
	[12824] = 78,
	[12826] = 78,
	[12827] = 78,
	[12828] = 78,
	[12829] = 78,
	[12830] = 78,
	[12831] = 78,
	[12832] = 78,
	[12833] = 78,
	[12836] = 78,
	[12838] = 80,
	[12839] = 80,
	[12840] = 80,
	[12841] = 79,
	[12842] = 55,
	[12843] = 79,
	[12844] = 79,
	[12846] = 78,
	[12847] = 80,
	[12848] = 55,
	[12849] = 55,
	[12850] = 55,
	[12851] = 80,
	[12852] = 80,
	[12853] = 78,
	[12854] = 80,
	[12855] = 80,
	[12856] = 80,
	[12857] = 75,
	[12858] = 80,
	[12859] = 75,
	[12860] = 80,
	[12861] = 75,
	[12862] = 78,
	[12863] = 78,
	[12864] = 78,
	[12865] = 78,
	[12866] = 78,
	[12867] = 78,
	[12868] = 78,
	[12869] = 78,
	[12870] = 78,
	[12871] = 80,
	[12872] = 80,
	[12873] = 80,
	[12874] = 80,
	[12875] = 80,
	[12876] = 80,
	[12877] = 80,
	[12878] = 80,
	[12879] = 80,
	[12880] = 80,
	[12882] = 78,
	[12883] = 75,
	[12884] = 75,
	[12885] = 80,
	[12886] = 80,
	[12887] = 80,
	[12888] = 80,
	[12889] = 80,
	[12890] = 79,
	[12891] = 80,
	[12892] = 80,
	[12893] = 80,
	[12894] = 75,
	[12895] = 80,
	[12896] = 80,
	[12897] = 80,
	[12898] = 80,
	[12899] = 80,
	[12900] = 80,
	[12901] = 76,
	[12902] = 75,
	[12903] = 76,
	[12904] = 76,
	[12905] = 79,
	[12906] = 79,
	[12907] = 79,
	[12908] = 79,
	[12909] = 80,
	[12910] = 80,
	[12912] = 76,
	[12913] = 80,
	[12914] = 76,
	[12915] = 80,
	[12916] = 76,
	[12917] = 80,
	[12919] = 76,
	[12920] = 80,
	[12921] = 79,
	[12922] = 80,
	[12924] = 80,
	[12925] = 80,
	[12926] = 80,
	[12927] = 80,
	[12928] = 80,
	[12929] = 80,
	[12930] = 80,
	[12931] = 80,
	[12932] = 77,
	[12933] = 77,
	[12934] = 77,
	[12935] = 77,
	[12936] = 77,
	[12937] = 80,
	[12938] = 80,
	[12939] = 80,
	[12942] = 80,
	[12943] = 80,
	[12948] = 78,
	[12949] = 80,
	[12951] = 80,
	[12953] = 80,
	[12955] = 80,
	[12956] = 80,
	[12957] = 80,
	[12964] = 80,
	[12965] = 80,
	[12966] = 80,
	[12967] = 80,
	[12968] = 80,
	[12969] = 80,
	[12970] = 80,
	[12971] = 80,
	[12972] = 80,
	[12973] = 80,
	[12974] = 77,
	[12975] = 80,
	[12976] = 80,
	[12977] = 80,
	[12978] = 80,
	[12979] = 80,
	[12980] = 80,
	[12981] = 80,
	[12982] = 80,
	[12983] = 80,
	[12984] = 80,
	[12985] = 80,
	[12986] = 80,
	[12987] = 80,
	[12988] = 80,
	[12989] = 80,
	[12991] = 80,
	[12992] = 80,
	[12993] = 80,
	[12994] = 80,
	[12995] = 80,
	[12996] = 80,
	[12997] = 80,
	[12998] = 80,
	[12999] = 80,
	[13000] = 79,
	[13001] = 80,
	[13003] = 80,
	[13005] = 80,
	[13006] = 80,
	[13007] = 80,
	[13008] = 78,
	[13009] = 80,
	[13010] = 80,
	[13011] = 80,
	[13034] = 80,
	[13035] = 80,
	[13036] = 78,
	[13037] = 80,
	[13038] = 80,
	[13039] = 78,
	[13040] = 78,
	[13042] = 80,
	[13043] = 80,
	[13044] = 78,
	[13045] = 78,
	[13046] = 80,
	[13047] = 80,
	[13048] = 80,
	[13049] = 80,
	[13050] = 80,
	[13051] = 80,
	[13054] = 80,
	[13055] = 80,
	[13056] = 80,
	[13057] = 80,
	[13058] = 80,
	[13059] = 80,
	[13060] = 78,
	[13061] = 79,
	[13062] = 80,
	[13063] = 80,
	[13064] = 80,
	[13068] = 80,
	[13069] = 80,
	[13070] = 78,
	[13071] = 80,
	[13072] = 80,
	[13073] = 80,
	[13074] = 80,
	[13075] = 80,
	[13076] = 80,
	[13077] = 80,
	[13078] = 80,
	[13079] = 80,
	[13080] = 80,
	[13081] = 80,
	[13082] = 80,
	[13083] = 80,
	[13084] = 80,
	[13085] = 80,
	[13086] = 78,
	[13091] = 80,
	[13092] = 80,
	[13093] = 80,
	[13094] = 71,
	[13095] = 71,
	[13104] = 78,
	[13105] = 78,
	[13106] = 80,
	[13110] = 78,
	[13117] = 80,
	[13118] = 78,
	[13119] = 80,
	[13120] = 80,
	[13121] = 80,
	[13122] = 78,
	[13124] = 80,
	[13125] = 79,
	[13126] = 80,
	[13127] = 80,
	[13128] = 80,
	[13129] = 74,
	[13130] = 79,
	[13131] = 80,
	[13132] = 80,
	[13133] = 80,
	[13134] = 80,
	[13135] = 79,
	[13136] = 80,
	[13137] = 80,
	[13138] = 80,
	[13139] = 79,
	[13140] = 80,
	[13141] = 79,
	[13142] = 80,
	[13143] = 80,
	[13144] = 80,
	[13145] = 80,
	[13146] = 80,
	[13147] = 80,
	[13149] = 80,
	[13151] = 80,
	[13152] = 80,
	[13153] = 80,
	[13154] = 80,
	[13155] = 80,
	[13156] = 80,
	[13157] = 79,
	[13160] = 80,
	[13161] = 80,
	[13162] = 80,
	[13163] = 80,
	[13164] = 80,
	[13165] = 55,
	[13166] = 55,
	[13168] = 80,
	[13169] = 80,
	[13170] = 80,
	[13171] = 80,
	[13172] = 80,
	[13174] = 80,
	[13175] = 80,
	[13176] = 80,
	[13177] = 90,
	[13178] = 90,
	[13179] = 90,
	[13180] = 90,
	[13181] = 90,
	[13183] = 90,
	[13184] = 80,
	[13185] = 90,
	[13186] = 90,
	[13187] = 76,
	[13188] = 55,
	[13189] = 55,
	[13191] = 80,
	[13192] = 80,
	[13193] = 80,
	[13194] = 80,
	[13195] = 80,
	[13196] = 80,
	[13197] = 80,
	[13198] = 80,
	[13199] = 80,
	[13200] = 80,
	[13201] = 80,
	[13202] = 80,
	[13206] = 71,
	[13207] = 78,
	[13211] = 80,
	[13212] = 80,
	[13213] = 80,
	[13214] = 80,
	[13215] = 80,
	[13216] = 80,
	[13217] = 80,
	[13218] = 80,
	[13219] = 80,
	[13220] = 80,
	[13221] = 80,
	[13222] = 90,
	[13223] = 90,
	[13224] = 79,
	[13225] = 79,
	[13226] = 78,
	[13227] = 78,
	[13228] = 80,
	[13229] = 80,
	[13230] = 80,
	[13231] = 80,
	[13232] = 80,
	[13233] = 80,
	[13234] = 80,
	[13235] = 80,
	[13236] = 80,
	[13237] = 80,
	[13238] = 80,
	[13239] = 80,
	[13258] = 80,
	[13259] = 80,
	[13260] = 80,
	[13261] = 80,
	[13262] = 80,
	[13263] = 80,
	[13264] = 80,
	[13271] = 80,
	[13273] = 80,
	[13274] = 80,
	[13275] = 80,
	[13276] = 80,
	[13277] = 80,
	[13278] = 80,
	[13279] = 80,
	[13280] = 80,
	[13281] = 80,
	[13282] = 80,
	[13283] = 80,
	[13284] = 80,
	[13285] = 80,
	[13286] = 80,
	[13287] = 80,
	[13288] = 80,
	[13289] = 80,
	[13290] = 80,
	[13291] = 80,
	[13292] = 80,
	[13293] = 80,
	[13294] = 80,
	[13295] = 80,
	[13296] = 80,
	[13297] = 80,
	[13298] = 80,
	[13300] = 80,
	[13301] = 80,
	[13302] = 80,
	[13304] = 80,
	[13305] = 80,
	[13306] = 80,
	[13307] = 80,
	[13308] = 80,
	[13309] = 80,
	[13310] = 80,
	[13311] = 45,
	[13312] = 80,
	[13313] = 80,
	[13314] = 80,
	[13315] = 80,
	[13316] = 80,
	[13318] = 80,
	[13319] = 80,
	[13320] = 80,
	[13321] = 80,
	[13322] = 80,
	[13323] = 80,
	[13324] = 80,
	[13325] = 80,
	[13326] = 80,
	[13327] = 80,
	[13328] = 80,
	[13329] = 80,
	[13330] = 80,
	[13331] = 80,
	[13332] = 80,
	[13333] = 80,
	[13334] = 80,
	[13335] = 80,
	[13336] = 80,
	[13337] = 80,
	[13338] = 80,
	[13339] = 80,
	[13340] = 80,
	[13341] = 80,
	[13342] = 80,
	[13343] = 80,
	[13344] = 80,
	[13345] = 80,
	[13346] = 80,
	[13348] = 80,
	[13349] = 80,
	[13350] = 80,
	[13351] = 80,
	[13352] = 80,
	[13353] = 80,
	[13354] = 80,
	[13355] = 80,
	[13356] = 80,
	[13357] = 80,
	[13358] = 80,
	[13359] = 80,
	[13360] = 80,
	[13361] = 80,
	[13362] = 80,
	[13363] = 80,
	[13364] = 80,
	[13365] = 80,
	[13366] = 80,
	[13367] = 80,
	[13368] = 80,
	[13372] = 80,
	[13374] = 80,
	[13375] = 80,
	[13381] = 80,
	[13384] = 80,
	[13385] = 80,
	[13386] = 80,
	[13387] = 80,
	[13388] = 80,
	[13389] = 80,
	[13390] = 80,
	[13391] = 80,
	[13392] = 80,
	[13393] = 80,
	[13394] = 80,
	[13395] = 80,
	[13396] = 80,
	[13397] = 80,
	[13398] = 80,
	[13399] = 80,
	[13400] = 80,
	[13401] = 80,
	[13402] = 80,
	[13403] = 80,
	[13408] = 60,
	[13409] = 60,
	[13410] = 60,
	[13411] = 60,
	[13412] = 80,
	[13413] = 80,
	[13414] = 80,
	[13415] = 80,
	[13416] = 80,
	[13417] = 80,
	[13418] = 80,
	[13419] = 80,
	[13420] = 77,
	[13421] = 77,
	[13422] = 79,
	[13423] = 80,
	[13424] = 80,
	[13425] = 80,
	[13426] = 80,
	[13429] = 70,
	[13430] = 70,
	[13431] = 70,
	[13432] = 70,
	[13481] = 80,
	[13482] = 80,
	[13504] = 13,
	[13505] = 13,
	[13506] = 13,
	[13507] = 13,
	[13508] = 13,
	[13509] = 13,
	[13510] = 13,
	[13511] = 13,
	[13512] = 14,
	[13513] = 14,
	[13514] = 14,
	[13515] = 14,
	[13518] = 10,
	[13519] = 13,
	[13520] = 10,
	[13521] = 10,
	[13522] = 10,
	[13523] = 13,
	[13525] = 19,
	[13526] = 19,
	[13527] = 11,
	[13528] = 11,
	[13529] = 11,
	[13537] = 11,
	[13538] = 90,
	[13539] = 90,
	[13542] = 15,
	[13543] = 15,
	[13544] = 19,
	[13545] = 19,
	[13546] = 19,
	[13547] = 15,
	[13549] = 77,
	[13554] = 11,
	[13556] = 77,
	[13557] = 11,
	[13558] = 16,
	[13559] = 80,
	[13560] = 13,
	[13561] = 11,
	[13562] = 11,
	[13563] = 11,
	[13564] = 11,
	[13565] = 12,
	[13566] = 12,
	[13567] = 12,
	[13568] = 12,
	[13569] = 12,
	[13570] = 15,
	[13571] = 80,
	[13572] = 19,
	[13573] = 15,
	[13575] = 15,
	[13576] = 15,
	[13577] = 16,
	[13578] = 17,
	[13579] = 15,
	[13580] = 17,
	[13581] = 15,
	[13582] = 15,
	[13583] = 16,
	[13584] = 16,
	[13585] = 17,
	[13586] = 17,
	[13587] = 17,
	[13588] = 17,
	[13589] = 13,
	[13590] = 14,
	[13591] = 15,
	[13592] = 80,
	[13593] = 80,
	[13594] = 21,
	[13595] = 21,
	[13596] = 13,
	[13597] = 12,
	[13598] = 12,
	[13599] = 12,
	[13600] = 80,
	[13601] = 15,
	[13602] = 21,
	[13603] = 80,
	[13604] = 80,
	[13605] = 15,
	[13606] = 80,
	[13607] = 80,
	[13609] = 80,
	[13610] = 80,
	[13611] = 80,
	[13612] = 21,
	[13613] = 21,
	[13614] = 80,
	[13615] = 21,
	[13616] = 80,
	[13617] = 21,
	[13618] = 21,
	[13619] = 21,
	[13620] = 21,
	[13621] = 21,
	[13622] = 80,
	[13623] = 21,
	[13624] = 21,
	[13625] = 80,
	[13626] = 21,
	[13627] = 80,
	[13628] = 21,
	[13629] = 80,
	[13630] = 21,
	[13631] = 80,
	[13632] = 21,
	[13633] = 80,
	[13634] = 80,
	[13635] = 11,
	[13636] = 13,
	[13638] = 12,
	[13639] = 16,
	[13640] = 21,
	[13641] = 80,
	[13642] = 21,
	[13643] = 80,
	[13644] = 22,
	[13645] = 23,
	[13646] = 23,
	[13647] = 16,
	[13648] = 12,
	[13650] = 16,
	[13651] = 21,
	[13652] = 15,
	[13653] = 21,
	[13654] = 80,
	[13655] = 16,
	[13656] = 16,
	[13657] = 16,
	[13658] = 16,
	[13659] = 17,
	[13660] = 16,
	[13661] = 18,
	[13662] = 50,
	[13663] = 80,
	[13664] = 80,
	[13665] = 80,
	[13666] = 80,
	[13667] = 80,
	[13668] = 80,
	[13669] = 80,
	[13670] = 80,
	[13671] = 80,
	[13672] = 80,
	[13673] = 80,
	[13674] = 80,
	[13675] = 80,
	[13676] = 80,
	[13677] = 80,
	[13678] = 80,
	[13679] = 80,
	[13680] = 80,
	[13681] = 80,
	[13682] = 80,
	[13683] = 21,
	[13684] = 80,
	[13685] = 80,
	[13688] = 80,
	[13689] = 80,
	[13690] = 80,
	[13691] = 80,
	[13693] = 80,
	[13694] = 80,
	[13695] = 80,
	[13696] = 80,
	[13697] = 80,
	[13698] = 21,
	[13699] = 80,
	[13702] = 80,
	[13703] = 80,
	[13704] = 80,
	[13705] = 80,
	[13706] = 80,
	[13707] = 80,
	[13708] = 80,
	[13709] = 80,
	[13710] = 80,
	[13711] = 80,
	[13712] = 21,
	[13713] = 80,
	[13714] = 80,
	[13715] = 80,
	[13716] = 80,
	[13717] = 80,
	[13718] = 80,
	[13719] = 80,
	[13720] = 80,
	[13721] = 80,
	[13722] = 80,
	[13723] = 80,
	[13724] = 80,
	[13725] = 80,
	[13726] = 80,
	[13727] = 80,
	[13728] = 80,
	[13729] = 80,
	[13730] = 21,
	[13731] = 80,
	[13732] = 80,
	[13733] = 80,
	[13734] = 80,
	[13735] = 80,
	[13736] = 80,
	[13737] = 80,
	[13738] = 80,
	[13739] = 80,
	[13740] = 80,
	[13741] = 80,
	[13742] = 80,
	[13743] = 80,
	[13744] = 80,
	[13745] = 80,
	[13746] = 80,
	[13747] = 80,
	[13748] = 80,
	[13749] = 80,
	[13750] = 80,
	[13751] = 22,
	[13752] = 80,
	[13753] = 80,
	[13754] = 80,
	[13755] = 80,
	[13756] = 80,
	[13757] = 80,
	[13758] = 80,
	[13759] = 80,
	[13760] = 80,
	[13761] = 80,
	[13762] = 80,
	[13763] = 80,
	[13764] = 80,
	[13765] = 80,
	[13766] = 21,
	[13767] = 80,
	[13768] = 80,
	[13769] = 80,
	[13770] = 80,
	[13771] = 80,
	[13772] = 80,
	[13773] = 80,
	[13774] = 80,
	[13775] = 80,
	[13776] = 80,
	[13777] = 80,
	[13778] = 80,
	[13779] = 80,
	[13780] = 80,
	[13781] = 80,
	[13782] = 80,
	[13783] = 80,
	[13784] = 80,
	[13785] = 80,
	[13786] = 80,
	[13787] = 80,
	[13788] = 80,
	[13789] = 80,
	[13790] = 80,
	[13791] = 80,
	[13792] = 21,
	[13793] = 80,
	[13794] = 80,
	[13795] = 80,
	[13796] = 21,
	[13797] = 22,
	[13798] = 22,
	[13799] = 65,
	[13800] = 65,
	[13801] = 21,
	[13803] = 22,
	[13805] = 22,
	[13806] = 22,
	[13808] = 22,
	[13809] = 80,
	[13810] = 80,
	[13811] = 80,
	[13812] = 80,
	[13813] = 80,
	[13814] = 80,
	[13815] = 22,
	[13816] = 80,
	[13817] = 80,
	[13818] = 80,
	[13819] = 80,
	[13821] = 80,
	[13822] = 80,
	[13823] = 80,
	[13824] = 80,
	[13827] = 77,
	[13828] = 80,
	[13829] = 80,
	[13831] = 11,
	[13835] = 80,
	[13837] = 80,
	[13838] = 80,
	[13839] = 80,
	[13841] = 22,
	[13842] = 23,
	[13843] = 80,
	[13844] = 14,
	[13845] = 80,
	[13846] = 80,
	[13847] = 80,
	[13848] = 22,
	[13849] = 23,
	[13850] = 53,
	[13851] = 80,
	[13852] = 80,
	[13853] = 23,
	[13854] = 80,
	[13855] = 80,
	[13856] = 80,
	[13857] = 80,
	[13858] = 80,
	[13859] = 80,
	[13860] = 80,
	[13861] = 80,
	[13862] = 80,
	[13863] = 80,
	[13864] = 80,
	[13865] = 22,
	[13866] = 20,
	[13867] = 23,
	[13868] = 23,
	[13869] = 21,
	[13870] = 22,
	[13871] = 22,
	[13872] = 23,
	[13873] = 22,
	[13874] = 23,
	[13875] = 22,
	[13876] = 24,
	[13877] = 23,
	[13878] = 11,
	[13879] = 23,
	[13880] = 23,
	[13881] = 18,
	[13882] = 18,
	[13883] = 22,
	[13884] = 23,
	[13885] = 19,
	[13886] = 24,
	[13887] = 53,
	[13888] = 24,
	[13889] = 53,
	[13890] = 22,
	[13891] = 18,
	[13892] = 19,
	[13893] = 19,
	[13895] = 19,
	[13896] = 19,
	[13897] = 19,
	[13898] = 20,
	[13899] = 20,
	[13900] = 20,
	[13901] = 22,
	[13902] = 18,
	[13903] = 53,
	[13904] = 53,
	[13905] = 53,
	[13906] = 53,
	[13907] = 18,
	[13909] = 18,
	[13910] = 18,
	[13911] = 18,
	[13912] = 18,
	[13913] = 25,
	[13918] = 18,
	[13919] = 23,
	[13920] = 22,
	[13921] = 23,
	[13922] = 23,
	[13923] = 22,
	[13924] = 23,
	[13925] = 18,
	[13928] = 23,
	[13935] = 23,
	[13936] = 23,
	[13940] = 17,
	[13942] = 23,
	[13943] = 23,
	[13944] = 23,
	[13945] = 7,
	[13946] = 7,
	[13947] = 23,
	[13948] = 19,
	[13949] = 12,
	[13953] = 19,
	[13958] = 23,
	[13961] = 12,
	[13962] = 24,
	[13963] = 12,
	[13964] = 25,
	[13965] = 25,
	[13967] = 25,
	[13968] = 12,
	[13969] = 12,
	[13970] = 12,
	[13971] = 12,
	[13973] = 12,
	[13974] = 23,
	[13975] = 13,
	[13976] = 25,
	[13977] = 24,
	[13979] = 25,
	[13980] = 25,
	[13981] = 25,
	[13982] = 26,
	[13983] = 25,
	[13985] = 25,
	[13987] = 25,
	[13988] = 13,
	[13989] = 26,
	[13991] = 15,
	[13992] = 13,
	[13995] = 14,
	[13998] = 14,
	[13999] = 14,
	[14001] = 6,
	[14003] = 16,
	[14004] = 16,
	[14005] = 10,
	[14006] = 16,
	[14007] = 3,
	[14008] = 3,
	[14009] = 3,
	[14010] = 3,
	[14011] = 3,
	[14012] = 3,
	[14013] = 3,
	[14014] = 6,
	[14016] = 80,
	[14017] = 80,
	[14018] = 23,
	[14019] = 6,
	[14021] = 6,
	[14031] = 6,
	[14034] = 16,
	[14038] = 16,
	[14039] = 11,
	[14042] = 16,
	[14045] = 16,
	[14046] = 16,
	[14049] = 16,
	[14050] = 16,
	[14052] = 16,
	[14056] = 16,
	[14057] = 16,
	[14063] = 17,
	[14066] = 15,
	[14067] = 15,
	[14068] = 16,
	[14069] = 1,
	[14070] = 3,
	[14071] = 3,
	[14072] = 15,
	[14073] = 18,
	[14074] = 80,
	[14075] = 1,
	[14076] = 80,
	[14077] = 80,
	[14078] = 1,
	[14079] = 20,
	[14080] = 80,
	[14081] = 20,
	[14082] = 20,
	[14083] = 20,
	[14084] = 20,
	[14085] = 20,
	[14086] = 20,
	[14087] = 20,
	[14088] = 20,
	[14089] = 20,
	[14090] = 80,
	[14091] = 2,
	[14092] = 80,
	[14093] = 2,
	[14094] = 2,
	[14095] = 80,
	[14096] = 80,
	[14098] = 2,
	[14099] = 3,
	[14101] = 80,
	[14102] = 80,
	[14104] = 80,
	[14105] = 80,
	[14107] = 80,
	[14108] = 80,
	[14109] = 3,
	[14110] = 3,
	[14112] = 80,
	[14113] = 3,
	[14115] = 4,
	[14116] = 4,
	[14117] = 10,
	[14118] = 10,
	[14120] = 4,
	[14121] = 4,
	[14122] = 4,
	[14123] = 4,
	[14124] = 4,
	[14125] = 5,
	[14126] = 5,
	[14127] = 10,
	[14128] = 10,
	[14129] = 11,
	[14130] = 17,
	[14131] = 17,
	[14132] = 17,
	[14134] = 11,
	[14135] = 11,
	[14136] = 80,
	[14138] = 1,
	[14140] = 80,
	[14141] = 80,
	[14142] = 80,
	[14143] = 80,
	[14144] = 80,
	[14145] = 80,
	[14146] = 11,
	[14152] = 80,
	[14153] = 3,
	[14154] = 4,
	[14155] = 11,
	[14157] = 4,
	[14159] = 4,
	[14161] = 11,
	[14162] = 11,
	[14165] = 11,
	[14184] = 30,
	[14188] = 30,
	[14189] = 30,
	[14190] = 11,
	[14191] = 30,
	[14192] = 11,
	[14193] = 30,
	[14194] = 11,
	[14195] = 31,
	[14196] = 31,
	[14197] = 11,
	[14198] = 31,
	[14200] = 70,
	[14201] = 12,
	[14202] = 12,
	[14203] = 80,
	[14204] = 4,
	[14209] = 12,
	[14212] = 5,
	[14213] = 31,
	[14214] = 4,
	[14215] = 12,
	[14216] = 12,
	[14217] = 31,
	[14218] = 5,
	[14219] = 31,
	[14220] = 5,
	[14221] = 5,
	[14222] = 5,
	[14223] = 30,
	[14225] = 31,
	[14226] = 18,
	[14227] = 31,
	[14230] = 18,
	[14231] = 15,
	[14232] = 31,
	[14233] = 6,
	[14234] = 6,
	[14235] = 6,
	[14236] = 6,
	[14237] = 7,
	[14238] = 7,
	[14239] = 6,
	[14240] = 7,
	[14241] = 7,
	[14242] = 7,
	[14243] = 7,
	[14244] = 7,
	[14245] = 7,
	[14246] = 31,
	[14247] = 31,
	[14248] = 6,
	[14249] = 18,
	[14250] = 18,
	[14251] = 31,
	[14252] = 31,
	[14253] = 31,
	[14254] = 31,
	[14255] = 31,
	[14256] = 32,
	[14257] = 32,
	[14258] = 12,
	[14260] = 32,
	[14261] = 19,
	[14262] = 13,
	[14263] = 18,
	[14264] = 32,
	[14265] = 2,
	[14266] = 3,
	[14267] = 13,
	[14268] = 32,
	[14269] = 2,
	[14270] = 13,
	[14271] = 13,
	[14272] = 2,
	[14273] = 2,
	[14274] = 2,
	[14275] = 2,
	[14276] = 2,
	[14277] = 2,
	[14278] = 2,
	[14279] = 2,
	[14280] = 2,
	[14281] = 2,
	[14282] = 32,
	[14283] = 2,
	[14284] = 32,
	[14285] = 3,
	[14286] = 3,
	[14287] = 3,
	[14288] = 3,
	[14289] = 3,
	[14290] = 3,
	[14291] = 3,
	[14292] = 32,
	[14293] = 4,
	[14294] = 4,
	[14295] = 13,
	[14296] = 18,
	[14297] = 19,
	[14299] = 18,
	[14300] = 18,
	[14301] = 32,
	[14302] = 32,
	[14303] = 7,
	[14304] = 33,
	[14305] = 32,
	[14306] = 32,
	[14307] = 32,
	[14308] = 13,
	[14309] = 32,
	[14310] = 13,
	[14311] = 32,
	[14312] = 32,
	[14313] = 5,
	[14314] = 32,
	[14316] = 32,
	[14318] = 33,
	[14319] = 5,
	[14320] = 5,
	[14321] = 5,
	[14322] = 13,
	[14323] = 17,
	[14324] = 17,
	[14325] = 33,
	[14326] = 7,
	[14327] = 33,
	[14328] = 34,
	[14329] = 34,
	[14330] = 35,
	[14332] = 35,
	[14333] = 35,
	[14334] = 35,
	[14335] = 35,
	[14336] = 5,
	[14337] = 34,
	[14338] = 32,
	[14339] = 33,
	[14340] = 18,
	[14341] = 32,
	[14342] = 35,
	[14343] = 34,
	[14344] = 35,
	[14345] = 17,
	[14346] = 34,
	[14347] = 5,
	[14348] = 5,
	[14354] = 31,
	[14357] = 31,
	[14358] = 31,
	[14359] = 31,
	[14360] = 30,
	[14361] = 30,
	[14362] = 31,
	[14363] = 31,
	[14364] = 31,
	[14365] = 31,
	[14366] = 5,
	[14367] = 6,
	[14368] = 6,
	[14369] = 6,
	[14370] = 13,
	[14371] = 13,
	[14372] = 34,
	[14373] = 35,
	[14374] = 35,
	[14375] = 5,
	[14376] = 35,
	[14377] = 13,
	[14378] = 34,
	[14379] = 34,
	[14380] = 34,
	[14381] = 34,
	[14382] = 6,
	[14383] = 14,
	[14384] = 30,
	[14385] = 14,
	[14386] = 6,
	[14387] = 30,
	[14388] = 14,
	[14389] = 19,
	[14390] = 19,
	[14391] = 19,
	[14392] = 19,
	[14393] = 35,
	[14394] = 35,
	[14395] = 6,
	[14396] = 6,
	[14397] = 7,
	[14398] = 7,
	[14399] = 7,
	[14400] = 7,
	[14401] = 7,
	[14402] = 7,
	[14403] = 7,
	[14404] = 7,
	[14405] = 7,
	[14406] = 7,
	[14407] = 17,
	[14408] = 14,
	[14410] = 35,
	[14412] = 7,
	[14413] = 18,
	[14416] = 7,
	[14422] = 14,
	[14423] = 12,
	[14424] = 13,
	[14428] = 18,
	[14429] = 18,
	[14430] = 18,
	[14431] = 17,
	[14432] = 17,
	[14433] = 17,
	[14434] = 12,
	[14435] = 17,
	[14436] = 8,
	[14438] = 6,
	[14439] = 10,
	[14442] = 13,
	[14443] = 80,
	[14444] = 80,
	[14445] = 7,
	[14446] = 80,
	[14447] = 80,
	[14448] = 80,
	[14449] = 1,
	[14452] = 2,
	[14455] = 3,
	[14456] = 3,
	[14457] = 80,
	[14458] = 2,
	[14459] = 4,
	[14460] = 5,
	[14461] = 4,
	[14462] = 20,
	[14463] = 7,
	[14464] = 20,
	[14465] = 7,
	[14466] = 7,
	[14467] = 7,
	[14468] = 13,
	[14469] = 13,
	[14470] = 13,
	[14471] = 13,
	[14472] = 13,
	[14473] = 6,
	[14474] = 6,
	[14475] = 20,
	[14476] = 20,
	[14477] = 20,
	[14478] = 16,
	[14479] = 16,
	[14480] = 17,
	[14481] = 80,
	[14482] = 80,
	[14483] = 80,
	[14484] = 17,
	[14485] = 17,
	[14486] = 17,
	[14487] = 17,
	[14488] = 80,
	[14491] = 7,
	[20438] = 80,
	[20439] = 80,
	[20440] = 5,
	[20441] = 7,
	[23733] = 5,
	[24215] = 5,
	[24428] = 80,
	[24429] = 80,
	[24430] = 20,
	[24432] = 81,
	[24433] = 20,
	[24434] = 20,
	[24435] = 16,
	[24436] = 16,
	[24437] = 16,
	[24438] = 8,
	[24439] = 20,
	[24440] = 6,
	[24441] = 7,
	[24442] = 80,
	[24448] = 17,
	[24449] = 17,
	[24451] = 80,
	[24452] = 13,
	[24453] = 13,
	[24454] = 80,
	[24455] = 16,
	[24456] = 8,
	[24457] = 6,
	[24458] = 15,
	[24459] = 8,
	[24461] = 80,
	[24462] = 2,
	[24463] = 20,
	[24467] = 19,
	[24468] = 8,
	[24469] = 1,
	[24470] = 2,
	[24471] = 2,
	[24472] = 8,
	[24473] = 2,
	[24474] = 2,
	[24475] = 2,
	[24476] = 80,
	[24477] = 2,
	[24478] = 18,
	[24479] = 18,
	[24480] = 80,
	[24483] = 8,
	[24484] = 8,
	[24486] = 2,
	[24487] = 3,
	[24488] = 3,
	[24489] = 3,
	[24490] = 5,
	[24491] = 5,
	[24492] = 5,
	[24493] = 5,
	[24494] = 3,
	[24495] = 8,
	[24496] = 3,
	[24497] = 20,
	[24498] = 80,
	[24499] = 80,
	[24500] = 80,
	[24501] = 9,
	[24502] = 3,
	[24503] = 3,
	[24504] = 30,
	[24505] = 30,
	[24506] = 80,
	[24507] = 80,
	[24510] = 80,
	[24511] = 80,
	[24512] = 30,
	[24513] = 30,
	[24514] = 30,
	[24515] = 31,
	[24517] = 31,
	[24518] = 31,
	[24519] = 31,
	[24520] = 3,
	[24522] = 80,
	[24523] = 10,
	[24524] = 10,
	[24525] = 31,
	[24526] = 3,
	[24527] = 3,
	[24528] = 3,
	[24529] = 32,
	[24530] = 3,
	[24531] = 3,
	[24532] = 3,
	[24533] = 3,
	[24534] = 32,
	[24535] = 80,
	[24539] = 31,
	[24540] = 10,
	[24542] = 31,
	[24543] = 32,
	[24545] = 80,
	[24546] = 32,
	[24547] = 80,
	[24548] = 80,
	[24549] = 80,
	[24550] = 10,
	[24551] = 32,
	[24552] = 33,
	[24553] = 80,
	[24554] = 80,
	[24555] = 80,
	[24556] = 80,
	[24557] = 80,
	[24558] = 80,
	[24559] = 80,
	[24560] = 80,
	[24561] = 80,
	[24562] = 80,
	[24563] = 80,
	[24564] = 80,
	[24565] = 31,
	[24566] = 31,
	[24567] = 3,
	[24568] = 33,
	[24569] = 32,
	[24570] = 31,
	[24571] = 31,
	[24572] = 33,
	[24573] = 33,
	[24574] = 32,
	[24575] = 10,
	[24577] = 33,
	[24578] = 8,
	[24579] = 80,
	[24580] = 80,
	[24581] = 80,
	[24582] = 80,
	[24583] = 80,
	[24584] = 80,
	[24585] = 80,
	[24586] = 80,
	[24587] = 80,
	[24588] = 80,
	[24589] = 80,
	[24590] = 80,
	[24591] = 33,
	[24592] = 10,
	[24593] = 9,
	[24594] = 80,
	[24595] = 80,
	[24596] = 80,
	[24598] = 80,
	[24601] = 32,
	[24602] = 11,
	[24603] = 34,
	[24604] = 34,
	[24606] = 34,
	[24607] = 2,
	[24608] = 34,
	[24616] = 9,
	[24617] = 9,
	[24618] = 34,
	[24619] = 34,
	[24620] = 34,
	[24621] = 34,
	[24622] = 3,
	[24623] = 3,
	[24624] = 3,
	[24625] = 3,
	[24626] = 3,
	[24627] = 9,
	[24628] = 11,
	[24631] = 34,
	[24632] = 34,
	[24633] = 35,
	[24634] = 34,
	[24637] = 34,
	[24639] = 2,
	[24640] = 3,
	[24641] = 3,
	[24642] = 3,
	[24643] = 3,
	[24644] = 1,
	[24646] = 9,
	[24653] = 35,
	[24654] = 34,
	[24667] = 34,
	[24671] = 7,
	[24672] = 9,
	[24673] = 9,
	[24674] = 11,
	[24675] = 10,
	[24676] = 11,
	[24677] = 10,
	[24678] = 11,
	[24679] = 11,
	[24680] = 12,
	[24681] = 12,
	[24682] = 80,
	[24683] = 80,
	[24684] = 35,
	[24685] = 35,
	[24686] = 51,
	[24687] = 51,
	[24688] = 53,
	[24689] = 51,
	[24690] = 53,
	[24691] = 52,
	[24692] = 53,
	[24693] = 52,
	[24694] = 55,
	[24695] = 55,
	[24697] = 52,
	[24698] = 53,
	[24699] = 54,
	[24700] = 52,
	[24701] = 53,
	[24702] = 52,
	[24703] = 54,
	[24704] = 54,
	[24705] = 54,
	[24706] = 54,
	[24707] = 55,
	[24708] = 54,
	[24709] = 55,
	[24710] = 80,
	[24711] = 80,
	[24712] = 80,
	[24713] = 80,
	[24714] = 52,
	[24715] = 52,
	[24717] = 52,
	[24718] = 53,
	[24719] = 51,
	[24720] = 52,
	[24721] = 53,
	[24722] = 53,
	[24723] = 55,
	[24724] = 55,
	[24725] = 55,
	[24726] = 55,
	[24727] = 55,
	[24728] = 55,
	[24729] = 55,
	[24730] = 53,
	[24731] = 51,
	[24732] = 52,
	[24733] = 53,
	[24734] = 52,
	[24735] = 52,
	[24736] = 53,
	[24737] = 52,
	[24740] = 52,
	[24741] = 8,
	[24742] = 52,
	[24743] = 80,
	[24744] = 8,
	[24745] = 80,
	[24747] = 35,
	[24748] = 80,
	[24749] = 80,
	[24750] = 2,
	[24751] = 2,
	[24752] = 3,
	[24753] = 3,
	[24754] = 3,
	[24755] = 3,
	[24756] = 80,
	[24757] = 80,
	[24758] = 2,
	[24759] = 2,
	[24760] = 3,
	[24761] = 3,
	[24762] = 3,
	[24763] = 3,
	[24764] = 2,
	[24765] = 2,
	[24766] = 3,
	[24767] = 3,
	[24768] = 3,
	[24769] = 3,
	[24770] = 2,
	[24771] = 2,
	[24772] = 3,
	[24773] = 3,
	[24774] = 3,
	[24775] = 3,
	[24776] = 2,
	[24777] = 2,
	[24778] = 3,
	[24779] = 3,
	[24780] = 3,
	[24781] = 3,
	[24782] = 2,
	[24783] = 2,
	[24784] = 3,
	[24785] = 3,
	[24786] = 3,
	[24787] = 3,
	[24788] = 80,
	[24789] = 80,
	[24790] = 80,
	[24791] = 80,
	[24794] = 53,
	[24795] = 80,
	[24796] = 80,
	[24798] = 80,
	[24799] = 80,
	[24800] = 80,
	[24801] = 80,
	[24802] = 80,
	[24807] = 32,
	[24812] = 4,
	[24813] = 4,
	[24814] = 5,
	[24815] = 80,
	[24816] = 8,
	[24817] = 8,
	[24819] = 80,
	[24820] = 80,
	[24821] = 80,
	[24822] = 80,
	[24823] = 80,
	[24824] = 34,
	[24825] = 80,
	[24826] = 80,
	[24827] = 80,
	[24828] = 80,
	[24829] = 80,
	[24830] = 80,
	[24831] = 80,
	[24832] = 80,
	[24833] = 80,
	[24834] = 80,
	[24835] = 80,
	[24836] = 80,
	[24837] = 80,
	[24838] = 80,
	[24839] = 80,
	[24840] = 80,
	[24841] = 80,
	[24842] = 80,
	[24843] = 80,
	[24844] = 80,
	[24845] = 80,
	[24846] = 80,
	[24847] = 80,
	[24852] = 2,
	[24854] = 51,
	[24855] = 52,
	[24856] = 8,
	[24858] = 8,
	[24859] = 8,
	[24861] = 5,
	[24862] = 30,
	[24863] = 30,
	[24864] = 8,
	[24865] = 51,
	[24866] = 51,
	[24868] = 8,
	[24881] = 15,
	[24882] = 25,
	[24883] = 34,
	[24884] = 45,
	[24885] = 55,
	[24886] = 60,
	[24887] = 64,
	[24888] = 70,
	[24889] = 15,
	[24890] = 25,
	[24891] = 34,
	[24892] = 45,
	[24893] = 55,
	[24894] = 60,
	[24895] = 64,
	[24896] = 70,
	[24897] = 8,
	[24901] = 8,
	[24902] = 11,
	[24903] = 11,
	[24904] = 11,
	[24905] = 47,
	[24906] = 45,
	[24907] = 45,
	[24910] = 45,
	[24911] = 52,
	[24912] = 80,
	[24913] = 55,
	[24914] = 80,
	[24915] = 80,
	[24916] = 80,
	[24917] = 80,
	[24918] = 80,
	[24919] = 80,
	[24920] = 11,
	[24921] = 30,
	[24922] = 70,
	[24923] = 70,
	[24924] = 8,
	[24925] = 8,
	[24926] = 52,
	[24927] = 46,
	[24928] = 46,
	[24929] = 8,
	[24930] = 3,
	[24931] = 47,
	[24932] = 47,
	[24933] = 47,
	[24934] = 30,
	[24937] = 8,
	[24938] = 30,
	[24939] = 30,
	[24940] = 8,
	[24941] = 30,
	[24942] = 8,
	[24943] = 30,
	[24944] = 30,
	[24945] = 9,
	[24946] = 8,
	[24947] = 46,
	[24948] = 30,
	[24949] = 46,
	[24950] = 46,
	[24951] = 47,
	[24952] = 8,
	[24953] = 47,
	[24954] = 8,
	[24955] = 48,
	[24956] = 31,
	[24957] = 48,
	[24958] = 9,
	[24959] = 1,
	[24960] = 1,
	[24961] = 3,
	[24962] = 3,
	[24963] = 48,
	[24964] = 3,
	[24965] = 3,
	[24966] = 3,
	[24967] = 3,
	[24968] = 3,
	[24969] = 3,
	[24970] = 4,
	[24971] = 5,
	[24972] = 5,
	[24973] = 4,
	[24974] = 6,
	[24975] = 6,
	[24976] = 6,
	[24977] = 6,
	[24978] = 6,
	[24979] = 6,
	[24980] = 6,
	[24981] = 8,
	[24982] = 7,
	[24983] = 8,
	[24988] = 8,
	[24989] = 8,
	[24990] = 6,
	[24991] = 8,
	[24992] = 7,
	[24993] = 8,
	[24994] = 7,
	[24995] = 8,
	[24996] = 6,
	[24997] = 7,
	[24998] = 9,
	[24999] = 8,
	[25000] = 31,
	[25001] = 48,
	[25002] = 31,
	[25003] = 9,
	[25004] = 8,
	[25005] = 9,
	[25006] = 9,
	[25007] = 9,
	[25008] = 31,
	[25009] = 9,
	[25010] = 10,
	[25011] = 10,
	[25012] = 10,
	[25013] = 10,
	[25014] = 48,
	[25015] = 31,
	[25017] = 49,
	[25018] = 48,
	[25019] = 49,
	[25020] = 49,
	[25021] = 45,
	[25022] = 31,
	[25023] = 9,
	[25024] = 9,
	[25025] = 45,
	[25026] = 45,
	[25027] = 31,
	[25028] = 31,
	[25029] = 9,
	[25030] = 9,
	[25031] = 9,
	[25032] = 46,
	[25034] = 31,
	[25035] = 4,
	[25036] = 31,
	[25037] = 3,
	[25038] = 6,
	[25039] = 7,
	[25041] = 32,
	[25042] = 32,
	[25043] = 32,
	[25044] = 32,
	[25045] = 32,
	[25046] = 10,
	[25048] = 45,
	[25049] = 45,
	[25050] = 45,
	[25051] = 36,
	[25052] = 46,
	[25053] = 46,
	[25054] = 46,
	[25056] = 9,
	[25057] = 32,
	[25058] = 9,
	[25059] = 32,
	[25060] = 48,
	[25061] = 47,
	[25062] = 48,
	[25063] = 48,
	[25064] = 3,
	[25065] = 48,
	[25066] = 9,
	[25067] = 49,
	[25068] = 49,
	[25069] = 49,
	[25070] = 49,
	[25072] = 47,
	[25073] = 5,
	[25074] = 33,
	[25075] = 33,
	[25079] = 33,
	[25080] = 33,
	[25081] = 34,
	[25082] = 34,
	[25084] = 34,
	[25085] = 34,
	[25086] = 34,
	[25087] = 34,
	[25089] = 1,
	[25090] = 6,
	[25091] = 45,
	[25093] = 10,
	[25094] = 49,
	[25095] = 49,
	[25098] = 9,
	[25099] = 9,
	[25100] = 9,
	[25102] = 34,
	[25103] = 46,
	[25104] = 34,
	[25106] = 34,
	[25107] = 49,
	[25108] = 34,
	[25109] = 9,
	[25110] = 9,
	[25111] = 45,
	[25112] = 45,
	[25115] = 45,
	[25118] = 13,
	[25120] = 34,
	[25121] = 46,
	[25122] = 9,
	[25123] = 10,
	[25125] = 9,
	[25126] = 2,
	[25127] = 3,
	[25128] = 5,
	[25129] = 5,
	[25130] = 5,
	[25131] = 4,
	[25132] = 5,
	[25133] = 5,
	[25134] = 4,
	[25135] = 4,
	[25136] = 3,
	[25138] = 3,
	[25139] = 3,
	[25141] = 3,
	[25143] = 3,
	[25145] = 3,
	[25147] = 3,
	[25149] = 3,
	[25151] = 34,
	[25152] = 1,
	[25153] = 34,
	[25163] = 34,
	[25164] = 81,
	[25165] = 6,
	[25166] = 46,
	[25167] = 6,
	[25168] = 6,
	[25169] = 6,
	[25170] = 6,
	[25171] = 6,
	[25172] = 3,
	[25173] = 7,
	[25174] = 34,
	[25175] = 34,
	[25176] = 7,
	[25177] = 7,
	[25178] = 7,
	[25179] = 7,
	[25182] = 35,
	[25183] = 35,
	[25184] = 9,
	[25185] = 35,
	[25186] = 31,
	[25187] = 8,
	[25188] = 8,
	[25189] = 8,
	[25190] = 8,
	[25191] = 30,
	[25192] = 9,
	[25193] = 8,
	[25194] = 8,
	[25195] = 9,
	[25196] = 10,
	[25197] = 30,
	[25200] = 10,
	[25201] = 10,
	[25202] = 11,
	[25203] = 11,
	[25204] = 10,
	[25205] = 10,
	[25206] = 10,
	[25207] = 10,
	[25208] = 36,
	[25209] = 36,
	[25210] = 36,
	[25211] = 21,
	[25213] = 10,
	[25214] = 10,
	[25215] = 81,
	[25216] = 81,
	[25217] = 81,
	[25218] = 81,
	[25219] = 81,
	[25220] = 81,
	[25221] = 81,
	[25222] = 81,
	[25223] = 81,
	[25224] = 81,
	[25227] = 8,
	[25230] = 36,
	[25232] = 10,
	[25233] = 81,
	[25234] = 81,
	[25235] = 22,
	[25236] = 10,
	[25237] = 36,
	[25239] = 80,
	[25240] = 80,
	[25241] = 36,
	[25242] = 80,
	[25243] = 11,
	[25244] = 11,
	[25246] = 80,
	[25247] = 80,
	[25248] = 80,
	[25249] = 80,
	[25250] = 36,
	[25251] = 10,
	[25252] = 37,
	[25255] = 81,
	[25256] = 10,
	[25257] = 10,
	[25258] = 10,
	[25259] = 10,
	[25260] = 10,
	[25261] = 10,
	[25262] = 12,
	[25263] = 12,
	[25264] = 13,
	[25265] = 11,
	[25266] = 11,
	[25267] = 11,
	[25268] = 81,
	[25269] = 81,
	[25270] = 81,
	[25271] = 81,
	[25272] = 81,
	[25273] = 81,
	[25274] = 81,
	[25275] = 11,
	[25276] = 81,
	[25277] = 81,
	[25278] = 81,
	[25279] = 81,
	[25280] = 81,
	[25281] = 81,
	[25284] = 30,
	[25291] = 81,
	[25292] = 35,
	[25294] = 81,
	[25296] = 81,
	[25297] = 81,
	[25298] = 81,
	[25299] = 81,
	[25300] = 81,
	[25301] = 81,
	[25303] = 81,
	[25304] = 37,
	[25305] = 37,
	[25308] = 81,
	[25309] = 81,
	[25310] = 81,
	[25311] = 81,
	[25312] = 81,
	[25314] = 81,
	[25315] = 81,
	[25316] = 81,
	[25317] = 81,
	[25319] = 81,
	[25320] = 81,
	[25321] = 81,
	[25323] = 81,
	[25324] = 81,
	[25325] = 81,
	[25328] = 81,
	[25329] = 37,
	[25330] = 81,
	[25332] = 81,
	[25333] = 37,
	[25334] = 81,
	[25336] = 38,
	[25337] = 38,
	[25338] = 37,
	[25339] = 36,
	[25340] = 36,
	[25341] = 36,
	[25342] = 37,
	[25344] = 37,
	[25345] = 37,
	[25346] = 37,
	[25349] = 40,
	[25350] = 37,
	[25352] = 81,
	[25353] = 81,
	[25354] = 81,
	[25355] = 81,
	[25356] = 40,
	[25357] = 81,
	[25358] = 81,
	[25359] = 81,
	[25360] = 81,
	[25361] = 38,
	[25362] = 38,
	[25363] = 38,
	[25364] = 38,
	[25365] = 38,
	[25366] = 38,
	[25367] = 38,
	[25368] = 37,
	[25369] = 38,
	[25370] = 81,
	[25371] = 81,
	[25372] = 81,
	[25373] = 39,
	[25374] = 39,
	[25375] = 39,
	[25377] = 81,
	[25378] = 40,
	[25379] = 40,
	[25381] = 81,
	[25382] = 81,
	[25383] = 40,
	[25384] = 81,
	[25385] = 81,
	[25386] = 36,
	[25387] = 38,
	[25388] = 81,
	[25389] = 81,
	[25390] = 81,
	[25391] = 37,
	[25392] = 81,
	[25394] = 36,
	[25395] = 20,
	[25396] = 36,
	[25397] = 36,
	[25398] = 36,
	[25399] = 37,
	[25400] = 37,
	[25401] = 37,
	[25402] = 37,
	[25403] = 37,
	[25404] = 81,
	[25405] = 81,
	[25406] = 37,
	[25407] = 37,
	[25408] = 81,
	[25409] = 37,
	[25410] = 37,
	[25411] = 81,
	[25412] = 81,
	[25413] = 81,
	[25419] = 81,
	[25420] = 49,
	[25421] = 49,
	[25422] = 37,
	[25423] = 37,
	[25424] = 81,
	[25426] = 39,
	[25427] = 39,
	[25428] = 81,
	[25429] = 39,
	[25430] = 81,
	[25431] = 39,
	[25432] = 39,
	[25433] = 39,
	[25434] = 39,
	[25436] = 40,
	[25437] = 40,
	[25438] = 40,
	[25439] = 81,
	[25440] = 81,
	[25441] = 81,
	[25442] = 81,
	[25447] = 36,
	[25448] = 36,
	[25449] = 36,
	[25450] = 37,
	[25451] = 37,
	[25452] = 36,
	[25453] = 37,
	[25454] = 37,
	[25456] = 81,
	[25458] = 37,
	[25459] = 81,
	[25460] = 81,
	[25462] = 81,
	[25463] = 37,
	[25464] = 81,
	[25465] = 37,
	[25466] = 37,
	[25467] = 81,
	[25468] = 37,
	[25469] = 37,
	[25471] = 81,
	[25472] = 81,
	[25473] = 2,
	[25475] = 37,
	[25476] = 37,
	[25477] = 81,
	[25478] = 40,
	[25479] = 40,
	[25481] = 40,
	[25482] = 80,
	[25483] = 80,
	[25484] = 80,
	[25485] = 80,
	[25486] = 40,
	[25487] = 40,
	[25488] = 40,
	[25489] = 40,
	[25490] = 81,
	[25491] = 81,
	[25492] = 81,
	[25493] = 81,
	[25494] = 81,
	[25496] = 81,
	[25497] = 81,
	[25498] = 81,
	[25499] = 81,
	[25502] = 81,
	[25503] = 81,
	[25504] = 40,
	[25505] = 40,
	[25507] = 81,
	[25509] = 81,
	[25510] = 81,
	[25513] = 49,
	[25514] = 81,
	[25515] = 40,
	[25516] = 40,
	[25517] = 40,
	[25518] = 40,
	[25519] = 81,
	[25520] = 81,
	[25521] = 46,
	[25522] = 46,
	[25523] = 81,
	[25524] = 40,
	[25525] = 81,
	[25526] = 40,
	[25531] = 81,
	[25532] = 40,
	[25533] = 40,
	[25534] = 46,
	[25535] = 81,
	[25536] = 81,
	[25537] = 81,
	[25538] = 81,
	[25539] = 81,
	[25540] = 81,
	[25541] = 46,
	[25542] = 40,
	[25543] = 40,
	[25544] = 81,
	[25545] = 81,
	[25546] = 81,
	[25547] = 81,
	[25548] = 81,
	[25549] = 81,
	[25550] = 82,
	[25551] = 82,
	[25552] = 82,
	[25553] = 82,
	[25554] = 81,
	[25555] = 82,
	[25556] = 47,
	[25558] = 81,
	[25559] = 49,
	[25560] = 81,
	[25561] = 40,
	[25562] = 40,
	[25564] = 81,
	[25565] = 49,
	[25566] = 49,
	[25574] = 81,
	[25575] = 81,
	[25576] = 81,
	[25577] = 81,
	[25578] = 81,
	[25579] = 81,
	[25580] = 81,
	[25581] = 81,
	[25582] = 81,
	[25583] = 81,
	[25584] = 81,
	[25585] = 41,
	[25586] = 41,
	[25587] = 81,
	[25588] = 41,
	[25589] = 41,
	[25590] = 41,
	[25591] = 49,
	[25592] = 81,
	[25593] = 81,
	[25594] = 81,
	[25595] = 81,
	[25596] = 41,
	[25597] = 81,
	[25598] = 81,
	[25599] = 81,
	[25600] = 81,
	[25601] = 81,
	[25602] = 81,
	[25607] = 25,
	[25608] = 81,
	[25609] = 41,
	[25610] = 41,
	[25611] = 81,
	[25612] = 81,
	[25613] = 25,
	[25614] = 25,
	[25615] = 25,
	[25616] = 26,
	[25617] = 81,
	[25618] = 81,
	[25619] = 81,
	[25620] = 81,
	[25621] = 26,
	[25622] = 26,
	[25623] = 81,
	[25624] = 81,
	[25626] = 81,
	[25627] = 42,
	[25628] = 42,
	[25629] = 81,
	[25630] = 81,
	[25636] = 81,
	[25637] = 81,
	[25638] = 81,
	[25640] = 26,
	[25641] = 37,
	[25642] = 26,
	[25643] = 37,
	[25644] = 82,
	[25645] = 37,
	[25646] = 26,
	[25647] = 26,
	[25648] = 10,
	[25649] = 26,
	[25650] = 26,
	[25651] = 81,
	[25652] = 26,
	[25653] = 81,
	[25654] = 36,
	[25655] = 81,
	[25656] = 81,
	[25657] = 81,
	[25658] = 81,
	[25659] = 81,
	[25660] = 41,
	[25661] = 42,
	[25662] = 26,
	[25663] = 81,
	[25664] = 81,
	[25665] = 81,
	[25666] = 81,
	[25667] = 6,
	[25668] = 6,
	[25669] = 27,
	[25670] = 81,
	[25671] = 28,
	[25672] = 42,
	[25673] = 27,
	[25674] = 55,
	[25675] = 55,
	[25676] = 55,
	[25677] = 55,
	[25678] = 55,
	[25679] = 55,
	[25680] = 55,
	[25681] = 55,
	[25682] = 55,
	[25683] = 55,
	[25684] = 55,
	[25685] = 55,
	[25686] = 55,
	[25687] = 55,
	[25688] = 55,
	[25689] = 56,
	[25690] = 55,
	[25691] = 56,
	[25692] = 56,
	[25693] = 56,
	[25694] = 56,
	[25695] = 56,
	[25696] = 57,
	[25697] = 56,
	[25698] = 56,
	[25699] = 56,
	[25700] = 56,
	[25701] = 57,
	[25702] = 57,
	[25703] = 57,
	[25704] = 42,
	[25705] = 57,
	[25706] = 57,
	[25707] = 57,
	[25708] = 55,
	[25709] = 55,
	[25710] = 55,
	[25711] = 55,
	[25712] = 55,
	[25713] = 55,
	[25714] = 55,
	[25715] = 55,
	[25716] = 55,
	[25717] = 58,
	[25718] = 58,
	[25719] = 58,
	[25720] = 59,
	[25721] = 20,
	[25722] = 20,
	[25723] = 20,
	[25724] = 6,
	[25725] = 20,
	[25726] = 20,
	[25727] = 20,
	[25728] = 27,
	[25729] = 27,
	[25730] = 27,
	[25731] = 81,
	[25732] = 81,
	[25733] = 21,
	[25734] = 21,
	[25735] = 21,
	[25736] = 20,
	[25737] = 81,
	[25738] = 81,
	[25739] = 27,
	[25740] = 81,
	[25741] = 27,
	[25742] = 81,
	[25743] = 81,
	[25744] = 41,
	[25745] = 41,
	[25746] = 81,
	[25747] = 81,
	[25748] = 81,
	[25749] = 81,
	[25751] = 81,
	[25752] = 81,
	[25753] = 81,
	[25754] = 81,
	[25755] = 81,
	[25756] = 41,
	[25757] = 41,
	[25758] = 81,
	[25760] = 81,
	[25761] = 81,
	[25762] = 42,
	[25763] = 81,
	[25764] = 81,
	[25765] = 28,
	[25766] = 28,
	[25767] = 28,
	[25768] = 28,
	[25769] = 28,
	[25770] = 20,
	[25771] = 55,
	[25772] = 55,
	[25774] = 42,
	[25775] = 42,
	[25776] = 81,
	[25777] = 21,
	[25778] = 41,
	[25779] = 41,
	[25780] = 21,
	[25790] = 41,
	[25791] = 41,
	[25792] = 7,
	[25793] = 28,
	[25794] = 81,
	[25795] = 81,
	[25796] = 41,
	[25797] = 41,
	[25798] = 41,
	[25799] = 41,
	[25800] = 22,
	[25801] = 22,
	[25802] = 22,
	[25803] = 22,
	[25804] = 22,
	[25805] = 22,
	[25806] = 28,
	[25807] = 81,
	[25808] = 28,
	[25809] = 28,
	[25810] = 81,
	[25811] = 28,
	[25812] = 81,
	[25813] = 42,
	[25814] = 42,
	[25815] = 22,
	[25816] = 22,
	[25817] = 22,
	[25818] = 23,
	[25819] = 23,
	[25820] = 22,
	[25821] = 28,
	[25822] = 28,
	[25823] = 28,
	[25824] = 81,
	[25825] = 42,
	[25826] = 42,
	[25830] = 81,
	[25832] = 81,
	[25834] = 29,
	[25835] = 42,
	[25836] = 42,
	[25837] = 28,
	[25838] = 8,
	[25839] = 8,
	[25840] = 8,
	[25841] = 8,
	[25842] = 81,
	[25843] = 81,
	[25844] = 29,
	[25845] = 29,
	[25846] = 29,
	[25847] = 30,
	[25848] = 30,
	[25849] = 23,
	[25850] = 23,
	[25851] = 30,
	[25852] = 30,
	[25853] = 23,
	[25854] = 23,
	[25855] = 23,
	[25856] = 23,
	[25857] = 23,
	[25858] = 81,
	[25859] = 81,
	[25860] = 81,
	[25861] = 81,
	[25862] = 81,
	[25863] = 81,
	[25864] = 23,
	[25865] = 23,
	[25866] = 23,
	[25867] = 23,
	[25868] = 23,
	[25869] = 42,
	[25870] = 42,
	[25871] = 42,
	[25872] = 42,
	[25873] = 43,
	[25874] = 43,
	[25875] = 28,
	[25876] = 28,
	[25877] = 28,
	[25878] = 28,
	[25879] = 28,
	[25880] = 29,
	[25881] = 81,
	[25882] = 8,
	[25883] = 81,
	[25884] = 81,
	[25885] = 81,
	[25886] = 81,
	[25887] = 81,
	[25888] = 81,
	[25889] = 29,
	[25890] = 81,
	[25891] = 29,
	[25892] = 81,
	[25893] = 81,
	[25894] = 81,
	[25895] = 81,
	[25896] = 81,
	[25897] = 81,
	[25898] = 81,
	[25899] = 81,
	[25900] = 81,
	[25901] = 81,
	[25904] = 81,
	[25905] = 8,
	[25906] = 81,
	[25907] = 81,
	[25908] = 81,
	[25909] = 81,
	[25910] = 81,
	[25911] = 81,
	[25912] = 29,
	[25913] = 29,
	[25914] = 29,
	[25915] = 81,
	[25916] = 81,
	[25917] = 81,
	[25918] = 81,
	[25919] = 81,
	[25920] = 81,
	[25921] = 81,
	[25922] = 81,
	[25923] = 81,
	[25924] = 81,
	[25925] = 30,
	[25926] = 25,
	[25927] = 25,
	[25928] = 81,
	[25929] = 81,
	[25930] = 30,
	[25931] = 30,
	[25932] = 9,
	[25933] = 9,
	[25934] = 30,
	[25935] = 30,
	[25936] = 81,
	[25937] = 10,
	[25938] = 30,
	[25939] = 24,
	[25940] = 81,
	[25941] = 81,
	[25942] = 81,
	[25943] = 81,
	[25944] = 81,
	[25945] = 26,
	[25946] = 81,
	[25947] = 81,
	[25948] = 81,
	[25949] = 81,
	[25950] = 82,
	[25951] = 81,
	[25952] = 81,
	[25953] = 81,
	[25954] = 81,
	[25955] = 81,
	[25956] = 81,
	[25957] = 81,
	[25958] = 81,
	[25959] = 81,
	[25960] = 81,
	[25962] = 81,
	[25963] = 81,
	[25964] = 81,
	[25965] = 81,
	[25966] = 81,
	[25967] = 81,
	[25968] = 81,
	[25969] = 81,
	[25970] = 81,
	[25971] = 81,
	[25972] = 81,
	[25973] = 81,
	[25974] = 82,
	[25975] = 82,
	[25976] = 82,
	[25977] = 82,
	[25978] = 10,
	[25979] = 10,
	[25980] = 82,
	[25981] = 82,
	[25982] = 82,
	[25983] = 82,
	[25984] = 82,
	[25985] = 81,
	[25986] = 10,
	[25987] = 82,
	[25988] = 82,
	[25989] = 81,
	[25990] = 81,
	[25991] = 81,
	[25992] = 81,
	[25993] = 81,
	[25994] = 81,
	[25995] = 81,
	[25996] = 81,
	[25997] = 10,
	[25998] = 10,
	[25999] = 26,
	[26000] = 81,
	[26001] = 26,
	[26002] = 26,
	[26003] = 26,
	[26004] = 26,
	[26005] = 81,
	[26006] = 81,
	[26007] = 81,
	[26008] = 81,
	[26009] = 27,
	[26010] = 27,
	[26011] = 27,
	[26012] = 82,
	[26013] = 82,
	[26014] = 81,
	[26015] = 81,
	[26016] = 27,
	[26017] = 81,
	[26018] = 81,
	[26019] = 81,
	[26020] = 27,
	[26021] = 81,
	[26022] = 27,
	[26023] = 27,
	[26024] = 28,
	[26025] = 27,
	[26026] = 27,
	[26027] = 27,
	[26028] = 27,
	[26029] = 27,
	[26030] = 27,
	[26031] = 27,
	[26032] = 27,
	[26033] = 27,
	[26034] = 82,
	[26035] = 26,
	[26036] = 26,
	[26037] = 27,
	[26038] = 27,
	[26039] = 29,
	[26040] = 81,
	[26041] = 29,
	[26042] = 29,
	[26043] = 27,
	[26044] = 27,
	[26045] = 27,
	[26046] = 27,
	[26047] = 27,
	[26048] = 27,
	[26049] = 28,
	[26050] = 28,
	[26051] = 28,
	[26052] = 28,
	[26053] = 27,
	[26055] = 28,
	[26056] = 82,
	[26057] = 82,
	[26058] = 27,
	[26059] = 28,
	[26060] = 28,
	[26061] = 28,
	[26062] = 28,
	[26063] = 27,
	[26064] = 28,
	[26065] = 82,
	[26066] = 29,
	[26067] = 30,
	[26068] = 30,
	[26069] = 30,
	[26070] = 82,
	[26071] = 82,
	[26072] = 82,
	[26073] = 30,
	[26074] = 30,
	[26075] = 30,
	[26076] = 30,
	[26077] = 30,
	[26078] = 10,
	[26079] = 28,
	[26080] = 81,
	[26081] = 27,
	[26082] = 30,
	[26083] = 27,
	[26084] = 27,
	[26085] = 10,
	[26086] = 81,
	[26087] = 81,
	[26088] = 81,
	[26089] = 81,
	[26090] = 81,
	[26091] = 81,
	[26092] = 81,
	[26093] = 26,
	[26094] = 10,
	[26095] = 28,
	[26096] = 82,
	[26097] = 30,
	[26098] = 30,
	[26099] = 30,
	[26100] = 30,
	[26101] = 30,
	[26102] = 10,
	[26103] = 81,
	[26105] = 81,
	[26106] = 81,
	[26107] = 28,
	[26108] = 28,
	[26110] = 28,
	[26111] = 82,
	[26112] = 10,
	[26113] = 28,
	[26114] = 28,
	[26115] = 30,
	[26116] = 28,
	[26117] = 28,
	[26118] = 10,
	[26120] = 25,
	[26121] = 81,
	[26122] = 81,
	[26124] = 81,
	[26125] = 81,
	[26126] = 81,
	[26127] = 25,
	[26128] = 25,
	[26129] = 3,
	[26130] = 82,
	[26131] = 10,
	[26132] = 82,
	[26133] = 82,
	[26134] = 30,
	[26135] = 81,
	[26137] = 20,
	[26138] = 24,
	[26139] = 25,
	[26140] = 82,
	[26141] = 82,
	[26142] = 82,
	[26143] = 83,
	[26144] = 82,
	[26145] = 12,
	[26146] = 12,
	[26147] = 12,
	[26148] = 12,
	[26149] = 82,
	[26150] = 6,
	[26152] = 10,
	[26154] = 82,
	[26157] = 55,
	[26158] = 55,
	[26159] = 55,
	[26160] = 55,
	[26161] = 56,
	[26162] = 56,
	[26163] = 56,
	[26164] = 56,
	[26165] = 56,
	[26166] = 56,
	[26167] = 55,
	[26168] = 55,
	[26169] = 55,
	[26170] = 56,
	[26171] = 57,
	[26172] = 55,
	[26173] = 56,
	[26174] = 56,
	[26175] = 57,
	[26176] = 12,
	[26178] = 72,
	[26179] = 7,
	[26180] = 8,
	[26181] = 82,
	[26182] = 82,
	[26184] = 58,
	[26185] = 58,
	[26186] = 58,
	[26187] = 59,
	[26188] = 8,
	[26189] = 24,
	[26191] = 81,
	[26193] = 82,
	[26194] = 82,
	[26195] = 24,
	[26196] = 25,
	[26197] = 1,
	[26198] = 3,
	[26199] = 1,
	[26200] = 3,
	[26201] = 3,
	[26202] = 1,
	[26203] = 1,
	[26204] = 3,
	[26205] = 2,
	[26206] = 1,
	[26207] = 3,
	[26208] = 2,
	[26209] = 11,
	[26210] = 31,
	[26211] = 31,
	[26212] = 31,
	[26213] = 10,
	[26214] = 11,
	[26215] = 11,
	[26219] = 81,
	[26221] = 81,
	[26222] = 2,
	[26223] = 32,
	[26224] = 32,
	[26225] = 31,
	[26228] = 11,
	[26229] = 11,
	[26230] = 12,
	[26232] = 12,
	[26236] = 12,
	[26237] = 12,
	[26238] = 32,
	[26240] = 32,
	[26241] = 12,
	[26243] = 82,
	[26244] = 82,
	[26245] = 82,
	[26246] = 82,
	[26247] = 82,
	[26248] = 82,
	[26249] = 82,
	[26250] = 82,
	[26251] = 82,
	[26252] = 12,
	[26254] = 82,
	[26255] = 82,
	[26256] = 82,
	[26257] = 13,
	[26258] = 82,
	[26259] = 82,
	[26260] = 82,
	[26261] = 82,
	[26263] = 32,
	[26264] = 2,
	[26265] = 2,
	[26266] = 13,
	[26267] = 32,
	[26268] = 32,
	[26269] = 25,
	[26270] = 13,
	[26271] = 13,
	[26272] = 2,
	[26273] = 2,
	[26274] = 3,
	[26275] = 3,
	[26276] = 3,
	[26277] = 3,
	[26278] = 25,
	[26279] = 25,
	[26280] = 25,
	[26281] = 25,
	[26282] = 33,
	[26283] = 32,
	[26284] = 3,
	[26285] = 3,
	[26286] = 13,
	[26287] = 13,
	[26288] = 14,
	[26289] = 14,
	[26290] = 14,
	[26291] = 14,
	[26292] = 14,
	[26293] = 84,
	[26294] = 84,
	[26295] = 14,
	[26296] = 14,
	[26297] = 15,
	[26298] = 26,
	[26299] = 26,
	[26300] = 27,
	[26301] = 27,
	[26302] = 27,
	[26303] = 28,
	[26304] = 29,
	[26305] = 29,
	[26306] = 33,
	[26307] = 33,
	[26308] = 33,
	[26309] = 33,
	[26310] = 33,
	[26311] = 84,
	[26312] = 83,
	[26313] = 83,
	[26314] = 83,
	[26315] = 83,
	[26316] = 3,
	[26317] = 25,
	[26318] = 3,
	[26319] = 15,
	[26320] = 15,
	[26321] = 25,
	[26322] = 15,
	[26323] = 26,
	[26324] = 84,
	[26325] = 26,
	[26326] = 83,
	[26327] = 25,
	[26328] = 83,
	[26329] = 3,
	[26330] = 26,
	[26331] = 4,
	[26332] = 26,
	[26333] = 4,
	[26334] = 26,
	[26335] = 84,
	[26336] = 28,
	[26337] = 84,
	[26338] = 27,
	[26339] = 5,
	[26340] = 25,
	[26341] = 29,
	[26342] = 5,
	[26343] = 26,
	[26344] = 27,
	[26345] = 28,
	[26346] = 27,
	[26347] = 14,
	[26348] = 15,
	[26349] = 15,
	[26350] = 27,
	[26351] = 27,
	[26352] = 28,
	[26353] = 13,
	[26354] = 13,
	[26355] = 13,
	[26356] = 13,
	[26357] = 33,
	[26358] = 84,
	[26359] = 27,
	[26360] = 29,
	[26361] = 84,
	[26362] = 29,
	[26363] = 33,
	[26364] = 5,
	[26365] = 15,
	[26366] = 33,
	[26367] = 33,
	[26368] = 33,
	[26369] = 33,
	[26370] = 15,
	[26371] = 15,
	[26372] = 84,
	[26373] = 5,
	[26374] = 84,
	[26375] = 83,
	[26376] = 83,
	[26377] = 83,
	[26378] = 10,
	[26379] = 15,
	[26380] = 5,
	[26381] = 34,
	[26382] = 34,
	[26383] = 10,
	[26384] = 34,
	[26385] = 10,
	[26386] = 29,
	[26387] = 34,
	[26388] = 84,
	[26389] = 4,
	[26390] = 5,
	[26391] = 4,
	[26393] = 7,
	[26394] = 7,
	[26395] = 7,
	[26396] = 7,
	[26397] = 12,
	[26398] = 12,
	[26399] = 28,
	[26400] = 28,
	[26401] = 37,
	[26402] = 36,
	[26403] = 28,
	[26404] = 30,
	[26405] = 29,
	[26406] = 34,
	[26407] = 25,
	[26408] = 20,
	[26409] = 82,
	[26410] = 82,
	[26411] = 82,
	[26412] = 28,
	[26413] = 82,
	[26416] = 25,
	[26417] = 25,
	[26418] = 35,
	[26419] = 35,
	[26421] = 2,
	[26422] = 2,
	[26423] = 2,
	[26424] = 2,
	[26425] = 2,
	[26426] = 83,
	[26427] = 82,
	[26428] = 27,
	[26429] = 30,
	[26430] = 31,
	[26432] = 33,
	[26433] = 30,
	[26434] = 30,
	[26435] = 32,
	[26436] = 83,
	[26437] = 83,
	[26438] = 83,
	[26439] = 83,
	[26440] = 83,
	[26441] = 83,
	[26443] = 21,
	[26444] = 21,
	[26445] = 22,
	[26446] = 21,
	[26447] = 21,
	[26448] = 21,
	[26449] = 22,
	[26450] = 30,
	[26453] = 21,
	[26454] = 21,
	[26455] = 21,
	[26456] = 25,
	[26457] = 21,
	[26462] = 32,
	[26463] = 21,
	[26464] = 21,
	[26465] = 21,
	[26466] = 22,
	[26467] = 21,
	[26468] = 22,
	[26469] = 21,
	[26470] = 26,
	[26472] = 22,
	[26473] = 21,
	[26474] = 23,
	[26475] = 23,
	[26476] = 23,
	[26477] = 23,
	[26478] = 23,
	[26479] = 23,
	[26480] = 25,
	[26481] = 26,
	[26482] = 25,
	[26483] = 32,
	[26484] = 82,
	[26485] = 31,
	[26486] = 31,
	[26487] = 30,
	[26489] = 30,
	[26490] = 32,
	[26491] = 32,
	[26492] = 32,
	[26493] = 30,
	[26494] = 31,
	[26495] = 31,
	[26496] = 33,
	[26497] = 33,
	[26498] = 33,
	[26499] = 82,
	[26500] = 82,
	[26501] = 82,
	[26502] = 82,
	[26503] = 15,
	[26504] = 15,
	[26505] = 16,
	[26506] = 16,
	[26507] = 83,
	[26508] = 16,
	[26509] = 16,
	[26510] = 16,
	[26511] = 16,
	[26512] = 16,
	[26513] = 16,
	[26514] = 16,
	[26515] = 33,
	[26516] = 33,
	[26517] = 33,
	[26518] = 33,
	[26519] = 16,
	[26520] = 16,
	[26521] = 33,
	[26523] = 33,
	[26524] = 33,
	[26525] = 33,
	[26526] = 33,
	[26527] = 34,
	[26528] = 34,
	[26529] = 34,
	[26530] = 35,
	[26531] = 35,
	[26532] = 35,
	[26533] = 31,
	[26534] = 31,
	[26535] = 32,
	[26537] = 82,
	[26538] = 84,
	[26539] = 84,
	[26540] = 84,
	[26542] = 30,
	[26544] = 16,
	[26545] = 16,
	[26546] = 31,
	[26547] = 31,
	[26548] = 31,
	[26549] = 84,
	[26550] = 31,
	[26551] = 32,
	[26552] = 32,
	[26553] = 32,
	[26554] = 32,
	[26555] = 32,
	[26558] = 35,
	[26560] = 17,
	[26561] = 17,
	[26562] = 17,
	[26563] = 17,
	[26564] = 82,
	[26566] = 2,
	[26567] = 17,
	[26568] = 17,
	[26569] = 17,
	[26570] = 17,
	[26571] = 17,
	[26573] = 17,
	[26574] = 38,
	[26575] = 83,
	[26576] = 83,
	[26577] = 83,
	[26578] = 83,
	[26579] = 83,
	[26580] = 83,
	[26581] = 83,
	[26582] = 83,
	[26583] = 83,
	[26584] = 83,
	[26585] = 83,
	[26586] = 17,
	[26587] = 17,
	[26589] = 35,
	[26590] = 30,
	[26591] = 82,
	[26592] = 30,
	[26593] = 32,
	[26594] = 32,
	[26595] = 32,
	[26596] = 35,
	[26597] = 33,
	[26598] = 33,
	[26599] = 33,
	[26600] = 33,
	[26601] = 33,
	[26602] = 33,
	[26603] = 32,
	[26604] = 32,
	[26605] = 32,
	[26606] = 33,
	[26607] = 18,
	[26608] = 84,
	[26609] = 32,
	[26610] = 32,
	[26611] = 32,
	[26612] = 33,
	[26613] = 33,
	[26614] = 33,
	[26616] = 18,
	[26617] = 32,
	[26618] = 21,
	[26619] = 84,
	[26620] = 21,
	[26621] = 84,
	[26622] = 84,
	[26623] = 21,
	[26624] = 33,
	[26625] = 83,
	[26627] = 21,
	[26628] = 28,
	[26629] = 33,
	[26630] = 33,
	[26631] = 33,
	[26632] = 83,
	[26633] = 33,
	[26634] = 33,
	[26635] = 33,
	[26636] = 18,
	[26637] = 18,
	[26638] = 18,
	[26639] = 18,
	[26640] = 18,
	[26641] = 34,
	[26642] = 12,
	[26643] = 34,
	[26644] = 34,
	[26645] = 21,
	[26646] = 18,
	[26647] = 34,
	[26648] = 34,
	[26649] = 34,
	[26650] = 35,
	[26651] = 18,
	[26652] = 21,
	[26653] = 21,
	[26654] = 21,
	[26655] = 21,
	[26656] = 83,
	[26657] = 83,
	[26658] = 83,
	[26659] = 83,
	[26660] = 21,
	[26661] = 22,
	[26662] = 35,
	[26663] = 35,
	[26664] = 35,
	[26665] = 35,
	[26666] = 23,
	[26667] = 23,
	[26668] = 18,
	[26669] = 23,
	[26670] = 23,
	[26671] = 23,
	[26672] = 23,
	[26674] = 23,
	[26676] = 22,
	[26677] = 22,
	[26678] = 35,
	[26679] = 35,
	[26680] = 22,
	[26681] = 22,
	[26682] = 36,
	[26683] = 21,
	[26684] = 21,
	[26685] = 22,
	[26686] = 21,
	[26687] = 35,
	[26688] = 23,
	[26689] = 23,
	[26690] = 23,
	[26691] = 24,
	[26692] = 19,
	[26693] = 19,
	[26694] = 19,
	[26695] = 35,
	[26696] = 35,
	[26697] = 35,
	[26698] = 35,
	[26699] = 35,
	[26700] = 35,
	[26701] = 35,
	[26702] = 35,
	[26703] = 35,
	[26706] = 12,
	[26707] = 24,
	[26708] = 20,
	[26709] = 83,
	[26710] = 83,
	[26711] = 3,
	[26712] = 3,
	[26713] = 20,
	[26714] = 20,
	[26717] = 24,
	[26718] = 35,
	[26719] = 24,
	[26720] = 24,
	[26721] = 24,
	[26722] = 25,
	[26723] = 24,
	[26724] = 25,
	[26725] = 25,
	[26726] = 20,
	[26727] = 22,
	[26728] = 20,
	[26729] = 26,
	[26730] = 26,
	[26731] = 26,
	[26732] = 25,
	[26733] = 25,
	[26734] = 25,
	[26735] = 25,
	[26736] = 25,
	[26737] = 25,
	[26738] = 25,
	[26739] = 25,
	[26740] = 28,
	[26742] = 26,
	[26743] = 26,
	[26744] = 26,
	[26745] = 26,
	[26746] = 26,
	[26747] = 26,
	[26748] = 26,
	[26749] = 27,
	[26750] = 83,
	[26751] = 27,
	[26752] = 83,
	[26753] = 25,
	[26754] = 25,
	[26755] = 83,
	[26760] = 24,
	[26761] = 15,
	[26762] = 83,
	[26763] = 28,
	[26764] = 28,
	[26765] = 28,
	[26766] = 82,
	[26768] = 82,
	[26769] = 16,
	[26770] = 83,
	[26771] = 82,
	[26772] = 27,
	[26773] = 27,
	[26774] = 29,
	[26775] = 29,
	[26776] = 29,
	[26777] = 24,
	[26778] = 24,
	[26779] = 29,
	[26780] = 29,
	[26781] = 28,
	[26782] = 28,
	[26783] = 28,
	[26784] = 84,
	[26785] = 24,
	[26786] = 84,
	[26787] = 24,
	[26788] = 84,
	[26791] = 83,
	[26792] = 83,
	[26793] = 25,
	[26794] = 25,
	[26795] = 25,
	[26796] = 25,
	[26797] = 25,
	[26798] = 84,
	[26799] = 1,
	[26800] = 2,
	[26801] = 3,
	[26802] = 3,
	[26803] = 10,
	[26804] = 10,
	[26805] = 30,
	[26806] = 10,
	[26807] = 10,
	[26808] = 31,
	[26809] = 31,
	[26810] = 32,
	[26811] = 32,
	[26812] = 32,
	[26813] = 32,
	[26814] = 32,
	[26815] = 31,
	[26816] = 32,
	[26817] = 30,
	[26818] = 30,
	[26819] = 30,
	[26820] = 30,
	[26821] = 32,
	[26822] = 30,
	[26823] = 30,
	[26824] = 32,
	[26825] = 30,
	[26826] = 30,
	[26827] = 83,
	[26828] = 83,
	[26829] = 83,
	[26830] = 84,
	[26831] = 83,
	[26832] = 83,
	[26833] = 83,
	[26834] = 83,
	[26835] = 83,
	[26836] = 83,
	[26837] = 30,
	[26838] = 25,
	[26839] = 30,
	[26840] = 84,
	[26841] = 3,
	[26842] = 12,
	[26843] = 13,
	[26844] = 13,
	[26845] = 13,
	[26846] = 13,
	[26854] = 11,
	[26855] = 11,
	[26857] = 82,
	[26860] = 12,
	[26861] = 82,
	[26863] = 13,
	[26864] = 13,
	[26868] = 15,
	[26869] = 83,
	[26870] = 21,
	[26871] = 83,
	[26872] = 18,
	[26873] = 18,
	[26875] = 83,
	[26876] = 83,
	[26878] = 16,
	[26881] = 25,
	[26882] = 28,
	[26883] = 28,
	[26884] = 26,
	[26885] = 25,
	[26886] = 46,
	[26887] = 46,
	[26888] = 27,
	[26889] = 46,
	[26890] = 22,
	[26891] = 26,
	[26892] = 26,
	[26894] = 24,
	[26895] = 49,
	[26896] = 49,
	[26897] = 24,
	[26898] = 24,
	[26899] = 28,
	[26901] = 35,
	[26903] = 35,
	[26904] = 3,
	[26905] = 35,
	[26906] = 35,
	[26907] = 35,
	[26908] = 33,
	[26909] = 29,
	[26910] = 3,
	[26911] = 27,
	[26912] = 28,
	[26913] = 3,
	[26914] = 3,
	[26915] = 3,
	[26916] = 3,
	[26917] = 3,
	[26918] = 3,
	[26919] = 3,
	[26920] = 35,
	[26921] = 35,
	[26922] = 35,
	[26923] = 35,
	[26924] = 35,
	[26925] = 35,
	[26926] = 35,
	[26927] = 14,
	[26928] = 15,
	[26929] = 15,
	[26930] = 36,
	[26931] = 36,
	[26932] = 15,
	[26933] = 36,
	[26934] = 36,
	[26935] = 37,
	[26936] = 36,
	[26937] = 36,
	[26938] = 37,
	[26939] = 27,
	[26940] = 3,
	[26941] = 28,
	[26942] = 29,
	[26943] = 26,
	[26944] = 26,
	[26945] = 3,
	[26946] = 3,
	[26947] = 3,
	[26948] = 3,
	[26949] = 3,
	[26952] = 37,
	[26953] = 37,
	[26954] = 37,
	[26955] = 38,
	[26956] = 37,
	[26957] = 38,
	[26958] = 3,
	[26960] = 84,
	[26961] = 16,
	[26963] = 3,
	[26964] = 10,
	[26965] = 11,
	[26966] = 3,
	[26968] = 3,
	[26969] = 3,
	[26970] = 3,
	[26971] = 83,
	[26975] = 84,
	[26977] = 84,
	[26978] = 36,
	[26979] = 36,
	[26980] = 23,
	[26981] = 23,
	[26989] = 11,
	[26992] = 11,
	[26995] = 11,
	[26997] = 84,
	[26998] = 11,
	[26999] = 37,
	[27000] = 37,
	[27001] = 37,
	[27002] = 37,
	[27003] = 83,
	[27004] = 83,
	[27005] = 83,
	[27006] = 83,
	[27007] = 82,
	[27008] = 83,
	[27009] = 46,
	[27010] = 82,
	[27011] = 37,
	[27012] = 37,
	[27013] = 37,
	[27014] = 3,
	[27015] = 3,
	[27016] = 16,
	[27017] = 38,
	[27019] = 44,
	[27020] = 3,
	[27021] = 3,
	[27022] = 45,
	[27023] = 3,
	[27024] = 44,
	[27025] = 16,
	[27026] = 16,
	[27027] = 3,
	[27028] = 16,
	[27029] = 44,
	[27030] = 16,
	[27031] = 17,
	[27032] = 18,
	[27033] = 18,
	[27034] = 18,
	[27035] = 18,
	[27036] = 17,
	[27037] = 16,
	[27038] = 84,
	[27039] = 11,
	[27040] = 83,
	[27041] = 83,
	[27042] = 83,
	[27043] = 83,
	[27044] = 84,
	[27045] = 11,
	[27046] = 83,
	[27047] = 83,
	[27048] = 83,
	[27049] = 83,
	[27050] = 83,
	[27051] = 83,
	[27053] = 38,
	[27054] = 38,
	[27055] = 39,
	[27056] = 11,
	[27057] = 38,
	[27058] = 83,
	[27059] = 83,
	[27060] = 84,
	[27061] = 82,
	[27062] = 43,
	[27063] = 43,
	[27064] = 84,
	[27065] = 12,
	[27066] = 3,
	[27067] = 3,
	[27068] = 49,
	[27069] = 12,
	[27070] = 48,
	[27071] = 48,
	[27072] = 84,
	[27073] = 12,
	[27074] = 18,
	[27075] = 18,
	[27076] = 48,
	[27077] = 18,
	[27078] = 19,
	[27082] = 12,
	[27083] = 40,
	[27084] = 40,
	[27085] = 40,
	[27086] = 40,
	[27087] = 40,
	[27088] = 12,
	[27089] = 40,
	[27090] = 40,
	[27091] = 3,
	[27092] = 84,
	[27093] = 12,
	[27094] = 13,
	[27095] = 12,
	[27096] = 13,
	[27097] = 13,
	[27098] = 13,
	[27099] = 13,
	[27100] = 82,
	[27101] = 82,
	[27102] = 82,
	[27103] = 41,
	[27104] = 41,
	[27105] = 40,
	[27106] = 84,
	[27107] = 40,
	[27108] = 40,
	[27109] = 43,
	[27110] = 44,
	[27111] = 44,
	[27112] = 43,
	[27113] = 43,
	[27114] = 46,
	[27115] = 18,
	[27116] = 18,
	[27117] = 35,
	[27118] = 46,
	[27119] = 46,
	[27120] = 46,
	[27123] = 82,
	[27124] = 47,
	[27125] = 47,
	[27126] = 83,
	[27128] = 47,
	[27129] = 40,
	[27130] = 40,
	[27131] = 42,
	[27132] = 42,
	[27133] = 46,
	[27134] = 46,
	[27135] = 82,
	[27136] = 82,
	[27139] = 7,
	[27141] = 83,
	[27144] = 40,
	[27151] = 37,
	[27152] = 37,
	[27153] = 37,
	[27154] = 37,
	[27155] = 37,
	[27156] = 37,
	[27157] = 37,
	[27158] = 35,
	[27159] = 35,
	[27160] = 35,
	[27161] = 35,
	[27162] = 35,
	[27163] = 35,
	[27164] = 35,
	[27165] = 35,
	[27166] = 36,
	[27167] = 36,
	[27168] = 36,
	[27169] = 36,
	[27170] = 36,
	[27171] = 36,
	[27172] = 36,
	[27173] = 36,
	[27174] = 37,
	[27175] = 37,
	[27176] = 83,
	[27177] = 84,
	[27178] = 84,
	[27179] = 83,
	[27180] = 13,
	[27181] = 13,
	[27182] = 36,
	[27183] = 36,
	[27184] = 36,
	[27185] = 46,
	[27186] = 36,
	[27187] = 83,
	[27188] = 36,
	[27189] = 36,
	[27190] = 36,
	[27191] = 36,
	[27192] = 46,
	[27193] = 13,
	[27194] = 13,
	[27195] = 13,
	[27196] = 83,
	[27197] = 40,
	[27198] = 40,
	[27199] = 40,
	[27200] = 84,
	[27201] = 40,
	[27202] = 40,
	[27203] = 82,
	[27204] = 40,
	[27205] = 40,
	[27206] = 40,
	[27208] = 47,
	[27210] = 36,
	[27211] = 36,
	[27212] = 36,
	[27213] = 36,
	[27214] = 36,
	[27215] = 36,
	[27216] = 36,
	[27217] = 36,
	[27218] = 36,
	[27219] = 36,
	[27220] = 37,
	[27221] = 37,
	[27222] = 37,
	[27223] = 47,
	[27225] = 20,
	[27226] = 13,
	[27227] = 51,
	[27228] = 50,
	[27229] = 36,
	[27230] = 50,
	[27231] = 13,
	[27232] = 13,
	[27233] = 37,
	[27234] = 37,
	[27235] = 37,
	[27236] = 37,
	[27237] = 37,
	[27238] = 37,
	[27239] = 37,
	[27240] = 37,
	[27241] = 37,
	[27242] = 37,
	[27243] = 37,
	[27244] = 36,
	[27245] = 37,
	[27246] = 36,
	[27247] = 36,
	[27248] = 39,
	[27249] = 37,
	[27251] = 37,
	[27252] = 37,
	[27253] = 37,
	[27254] = 35,
	[27255] = 37,
	[27256] = 37,
	[27257] = 37,
	[27258] = 37,
	[27259] = 37,
	[27260] = 37,
	[27261] = 37,
	[27262] = 37,
	[27263] = 37,
	[27264] = 37,
	[27265] = 20,
	[27266] = 20,
	[27267] = 20,
	[27268] = 20,
	[27269] = 20,
	[27270] = 20,
	[27271] = 20,
	[27272] = 20,
	[27273] = 20,
	[27274] = 20,
	[27275] = 42,
	[27276] = 42,
	[27277] = 20,
	[27278] = 20,
	[27279] = 20,
	[27280] = 20,
	[27281] = 20,
	[27282] = 20,
	[27283] = 20,
	[27284] = 37,
	[27285] = 37,
	[27286] = 37,
	[27287] = 37,
	[27288] = 37,
	[27290] = 14,
	[27291] = 39,
	[27292] = 37,
	[27293] = 38,
	[27294] = 37,
	[27295] = 38,
	[27296] = 38,
	[27297] = 38,
	[27298] = 20,
	[27299] = 84,
	[27300] = 84,
	[27301] = 84,
	[27302] = 84,
	[27303] = 84,
	[27304] = 20,
	[27305] = 46,
	[27306] = 37,
	[27310] = 42,
	[27311] = 42,
	[27312] = 42,
	[27313] = 42,
	[27314] = 42,
	[27315] = 42,
	[27316] = 42,
	[27317] = 42,
	[27318] = 42,
	[27319] = 42,
	[27320] = 42,
	[27321] = 42,
	[27322] = 15,
	[27323] = 42,
	[27324] = 42,
	[27325] = 42,
	[27326] = 42,
	[27327] = 43,
	[27328] = 43,
	[27329] = 43,
	[27330] = 43,
	[27331] = 20,
	[27332] = 20,
	[27333] = 14,
	[27334] = 20,
	[27335] = 20,
	[27336] = 38,
	[27337] = 20,
	[27338] = 84,
	[27339] = 38,
	[27340] = 38,
	[27341] = 84,
	[27342] = 14,
	[27343] = 20,
	[27344] = 20,
	[27345] = 14,
	[27346] = 38,
	[27347] = 38,
	[27348] = 38,
	[27349] = 14,
	[27350] = 14,
	[27351] = 20,
	[27352] = 50,
	[27353] = 20,
	[27354] = 20,
	[27355] = 20,
	[27356] = 20,
	[27357] = 43,
	[27358] = 43,
	[27359] = 50,
	[27360] = 15,
	[27361] = 20,
	[27362] = 20,
	[27363] = 20,
	[27364] = 15,
	[27365] = 20,
	[27366] = 84,
	[27367] = 40,
	[27368] = 40,
	[27369] = 40,
	[27370] = 40,
	[27371] = 40,
	[27372] = 40,
	[27373] = 40,
	[27374] = 84,
	[27375] = 84,
	[27376] = 84,
	[27377] = 84,
	[27378] = 84,
	[27379] = 84,
	[27380] = 85,
	[27381] = 41,
	[27382] = 41,
	[27383] = 41,
	[27384] = 41,
	[27385] = 41,
	[27386] = 41,
	[27387] = 41,
	[27388] = 41,
	[27389] = 41,
	[27390] = 41,
	[27391] = 41,
	[27392] = 41,
	[27393] = 81,
	[27394] = 81,
	[27395] = 20,
	[27396] = 20,
	[27397] = 20,
	[27398] = 82,
	[27399] = 82,
	[27400] = 20,
	[27401] = 15,
	[27402] = 20,
	[27403] = 20,
	[27404] = 20,
	[27405] = 15,
	[27406] = 16,
	[27407] = 39,
	[27408] = 39,
	[27409] = 39,
	[27410] = 39,
	[27411] = 39,
	[27412] = 39,
	[27413] = 39,
	[27414] = 39,
	[27415] = 39,
	[27416] = 39,
	[27417] = 39,
	[27418] = 39,
	[27420] = 41,
	[27421] = 41,
	[27422] = 45,
	[27423] = 16,
	[27424] = 39,
	[27425] = 38,
	[27426] = 38,
	[27427] = 38,
	[27428] = 38,
	[27429] = 38,
	[27430] = 38,
	[27431] = 83,
	[27432] = 41,
	[27433] = 84,
	[27434] = 20,
	[27435] = 20,
	[27436] = 20,
	[27437] = 20,
	[27438] = 16,
	[27439] = 20,
	[27440] = 59,
	[27441] = 20,
	[27442] = 82,
	[27443] = 82,
	[27444] = 59,
	[27445] = 60,
	[27446] = 43,
	[27447] = 43,
	[27448] = 42,
	[27449] = 42,
	[27450] = 42,
	[27451] = 42,
	[27452] = 42,
	[27453] = 42,
	[27454] = 42,
	[27455] = 42,
	[27456] = 42,
	[27457] = 42,
	[27458] = 42,
	[27459] = 42,
	[27460] = 42,
	[27461] = 42,
	[27462] = 42,
	[27463] = 42,
	[27464] = 42,
	[27465] = 42,
	[27466] = 43,
	[27467] = 42,
	[27468] = 84,
	[27469] = 58,
	[27470] = 58,
	[27471] = 58,
	[27472] = 16,
	[27474] = 17,
	[27475] = 17,
	[27476] = 18,
	[27477] = 43,
	[27478] = 18,
	[27479] = 43,
	[27480] = 18,
	[27481] = 43,
	[27482] = 43,
	[27483] = 18,
	[27484] = 18,
	[27485] = 85,
	[27486] = 85,
	[27487] = 43,
	[27488] = 43,
	[27489] = 43,
	[27490] = 85,
	[27491] = 85,
	[27492] = 85,
	[27493] = 85,
	[27494] = 85,
	[27495] = 85,
	[27496] = 85,
	[27497] = 85,
	[27499] = 85,
	[27502] = 85,
	[27503] = 85,
	[27504] = 85,
	[27505] = 85,
	[27506] = 85,
	[27507] = 85,
	[27508] = 85,
	[27509] = 85,
	[27510] = 18,
	[27511] = 83,
	[27512] = 18,
	[27513] = 18,
	[27514] = 84,
	[27515] = 84,
	[27516] = 84,
	[27517] = 83,
	[27518] = 19,
	[27519] = 83,
	[27520] = 83,
	[27521] = 44,
	[27522] = 44,
	[27523] = 44,
	[27524] = 44,
	[27525] = 45,
	[27526] = 45,
	[27527] = 45,
	[27528] = 44,
	[27529] = 44,
	[27530] = 45,
	[27531] = 44,
	[27532] = 44,
	[27533] = 44,
	[27534] = 44,
	[27535] = 44,
	[27536] = 52,
	[27537] = 84,
	[27538] = 84,
	[27539] = 44,
	[27541] = 83,
	[27542] = 19,
	[27544] = 41,
	[27545] = 84,
	[27547] = 19,
	[27548] = 19,
	[27549] = 83,
	[27550] = 19,
	[27551] = 45,
	[27564] = 85,
	[27565] = 52,
	[27567] = 55,
	[27568] = 54,
	[27569] = 55,
	[27571] = 56,
	[27573] = 57,
	[27574] = 19,
	[27575] = 19,
	[27576] = 85,
	[27577] = 19,
	[27578] = 58,
	[27579] = 52,
	[27580] = 20,
	[27581] = 55,
	[27582] = 54,
	[27583] = 84,
	[27584] = 84,
	[27585] = 55,
	[27586] = 84,
	[27587] = 52,
	[27588] = 85,
	[27589] = 56,
	[27590] = 85,
	[27591] = 57,
	[27592] = 52,
	[27593] = 58,
	[27594] = 20,
	[27595] = 83,
	[27596] = 55,
	[27597] = 52,
	[27598] = 52,
	[27599] = 52,
	[27600] = 52,
	[27601] = 20,
	[27602] = 83,
	[27603] = 52,
	[27604] = 54,
	[27605] = 54,
	[27606] = 84,
	[27607] = 84,
	[27608] = 85,
	[27609] = 85,
	[27610] = 84,
	[27611] = 84,
	[27612] = 42,
	[27613] = 42,
	[27614] = 42,
	[27615] = 42,
	[27616] = 42,
	[27617] = 42,
	[27618] = 42,
	[27619] = 42,
	[27620] = 43,
	[27621] = 84,
	[27622] = 84,
	[27623] = 83,
	[27624] = 83,
	[27625] = 35,
	[27626] = 35,
	[27627] = 83,
	[27628] = 83,
	[27629] = 84,
	[27630] = 83,
	[27631] = 83,
	[27632] = 83,
	[27633] = 54,
	[27635] = 2,
	[27636] = 85,
	[27638] = 85,
	[27640] = 84,
	[27641] = 84,
	[27642] = 84,
	[27643] = 84,
	[27644] = 84,
	[27645] = 84,
	[27646] = 84,
	[27647] = 84,
	[27648] = 84,
	[27649] = 84,
	[27650] = 84,
	[27651] = 84,
	[27652] = 85,
	[27653] = 85,
	[27654] = 85,
	[27655] = 85,
	[27656] = 52,
	[27657] = 85,
	[27658] = 85,
	[27659] = 85,
	[27660] = 85,
	[27661] = 85,
	[27662] = 85,
	[27663] = 52,
	[27664] = 85,
	[27665] = 85,
	[27666] = 85,
	[27667] = 85,
	[27668] = 81,
	[27669] = 83,
	[27670] = 1,
	[27671] = 1,
	[27672] = 39,
	[27673] = 39,
	[27674] = 2,
	[27676] = 39,
	[27677] = 40,
	[27679] = 39,
	[27680] = 40,
	[27681] = 39,
	[27682] = 39,
	[27683] = 40,
	[27684] = 40,
	[27685] = 81,
	[27687] = 81,
	[27688] = 85,
	[27689] = 85,
	[27690] = 84,
	[27691] = 53,
	[27692] = 39,
	[27693] = 46,
	[27694] = 53,
	[27695] = 85,
	[27696] = 85,
	[27697] = 34,
	[27698] = 36,
	[27699] = 81,
	[27700] = 85,
	[27701] = 85,
	[27702] = 85,
	[27703] = 85,
	[27704] = 53,
	[27705] = 53,
	[27706] = 83,
	[27707] = 83,
	[27708] = 81,
	[27709] = 46,
	[27711] = 85,
	[27712] = 85,
	[27713] = 47,
	[27714] = 47,
	[27715] = 47,
	[27716] = 81,
	[27717] = 81,
	[27718] = 80,
	[27719] = 85,
	[27720] = 85,
	[27721] = 80,
	[27722] = 82,
	[27724] = 80,
	[27725] = 34,
	[27726] = 80,
	[27727] = 82,
	[27729] = 81,
	[27733] = 23,
	[27737] = 24,
	[27738] = 83,
	[27739] = 25,
	[27740] = 53,
	[27742] = 85,
	[27743] = 85,
	[27744] = 85,
	[27745] = 85,
	[27746] = 20,
	[27747] = 84,
	[27748] = 83,
	[27750] = 84,
	[27751] = 84,
	[27752] = 84,
	[27753] = 84,
	[27754] = 84,
	[27755] = 83,
	[27756] = 16,
	[27757] = 53,
	[27758] = 16,
	[27760] = 83,
	[27761] = 83,
	[27762] = 45,
	[27763] = 45,
	[27764] = 45,
	[27765] = 45,
	[27766] = 45,
	[27768] = 54,
	[27769] = 45,
	[27770] = 45,
	[27771] = 45,
	[27772] = 45,
	[27773] = 54,
	[27774] = 45,
	[27775] = 45,
	[27776] = 45,
	[27777] = 83,
	[27778] = 83,
	[27779] = 83,
	[27781] = 16,
	[27782] = 85,
	[27783] = 85,
	[27784] = 85,
	[27785] = 16,
	[27786] = 85,
	[27787] = 85,
	[27788] = 85,
	[27789] = 46,
	[27790] = 17,
	[27791] = 46,
	[27792] = 46,
	[27793] = 46,
	[27794] = 46,
	[27795] = 54,
	[27796] = 46,
	[27797] = 46,
	[27798] = 85,
	[27803] = 84,
	[27804] = 84,
	[27805] = 84,
	[27806] = 84,
	[27807] = 84,
	[27808] = 84,
	[27809] = 84,
	[27810] = 84,
	[27811] = 84,
	[27812] = 84,
	[27813] = 84,
	[27814] = 84,
	[27815] = 84,
	[27816] = 84,
	[27817] = 84,
	[27818] = 53,
	[27821] = 54,
	[27822] = 54,
	[27823] = 46,
	[27824] = 46,
	[27825] = 47,
	[27826] = 47,
	[27827] = 47,
	[27828] = 47,
	[27829] = 47,
	[27830] = 47,
	[27831] = 47,
	[27832] = 47,
	[27833] = 47,
	[27834] = 47,
	[27835] = 47,
	[27836] = 83,
	[27837] = 83,
	[27838] = 83,
	[27839] = 83,
	[27840] = 54,
	[27842] = 16,
	[27843] = 54,
	[27844] = 16,
	[27845] = 54,
	[27847] = 16,
	[27848] = 16,
	[27849] = 54,
	[27850] = 17,
	[27851] = 54,
	[27852] = 54,
	[27853] = 54,
	[27854] = 54,
	[27855] = 54,
	[27856] = 54,
	[27857] = 54,
	[27858] = 47,
	[27859] = 47,
	[27860] = 54,
	[27861] = 85,
	[27862] = 85,
	[27863] = 85,
	[27864] = 85,
	[27865] = 85,
	[27866] = 85,
	[27867] = 85,
	[27868] = 85,
	[27869] = 53,
	[27870] = 54,
	[27871] = 54,
	[27874] = 81,
	[27875] = 55,
	[27876] = 55,
	[27877] = 46,
	[27878] = 46,
	[27879] = 47,
	[27880] = 47,
	[27881] = 46,
	[27882] = 46,
	[27883] = 46,
	[27884] = 46,
	[27885] = 46,
	[27886] = 46,
	[27887] = 46,
	[27888] = 46,
	[27889] = 47,
	[27890] = 47,
	[27891] = 47,
	[27892] = 47,
	[27893] = 47,
	[27894] = 47,
	[27895] = 47,
	[27896] = 47,
	[27897] = 47,
	[27898] = 47,
	[27899] = 83,
	[27900] = 83,
	[27901] = 83,
	[27902] = 55,
	[27903] = 83,
	[27904] = 55,
	[27905] = 83,
	[27906] = 55,
	[27907] = 55,
	[27908] = 55,
	[27909] = 55,
	[27910] = 55,
	[27911] = 55,
	[27912] = 46,
	[27913] = 46,
	[27914] = 54,
	[27915] = 54,
	[27916] = 55,
	[27917] = 18,
	[27918] = 55,
	[27919] = 55,
	[27920] = 19,
	[27921] = 20,
	[27922] = 83,
	[27923] = 83,
	[27924] = 83,
	[27925] = 83,
	[27926] = 83,
	[27927] = 47,
	[27928] = 83,
	[27929] = 84,
	[27930] = 47,
	[27931] = 82,
	[27932] = 82,
	[27933] = 82,
	[27934] = 82,
	[27935] = 82,
	[27936] = 82,
	[27937] = 83,
	[27938] = 83,
	[27939] = 83,
	[27940] = 83,
	[27941] = 83,
	[27942] = 83,
	[27943] = 83,
	[27944] = 85,
	[27945] = 84,
	[27947] = 84,
	[27948] = 85,
	[27949] = 85,
	[27950] = 83,
	[27951] = 84,
	[27952] = 83,
	[27953] = 83,
	[27954] = 84,
	[27955] = 84,
	[27956] = 47,
	[27957] = 47,
	[27958] = 47,
	[27959] = 47,
	[27960] = 47,
	[27961] = 47,
	[27962] = 47,
	[27963] = 47,
	[27964] = 47,
	[27965] = 48,
	[27966] = 85,
	[27967] = 85,
	[27968] = 21,
	[27969] = 83,
	[27970] = 85,
	[27971] = 85,
	[27972] = 85,
	[27973] = 85,
	[27974] = 18,
	[27975] = 85,
	[27976] = 48,
	[27977] = 48,
	[27978] = 85,
	[27979] = 48,
	[27980] = 48,
	[27981] = 48,
	[27982] = 48,
	[27983] = 48,
	[27984] = 48,
	[27985] = 48,
	[27986] = 49,
	[27987] = 85,
	[27988] = 19,
	[27989] = 45,
	[27990] = 83,
	[27991] = 85,
	[27992] = 85,
	[27993] = 83,
	[27994] = 45,
	[27995] = 46,
	[27996] = 20,
	[27997] = 45,
	[27998] = 21,
	[27999] = 84,
	[28000] = 45,
	[28001] = 84,
	[28002] = 83,
	[28028] = 49,
	[28029] = 49,
	[28030] = 49,
	[28031] = 41,
	[28032] = 49,
	[28033] = 49,
	[28034] = 49,
	[28035] = 49,
	[28038] = 85,
	[28041] = 84,
	[28042] = 41,
	[28043] = 84,
	[28044] = 46,
	[28045] = 41,
	[28046] = 85,
	[28047] = 41,
	[28048] = 42,
	[28049] = 46,
	[28050] = 85,
	[28051] = 41,
	[28052] = 49,
	[28053] = 50,
	[28054] = 49,
	[28055] = 49,
	[28056] = 49,
	[28057] = 50,
	[28058] = 50,
	[28059] = 85,
	[28060] = 50,
	[28061] = 50,
	[28062] = 50,
	[28063] = 85,
	[28064] = 50,
	[28065] = 85,
	[28068] = 49,
	[28069] = 49,
	[28084] = 25,
	[28085] = 44,
	[28086] = 44,
	[28087] = 44,
	[28088] = 44,
	[28089] = 20,
	[28090] = 85,
	[28091] = 85,
	[28092] = 85,
	[28093] = 85,
	[28094] = 85,
	[28096] = 20,
	[28097] = 85,
	[28098] = 44,
	[28099] = 48,
	[28100] = 46,
	[28101] = 85,
	[28102] = 46,
	[28103] = 85,
	[28104] = 85,
	[28105] = 83,
	[28107] = 85,
	[28108] = 85,
	[28109] = 85,
	[28111] = 20,
	[28112] = 83,
	[28113] = 46,
	[28114] = 20,
	[28115] = 20,
	[28116] = 46,
	[28117] = 85,
	[28118] = 85,
	[28119] = 46,
	[28120] = 85,
	[28121] = 46,
	[28122] = 85,
	[28123] = 84,
	[28124] = 45,
	[28125] = 45,
	[28126] = 46,
	[28127] = 45,
	[28128] = 46,
	[28129] = 46,
	[28130] = 85,
	[28131] = 46,
	[28132] = 83,
	[28133] = 84,
	[28134] = 83,
	[28135] = 83,
	[28136] = 45,
	[28137] = 85,
	[28138] = 20,
	[28139] = 45,
	[28140] = 45,
	[28141] = 83,
	[28142] = 45,
	[28143] = 45,
	[28144] = 20,
	[28145] = 83,
	[28146] = 20,
	[28147] = 85,
	[28148] = 45,
	[28149] = 85,
	[28150] = 46,
	[28151] = 85,
	[28152] = 46,
	[28153] = 46,
	[28154] = 20,
	[28155] = 46,
	[28156] = 20,
	[28157] = 45,
	[28158] = 45,
	[28159] = 45,
	[28160] = 45,
	[28161] = 45,
	[28162] = 85,
	[28163] = 85,
	[28164] = 20,
	[28165] = 85,
	[28166] = 85,
	[28167] = 1,
	[28168] = 21,
	[28169] = 1,
	[28170] = 85,
	[28171] = 85,
	[28172] = 50,
	[28173] = 85,
	[28174] = 50,
	[28175] = 85,
	[28176] = 85,
	[28177] = 50,
	[28178] = 50,
	[28179] = 50,
	[28180] = 50,
	[28181] = 50,
	[28182] = 50,
	[28183] = 50,
	[28184] = 50,
	[28185] = 85,
	[28186] = 85,
	[28187] = 83,
	[28188] = 85,
	[28189] = 20,
	[28190] = 47,
	[28191] = 85,
	[28192] = 21,
	[28193] = 83,
	[28194] = 83,
	[28195] = 83,
	[28196] = 21,
	[28197] = 21,
	[28198] = 83,
	[28199] = 21,
	[28200] = 83,
	[28201] = 83,
	[28202] = 50,
	[28203] = 50,
	[28204] = 50,
	[28205] = 50,
	[28206] = 21,
	[28207] = 47,
	[28208] = 47,
	[28209] = 21,
	[28210] = 83,
	[28211] = 84,
	[28212] = 84,
	[28213] = 47,
	[28214] = 47,
	[28215] = 84,
	[28216] = 84,
	[28217] = 48,
	[28218] = 48,
	[28219] = 48,
	[28220] = 48,
	[28221] = 48,
	[28222] = 48,
	[28223] = 85,
	[28224] = 48,
	[28225] = 50,
	[28226] = 50,
	[28227] = 50,
	[28228] = 48,
	[28229] = 48,
	[28230] = 21,
	[28231] = 21,
	[28232] = 85,
	[28233] = 84,
	[28234] = 84,
	[28235] = 21,
	[28237] = 21,
	[28238] = 84,
	[28239] = 50,
	[28241] = 84,
	[28242] = 84,
	[28243] = 84,
	[28244] = 84,
	[28245] = 50,
	[28246] = 50,
	[28247] = 85,
	[28248] = 85,
	[28249] = 85,
	[28250] = 83,
	[28251] = 22,
	[28252] = 50,
	[28253] = 50,
	[28254] = 50,
	[28256] = 48,
	[28257] = 48,
	[28258] = 50,
	[28259] = 50,
	[28260] = 50,
	[28261] = 48,
	[28262] = 50,
	[28263] = 50,
	[28264] = 48,
	[28265] = 51,
	[28266] = 51,
	[28267] = 83,
	[28268] = 50,
	[28269] = 83,
	[28271] = 83,
	[28272] = 83,
	[28273] = 83,
	[28274] = 83,
	[28275] = 85,
	[28276] = 83,
	[28277] = 83,
	[28278] = 51,
	[28279] = 51,
	[28280] = 84,
	[28281] = 84,
	[28282] = 84,
	[28283] = 42,
	[28284] = 42,
	[28285] = 50,
	[28286] = 51,
	[28287] = 50,
	[28288] = 46,
	[28289] = 50,
	[28290] = 50,
	[28291] = 83,
	[28292] = 83,
	[28293] = 83,
	[28294] = 84,
	[28295] = 83,
	[28296] = 83,
	[28297] = 50,
	[28298] = 50,
	[28299] = 50,
	[28300] = 50,
	[28301] = 50,
	[28302] = 50,
	[28303] = 50,
	[28304] = 50,
	[28305] = 48,
	[28306] = 47,
	[28307] = 50,
	[28308] = 50,
	[28309] = 50,
	[28310] = 51,
	[28311] = 51,
	[28312] = 51,
	[28313] = 51,
	[28314] = 51,
	[28315] = 51,
	[28316] = 51,
	[28317] = 51,
	[28318] = 51,
	[28319] = 51,
	[28320] = 52,
	[28321] = 52,
	[28322] = 52,
	[28323] = 50,
	[28324] = 22,
	[28325] = 22,
	[28326] = 51,
	[28327] = 52,
	[28328] = 50,
	[28329] = 22,
	[28330] = 22,
	[28331] = 22,
	[28332] = 22,
	[28333] = 49,
	[28334] = 49,
	[28335] = 49,
	[28336] = 49,
	[28337] = 48,
	[28338] = 49,
	[28339] = 49,
	[28340] = 49,
	[28341] = 48,
	[28342] = 48,
	[28343] = 50,
	[28344] = 22,
	[28345] = 22,
	[28346] = 84,
	[28348] = 22,
	[28349] = 3,
	[28350] = 83,
	[28351] = 83,
	[28352] = 83,
	[28353] = 83,
	[28354] = 22,
	[28355] = 22,
	[28356] = 22,
	[28357] = 49,
	[28358] = 48,
	[28359] = 48,
	[28360] = 48,
	[28361] = 48,
	[28362] = 49,
	[28363] = 83,
	[28364] = 49,
	[28366] = 49,
	[28367] = 83,
	[28368] = 49,
	[28369] = 84,
	[28370] = 49,
	[28372] = 49,
	[28373] = 49,
	[28374] = 48,
	[28375] = 23,
	[28376] = 83,
	[28377] = 85,
	[28378] = 85,
	[28379] = 85,
	[28380] = 49,
	[28381] = 49,
	[28382] = 49,
	[28383] = 49,
	[28384] = 49,
	[28385] = 49,
	[28386] = 49,
	[28387] = 49,
	[28388] = 49,
	[28389] = 49,
	[28390] = 83,
	[28391] = 83,
	[28392] = 49,
	[28393] = 50,
	[28394] = 50,
	[28395] = 50,
	[28396] = 50,
	[28397] = 23,
	[28398] = 50,
	[28399] = 50,
	[28400] = 23,
	[28401] = 50,
	[28402] = 83,
	[28403] = 83,
	[28404] = 83,
	[28405] = 50,
	[28406] = 50,
	[28407] = 84,
	[28408] = 84,
	[28409] = 84,
	[28410] = 84,
	[28411] = 84,
	[28413] = 84,
	[28414] = 3,
	[28415] = 51,
	[28416] = 50,
	[28417] = 50,
	[28418] = 50,
	[28419] = 50,
	[28420] = 50,
	[28421] = 50,
	[28422] = 50,
	[28423] = 50,
	[28424] = 50,
	[28425] = 50,
	[28426] = 50,
	[28427] = 50,
	[28428] = 50,
	[28429] = 50,
	[28430] = 50,
	[28431] = 50,
	[28432] = 50,
	[28433] = 50,
	[28434] = 50,
	[28435] = 50,
	[28436] = 50,
	[28437] = 51,
	[28438] = 51,
	[28439] = 51,
	[28440] = 51,
	[28441] = 51,
	[28442] = 51,
	[28443] = 51,
	[28444] = 51,
	[28445] = 51,
	[28446] = 51,
	[28447] = 51,
	[28448] = 51,
	[28449] = 51,
	[28450] = 51,
	[28451] = 51,
	[28452] = 51,
	[28453] = 52,
	[28454] = 52,
	[28455] = 52,
	[28456] = 52,
	[28457] = 50,
	[28458] = 50,
	[28459] = 50,
	[28460] = 50,
	[28461] = 50,
	[28462] = 50,
	[28463] = 50,
	[28464] = 50,
	[28465] = 50,
	[28466] = 50,
	[28467] = 50,
	[28469] = 50,
	[28470] = 50,
	[28471] = 50,
	[28472] = 50,
	[28473] = 50,
	[28474] = 50,
	[28475] = 50,
	[28476] = 50,
	[28477] = 50,
	[28478] = 50,
	[28479] = 51,
	[28480] = 84,
	[28482] = 83,
	[28483] = 84,
	[28484] = 23,
	[28485] = 25,
	[28486] = 84,
	[28487] = 23,
	[28488] = 83,
	[28489] = 23,
	[28490] = 10,
	[28491] = 51,
	[28492] = 20,
	[28493] = 20,
	[28494] = 10,
	[28495] = 23,
	[28496] = 10,
	[28497] = 83,
	[28498] = 84,
	[28499] = 84,
	[28500] = 84,
	[28501] = 84,
	[28502] = 84,
	[28503] = 40,
	[28504] = 40,
	[28505] = 35,
	[28506] = 23,
	[28507] = 45,
	[28508] = 35,
	[28509] = 45,
	[28510] = 35,
	[28511] = 35,
	[28512] = 47,
	[28513] = 51,
	[28514] = 50,
	[28515] = 50,
	[28516] = 51,
	[28517] = 10,
	[28518] = 51,
	[28519] = 51,
	[28520] = 84,
	[28521] = 50,
	[28522] = 50,
	[28523] = 52,
	[28524] = 50,
	[28525] = 50,
	[28526] = 50,
	[28527] = 55,
	[28528] = 55,
	[28529] = 12,
	[28530] = 50,
	[28531] = 30,
	[28532] = 25,
	[28533] = 84,
	[28534] = 51,
	[28535] = 51,
	[28536] = 51,
	[28537] = 51,
	[28538] = 24,
	[28539] = 25,
	[28540] = 51,
	[28542] = 45,
	[28543] = 45,
	[28544] = 50,
	[28545] = 50,
	[28548] = 30,
	[28549] = 30,
	[28550] = 30,
	[28551] = 30,
	[28552] = 35,
	[28553] = 55,
	[28554] = 35,
	[28555] = 84,
	[28556] = 24,
	[28557] = 84,
	[28558] = 84,
	[28559] = 10,
	[28560] = 10,
	[28561] = 84,
	[28562] = 10,
	[28563] = 15,
	[28564] = 20,
	[28565] = 20,
	[28566] = 24,
	[28567] = 10,
	[28568] = 10,
	[28569] = 52,
	[28570] = 52,
	[28571] = 20,
	[28572] = 25,
	[28573] = 25,
	[28574] = 30,
	[28575] = 35,
	[28576] = 35,
	[28577] = 40,
	[28578] = 40,
	[28579] = 45,
	[28580] = 45,
	[28581] = 48,
	[28582] = 48,
	[28583] = 84,
	[28584] = 84,
	[28586] = 84,
	[28587] = 24,
	[28588] = 84,
	[28589] = 84,
	[28590] = 84,
	[28591] = 84,
	[28592] = 84,
	[28593] = 84,
	[28594] = 84,
	[28595] = 84,
	[28596] = 84,
	[28597] = 84,
	[28598] = 84,
	[28599] = 84,
	[28600] = 24,
	[28601] = 45,
	[28602] = 83,
	[28603] = 24,
	[28604] = 24,
	[28605] = 24,
	[28606] = 5,
	[28607] = 5,
	[28608] = 1,
	[28609] = 52,
	[28610] = 52,
	[28611] = 84,
	[28612] = 83,
	[28613] = 83,
	[28614] = 52,
	[28615] = 52,
	[28616] = 24,
	[28618] = 52,
	[28619] = 25,
	[28620] = 25,
	[28621] = 83,
	[28622] = 83,
	[28623] = 84,
	[28624] = 52,
	[28625] = 52,
	[28626] = 52,
	[28627] = 52,
	[28628] = 52,
	[28629] = 52,
	[28630] = 52,
	[28631] = 52,
	[28632] = 52,
	[28633] = 83,
	[28634] = 25,
	[28635] = 25,
	[28636] = 25,
	[28637] = 53,
	[28638] = 53,
	[28639] = 53,
	[28640] = 53,
	[28641] = 53,
	[28643] = 25,
	[28644] = 25,
	[28645] = 25,
	[28646] = 25,
	[28647] = 25,
	[28649] = 55,
	[28650] = 55,
	[28651] = 3,
	[28652] = 1,
	[28653] = 2,
	[28654] = 83,
	[28655] = 84,
	[28656] = 51,
	[28657] = 85,
	[28658] = 85,
	[28659] = 85,
	[28660] = 85,
	[28661] = 85,
	[28662] = 85,
	[28663] = 85,
	[28664] = 85,
	[28665] = 85,
	[28666] = 50,
	[28667] = 50,
	[28668] = 85,
	[28669] = 85,
	[28670] = 85,
	[28671] = 55,
	[28672] = 3,
	[28673] = 55,
	[28674] = 53,
	[28675] = 52,
	[28676] = 53,
	[28677] = 52,
	[28678] = 85,
	[28679] = 85,
	[28680] = 85,
	[28681] = 85,
	[28682] = 85,
	[28683] = 85,
	[28684] = 85,
	[28685] = 85,
	[28686] = 85,
	[28687] = 85,
	[28688] = 25,
	[28689] = 85,
	[28690] = 85,
	[28691] = 85,
	[28692] = 85,
	[28693] = 85,
	[28694] = 85,
	[28695] = 85,
	[28696] = 85,
	[28697] = 85,
	[28698] = 85,
	[28699] = 25,
	[28700] = 85,
	[28701] = 53,
	[28702] = 30,
	[28703] = 53,
	[28704] = 30,
	[28705] = 60,
	[28706] = 53,
	[28707] = 53,
	[28708] = 60,
	[28709] = 70,
	[28710] = 53,
	[28711] = 70,
	[28712] = 85,
	[28713] = 2,
	[28714] = 3,
	[28715] = 3,
	[28716] = 84,
	[28717] = 84,
	[28718] = 53,
	[28719] = 53,
	[28721] = 85,
	[28722] = 52,
	[28723] = 3,
	[28724] = 3,
	[28725] = 3,
	[28726] = 4,
	[28727] = 4,
	[28728] = 5,
	[28729] = 5,
	[28730] = 5,
	[28731] = 5,
	[28732] = 82,
	[28734] = 3,
	[28735] = 82,
	[28736] = 83,
	[28737] = 82,
	[28738] = 82,
	[28740] = 82,
	[28741] = 82,
	[28742] = 53,
	[28743] = 83,
	[28745] = 53,
	[28746] = 83,
	[28749] = 35,
	[28750] = 35,
	[28753] = 83,
	[28755] = 46,
	[28756] = 42,
	[28757] = 3,
	[28758] = 85,
	[28759] = 3,
	[28760] = 84,
	[28762] = 3,
	[28763] = 3,
	[28764] = 3,
	[28765] = 3,
	[28766] = 3,
	[28767] = 3,
	[28768] = 50,
	[28769] = 3,
	[28770] = 3,
	[28771] = 3,
	[28772] = 3,
	[28773] = 3,
	[28774] = 3,
	[28779] = 84,
	[28780] = 3,
	[28781] = 85,
	[28782] = 53,
	[28783] = 85,
	[28784] = 3,
	[28785] = 3,
	[28786] = 3,
	[28787] = 3,
	[28788] = 3,
	[28789] = 3,
	[28790] = 80,
	[28791] = 3,
	[28792] = 3,
	[28793] = 3,
	[28794] = 3,
	[28795] = 3,
	[28796] = 3,
	[28797] = 3,
	[28805] = 80,
	[28806] = 3,
	[28807] = 84,
	[28808] = 3,
	[28809] = 3,
	[28810] = 3,
	[28811] = 3,
	[28812] = 3,
	[28813] = 3,
	[28814] = 84,
	[28815] = 84,
	[28816] = 80,
	[28817] = 4,
	[28818] = 4,
	[28819] = 4,
	[28820] = 4,
	[28821] = 4,
	[28822] = 4,
	[28823] = 4,
	[28824] = 84,
	[28825] = 80,
	[28826] = 80,
	[28827] = 80,
	[28828] = 53,
	[28829] = 54,
	[28830] = 54,
	[28831] = 54,
	[28832] = 84,
	[28833] = 82,
	[28834] = 82,
	[28836] = 82,
	[28837] = 54,
	[28838] = 54,
	[28839] = 54,
	[28840] = 54,
	[28841] = 55,
	[28842] = 55,
	[28843] = 82,
	[28845] = 84,
	[28847] = 54,
	[28848] = 51,
	[28849] = 84,
	[28850] = 3,
	[28852] = 85,
	[28853] = 85,
	[28854] = 85,
	[28856] = 55,
	[28857] = 55,
	[28858] = 55,
	[28859] = 55,
	[28860] = 84,
	[28861] = 84,
	[28862] = 84,
	[28863] = 84,
	[28864] = 84,
	[28865] = 54,
	[28866] = 83,
	[28867] = 54,
	[28868] = 7,
	[28869] = 83,
	[28870] = 85,
	[28871] = 84,
	[28872] = 84,
	[28873] = 84,
	[28874] = 84,
	[28875] = 84,
	[28876] = 20,
	[28877] = 15,
	[28881] = 48,
	[28882] = 90,
	[28884] = 90,
	[28885] = 85,
	[28905] = 85,
	[28906] = 85,
	[28907] = 85,
	[28908] = 85,
	[28909] = 84,
	[29015] = 16,
	[29021] = 16,
	[29022] = 16,
	[29023] = 16,
	[29024] = 16,
	[29026] = 16,
	[29027] = 16,
	[29028] = 46,
	[29029] = 46,
	[29033] = 53,
	[29066] = 81,
	[29071] = 80,
	[29073] = 80,
	[29078] = 3,
	[29079] = 3,
	[29080] = 3,
	[29081] = 3,
	[29082] = 3,
	[29083] = 4,
	[29084] = 45,
	[29085] = 45,
	[29086] = 16,
	[29087] = 16,
	[29088] = 16,
	[29089] = 16,
	[29090] = 16,
	[29091] = 17,
	[29094] = 16,
	[29095] = 16,
	[29098] = 17,
	[29100] = 85,
	[29101] = 85,
	[29102] = 85,
	[29103] = 85,
	[29104] = 85,
	[29105] = 85,
	[29109] = 17,
	[29110] = 17,
	[29111] = 17,
	[29112] = 17,
	[29114] = 85,
	[29115] = 85,
	[29118] = 85,
	[29120] = 85,
	[29121] = 85,
	[29122] = 85,
	[29123] = 85,
	[29124] = 85,
	[29125] = 85,
	[29126] = 85,
	[29127] = 85,
	[29128] = 85,
	[29129] = 85,
	[29131] = 85,
	[29132] = 85,
	[29133] = 85,
	[29134] = 85,
	[29135] = 85,
	[29137] = 85,
	[29138] = 85,
	[29139] = 85,
	[29141] = 85,
	[29142] = 85,
	[29143] = 85,
	[29145] = 85,
	[29147] = 85,
	[29148] = 85,
	[29149] = 85,
	[29150] = 85,
	[29151] = 85,
	[29152] = 85,
	[29153] = 85,
	[29154] = 85,
	[29155] = 85,
	[29156] = 85,
	[29157] = 85,
	[29158] = 85,
	[29159] = 85,
	[29160] = 85,
	[29161] = 85,
	[29162] = 85,
	[29163] = 85,
	[29164] = 85,
	[29165] = 85,
	[29166] = 85,
	[29168] = 85,
	[29169] = 85,
	[29172] = 85,
	[29173] = 85,
	[29174] = 85,
	[29175] = 85,
	[29177] = 81,
	[29179] = 85,
	[29180] = 85,
	[29181] = 85,
	[29182] = 85,
	[29183] = 85,
	[29184] = 85,
	[29185] = 85,
	[29186] = 85,
	[29187] = 85,
	[29188] = 85,
	[29189] = 85,
	[29192] = 85,
	[29193] = 85,
	[29194] = 85,
	[29195] = 85,
	[29196] = 85,
	[29197] = 85,
	[29198] = 85,
	[29199] = 85,
	[29200] = 85,
	[29201] = 85,
	[29202] = 85,
	[29203] = 85,
	[29204] = 85,
	[29205] = 85,
	[29206] = 85,
	[29208] = 85,
	[29209] = 85,
	[29210] = 85,
	[29211] = 85,
	[29213] = 85,
	[29214] = 85,
	[29215] = 85,
	[29217] = 85,
	[29219] = 85,
	[29220] = 85,
	[29221] = 85,
	[29222] = 85,
	[29223] = 85,
	[29225] = 85,
	[29226] = 85,
	[29227] = 85,
	[29229] = 85,
	[29230] = 85,
	[29231] = 85,
	[29232] = 85,
	[29233] = 85,
	[29234] = 85,
	[29235] = 85,
	[29236] = 85,
	[29237] = 85,
	[29238] = 85,
	[29239] = 85,
	[29240] = 85,
	[29241] = 85,
	[29242] = 85,
	[29243] = 85,
	[29244] = 85,
	[29245] = 85,
	[29246] = 85,
	[29247] = 85,
	[29248] = 85,
	[29249] = 85,
	[29250] = 85,
	[29251] = 85,
	[29252] = 85,
	[29253] = 85,
	[29254] = 85,
	[29255] = 85,
	[29257] = 85,
	[29263] = 85,
	[29264] = 85,
	[29265] = 85,
	[29267] = 85,
	[29268] = 85,
	[29269] = 85,
	[29270] = 85,
	[29272] = 85,
	[29273] = 85,
	[29274] = 85,
	[29275] = 85,
	[29276] = 85,
	[29278] = 85,
	[29279] = 85,
	[29280] = 85,
	[29281] = 85,
	[29282] = 85,
	[29283] = 85,
	[29284] = 85,
	[29285] = 85,
	[29287] = 85,
	[29288] = 85,
	[29289] = 85,
	[29290] = 85,
	[29293] = 85,
	[29295] = 85,
	[29296] = 85,
	[29297] = 85,
	[29298] = 85,
	[29299] = 85,
	[29302] = 85,
	[29303] = 85,
	[29304] = 85,
	[29305] = 85,
	[29307] = 85,
	[29308] = 85,
	[29309] = 85,
	[29310] = 85,
	[29311] = 85,
	[29312] = 85,
	[29326] = 85,
	[29327] = 85,
	[29328] = 85,
	[29329] = 85,
	[29330] = 85,
	[29331] = 85,
	[29335] = 85,
	[29336] = 85,
	[29337] = 85,
	[29338] = 85,
	[29339] = 85,
	[29372] = 85,
	[29373] = 85,
	[29386] = 80,
	[29387] = 85,
	[29388] = 85,
	[29389] = 85,
	[29390] = 85,
	[29391] = 85,
	[29401] = 20,
	[29406] = 2,
	[29408] = 2,
	[29409] = 2,
	[29410] = 2,
	[29412] = 20,
	[29414] = 3,
	[29417] = 4,
	[29418] = 4,
	[29419] = 3,
	[29420] = 4,
	[29421] = 4,
	[29422] = 4,
	[29423] = 5,
	[29424] = 3,
	[29432] = 85,
	[29437] = 85,
	[29439] = 85,
	[29440] = 85,
	[29441] = 19,
	[29451] = 85,
	[29452] = 85,
	[29453] = 85,
	[29464] = 85,
	[29521] = 5,
	[29522] = 3,
	[29523] = 4,
	[29524] = 2,
	[29527] = 62,
	[29528] = 62,
	[29529] = 62,
	[29530] = 62,
	[29531] = 85,
	[29534] = 85,
	[29535] = 63,
	[29536] = 63,
	[29537] = 63,
	[29538] = 63,
	[29539] = 63,
	[29540] = 63,
	[29541] = 85,
	[29542] = 62,
	[29543] = 62,
	[29547] = 86,
	[29548] = 86,
	[29552] = 86,
	[29553] = 86,
	[29555] = 86,
	[29556] = 86,
	[29558] = 86,
	[29559] = 86,
	[29560] = 86,
	[29562] = 86,
	[29563] = 65,
	[29564] = 65,
	[29565] = 65,
	[29566] = 65,
	[29567] = 65,
	[29568] = 65,
	[29570] = 65,
	[29571] = 65,
	[29573] = 66,
	[29574] = 66,
	[29575] = 66,
	[29576] = 86,
	[29577] = 87,
	[29578] = 86,
	[29579] = 86,
	[29580] = 86,
	[29581] = 87,
	[29582] = 66,
	[29583] = 66,
	[29585] = 86,
	[29586] = 86,
	[29587] = 86,
	[29590] = 67,
	[29591] = 67,
	[29593] = 62,
	[29594] = 62,
	[29595] = 67,
	[29596] = 67,
	[29598] = 68,
	[29599] = 68,
	[29600] = 87,
	[29605] = 69,
	[29606] = 69,
	[29607] = 69,
	[29608] = 70,
	[29609] = 70,
	[29611] = 86,
	[29612] = 86,
	[29613] = 70,
	[29614] = 70,
	[29615] = 70,
	[29616] = 69,
	[29617] = 85,
	[29618] = 86,
	[29619] = 86,
	[29620] = 86,
	[29622] = 86,
	[29623] = 86,
	[29624] = 86,
	[29626] = 86,
	[29627] = 86,
	[29628] = 86,
	[29629] = 86,
	[29630] = 86,
	[29631] = 86,
	[29632] = 86,
	[29633] = 86,
	[29634] = 86,
	[29635] = 86,
	[29636] = 86,
	[29637] = 86,
	[29639] = 86,
	[29640] = 70,
	[29641] = 70,
	[29642] = 70,
	[29643] = 70,
	[29644] = 70,
	[29645] = 70,
	[29646] = 86,
	[29647] = 86,
	[29649] = 70,
	[29650] = 70,
	[29651] = 70,
	[29652] = 70,
	[29653] = 70,
	[29654] = 70,
	[29655] = 70,
	[29656] = 70,
	[29657] = 70,
	[29658] = 70,
	[29659] = 70,
	[29660] = 70,
	[29661] = 5,
	[29662] = 5,
	[29663] = 5,
	[29664] = 4,
	[29665] = 9,
	[29666] = 5,
	[29667] = 70,
	[29669] = 70,
	[29670] = 86,
	[29674] = 70,
	[29675] = 70,
	[29676] = 5,
	[29677] = 5,
	[29678] = 5,
	[29679] = 5,
	[29680] = 5,
	[29681] = 70,
	[29682] = 70,
	[29684] = 70,
	[29685] = 70,
	[29686] = 70,
	[29687] = 70,
	[29688] = 70,
	[29689] = 70,
	[29690] = 86,
	[29691] = 65,
	[29692] = 65,
	[29694] = 86,
	[29716] = 86,
	[29717] = 86,
	[29723] = 86,
	[29725] = 86,
	[29726] = 86,
	[29727] = 86,
	[29730] = 86,
	[29731] = 86,
	[29733] = 86,
	[29743] = 86,
	[29745] = 86,
	[29747] = 86,
	[29748] = 86,
	[29749] = 86,
	[29750] = 86,
	[29751] = 86,
	[29752] = 86,
	[29753] = 86,
	[29754] = 86,
	[29755] = 86,
	[29756] = 86,
	[29757] = 87,
	[29758] = 87,
	[29759] = 86,
	[29760] = 85,
	[29761] = 85,
	[29762] = 86,
	[29763] = 71,
	[29764] = 71,
	[29765] = 86,
	[29768] = 6,
	[29769] = 6,
	[29770] = 6,
	[29771] = 6,
	[29772] = 6,
	[29774] = 6,
	[29775] = 6,
	[29776] = 6,
	[29777] = 7,
	[29778] = 7,
	[29779] = 7,
	[29780] = 7,
	[29781] = 7,
	[29782] = 7,
	[29783] = 7,
	[29784] = 7,
	[29785] = 7,
	[29786] = 7,
	[29787] = 8,
	[29788] = 8,
	[29789] = 8,
	[29790] = 8,
	[29791] = 8,
	[29792] = 9,
	[29793] = 9,
	[29794] = 9,
	[29795] = 9,
	[29796] = 9,
	[29797] = 9,
	[29798] = 9,
	[29799] = 9,
	[29800] = 10,
	[29801] = 85,
	[29802] = 85,
	[29803] = 71,
	[29804] = 86,
	[29807] = 74,
	[29808] = 74,
	[29809] = 83,
	[29811] = 74,
	[29815] = 86,
	[29820] = 71,
	[29821] = 86,
	[29822] = 86,
	[29823] = 86,
	[29824] = 86,
	[29825] = 76,
	[29826] = 76,
	[29827] = 86,
	[29828] = 74,
	[29829] = 77,
	[29830] = 77,
	[29833] = 78,
	[29834] = 78,
	[29835] = 78,
	[29836] = 78,
	[29838] = 78,
	[29839] = 78,
	[29840] = 78,
	[29844] = 78,
	[29847] = 85,
	[29848] = 78,
	[29850] = 78,
	[29851] = 78,
	[29860] = 80,
	[29861] = 80,
	[29862] = 80,
	[29863] = 80,
	[29864] = 80,
	[29865] = 86,
	[29866] = 86,
	[29867] = 85,
	[29871] = 87,
	[29872] = 87,
	[29873] = 85,
	[29874] = 85,
	[29875] = 85,
	[29877] = 87,
	[29879] = 86,
	[29881] = 86,
	[29882] = 86,
	[29883] = 86,
	[29885] = 86,
	[29887] = 86,
	[29888] = 86,
	[29889] = 86,
	[29890] = 86,
	[29891] = 86,
	[29892] = 86,
	[29893] = 86,
	[29894] = 86,
	[29898] = 86,
	[29899] = 86,
	[29900] = 86,
	[29901] = 86,
	[29903] = 86,
	[29904] = 86,
	[29905] = 86,
	[29906] = 86,
	[29907] = 87,
	[29908] = 87,
	[29909] = 87,
	[29910] = 87,
	[29911] = 87,
	[29912] = 87,
	[29913] = 87,
	[29914] = 87,
	[29915] = 87,
	[29916] = 87,
	[29917] = 87,
	[29918] = 87,
	[29919] = 87,
	[29920] = 86,
	[29922] = 86,
	[29924] = 86,
	[29925] = 86,
	[29926] = 86,
	[29927] = 86,
	[29928] = 86,
	[29929] = 86,
	[29930] = 86,
	[29931] = 86,
	[29932] = 86,
	[29933] = 86,
	[29934] = 85,
	[29935] = 86,
	[29936] = 86,
	[29937] = 86,
	[29939] = 86,
	[29940] = 87,
	[29941] = 86,
	[29942] = 86,
	[29943] = 86,
	[29944] = 87,
	[29945] = 87,
	[29946] = 87,
	[29947] = 87,
	[29948] = 87,
	[29949] = 87,
	[29950] = 87,
	[29951] = 87,
	[29952] = 87,
	[29966] = 86,
	[29967] = 86,
	[29968] = 86,
	[29971] = 86,
	[29981] = 87,
	[29982] = 87,
	[29983] = 87,
	[29984] = 87,
	[29985] = 87,
	[29986] = 87,
	[29987] = 87,
	[29988] = 87,
	[29989] = 87,
	[29990] = 87,
	[29992] = 87,
	[29993] = 86,
	[29995] = 86,
	[29997] = 86,
	[29998] = 86,
	[29999] = 86,
	[30000] = 86,
	[30001] = 86,
	[30002] = 86,
	[30004] = 86,
	[30005] = 86,
	[30006] = 90,
	[30011] = 86,
	[30015] = 86,
	[30027] = 1,
	[30028] = 87,
	[30029] = 87,
	[30030] = 87,
	[30031] = 87,
	[30032] = 87,
	[30033] = 1,
	[30034] = 1,
	[30035] = 1,
	[30036] = 1,
	[30037] = 1,
	[30038] = 1,
	[30039] = 1,
	[30040] = 1,
	[30041] = 1,
	[30042] = 1,
	[30043] = 1,
	[30044] = 1,
	[30045] = 1,
	[30046] = 87,
	[30047] = 87,
	[30048] = 87,
	[30049] = 87,
	[30050] = 87,
	[30051] = 87,
	[30052] = 87,
	[30053] = 87,
	[30054] = 87,
	[30055] = 87,
	[30056] = 87,
	[30057] = 87,
	[30058] = 87,
	[30059] = 87,
	[30063] = 90,
	[30064] = 90,
	[30065] = 90,
	[30066] = 90,
	[30067] = 90,
	[30068] = 90,
	[30069] = 86,
	[30070] = 86,
	[30072] = 87,
	[30073] = 87,
	[30074] = 87,
	[30075] = 87,
	[30076] = 87,
	[30077] = 87,
	[30078] = 87,
	[30079] = 86,
	[30080] = 86,
	[30081] = 86,
	[30082] = 86,
	[30083] = 86,
	[30084] = 86,
	[30085] = 87,
	[30086] = 87,
	[30088] = 86,
	[30089] = 86,
	[30090] = 86,
	[30091] = 86,
	[30092] = 85,
	[30093] = 85,
	[30094] = 85,
	[30095] = 85,
	[30096] = 85,
	[30097] = 85,
	[30098] = 85,
	[30099] = 85,
	[30100] = 85,
	[30101] = 85,
	[30102] = 85,
	[30103] = 85,
	[30104] = 85,
	[30105] = 85,
	[30106] = 85,
	[30107] = 85,
	[30108] = 85,
	[30109] = 85,
	[30110] = 85,
	[30111] = 85,
	[30112] = 71,
	[30113] = 85,
	[30116] = 85,
	[30117] = 87,
	[30118] = 85,
	[30119] = 85,
	[30120] = 75,
	[30121] = 86,
	[30123] = 86,
	[30124] = 86,
	[30127] = 86,
	[30128] = 86,
	[30129] = 86,
	[30130] = 86,
	[30131] = 86,
	[30132] = 87,
	[30133] = 86,
	[30134] = 90,
	[30135] = 90,
	[30136] = 90,
	[30137] = 90,
	[30138] = 90,
	[30139] = 90,
	[30140] = 90,
	[30141] = 90,
	[30142] = 90,
	[30143] = 90,
	[30144] = 90,
	[30145] = 90,
	[30146] = 90,
	[30147] = 90,
	[30148] = 90,
	[30149] = 90,
	[30150] = 90,
	[30151] = 90,
	[30152] = 90,
	[30154] = 90,
	[30155] = 90,
	[30156] = 90,
	[30157] = 90,
	[30158] = 90,
	[30159] = 90,
	[30160] = 90,
	[30163] = 87,
	[30164] = 87,
	[30168] = 87,
	[30169] = 87,
	[30172] = 87,
	[30174] = 87,
	[30175] = 87,
	[30177] = 85,
	[30178] = 86,
	[30179] = 86,
	[30181] = 87,
	[30182] = 87,
	[30183] = 87,
	[30184] = 87,
	[30185] = 87,
	[30186] = 87,
	[30187] = 90,
	[30188] = 90,
	[30189] = 90,
	[30229] = 87,
	[30230] = 87,
	[30240] = 90,
	[30241] = 87,
	[30242] = 90,
	[30243] = 90,
	[30252] = 87,
	[30254] = 87,
	[30255] = 87,
	[30256] = 87,
	[30257] = 87,
	[30258] = 90,
	[30259] = 90,
	[30260] = 90,
	[30261] = 90,
	[30266] = 90,
	[30267] = 87,
	[30268] = 87,
	[30269] = 87,
	[30270] = 87,
	[30271] = 87,
	[30272] = 87,
	[30273] = 87,
	[30274] = 87,
	[30275] = 87,
	[30277] = 90,
	[30280] = 90,
	[30306] = 90,
	[30317] = 90,
	[30318] = 90,
	[30319] = 90,
	[30321] = 90,
	[30322] = 90,
	[30323] = 90,
	[30324] = 90,
	[30325] = 90,
	[30326] = 90,
	[30327] = 90,
	[30328] = 90,
	[30329] = 90,
	[30330] = 90,
	[30331] = 90,
	[30332] = 90,
	[30333] = 90,
	[30334] = 90,
	[30335] = 90,
	[30336] = 90,
	[30337] = 90,
	[30343] = 85,
	[30344] = 87,
	[30346] = 87,
	[30347] = 87,
	[30348] = 87,
	[30349] = 87,
	[30350] = 87,
	[30351] = 87,
	[30352] = 87,
	[30353] = 87,
	[30354] = 87,
	[30355] = 87,
	[30356] = 87,
	[30357] = 87,
	[30358] = 85,
	[30359] = 87,
	[30360] = 87,
	[30361] = 88,
	[30362] = 85,
	[30363] = 87,
	[30364] = 85,
	[30376] = 87,
	[30377] = 85,
	[30378] = 85,
	[30379] = 90,
	[30380] = 90,
	[30381] = 90,
	[30382] = 90,
	[30383] = 90,
	[30384] = 87,
	[30386] = 90,
	[30387] = 90,
	[30388] = 90,
	[30389] = 90,
	[30390] = 90,
	[30391] = 90,
	[30392] = 90,
	[30393] = 90,
	[30394] = 90,
	[30395] = 90,
	[30396] = 90,
	[30397] = 90,
	[30398] = 90,
	[30399] = 90,
	[30400] = 90,
	[30401] = 90,
	[30402] = 90,
	[30403] = 90,
	[30404] = 90,
	[30405] = 90,
	[30406] = 90,
	[30407] = 90,
	[30408] = 90,
	[30409] = 90,
	[30410] = 90,
	[30411] = 90,
	[30412] = 90,
	[30413] = 90,
	[30414] = 90,
	[30416] = 90,
	[30417] = 90,
	[30418] = 90,
	[30419] = 90,
	[30420] = 90,
	[30421] = 90,
	[30422] = 90,
	[30423] = 90,
	[30424] = 90,
	[30425] = 90,
	[30426] = 90,
	[30427] = 90,
	[30428] = 90,
	[30429] = 90,
	[30430] = 90,
	[30431] = 90,
	[30432] = 90,
	[30433] = 90,
	[30434] = 90,
	[30435] = 90,
	[30436] = 90,
	[30437] = 90,
	[30438] = 90,
	[30439] = 90,
	[30445] = 87,
	[30449] = 90,
	[30450] = 90,
	[30451] = 90,
	[30452] = 90,
	[30457] = 87,
	[30459] = 87,
	[30460] = 87,
	[30461] = 86,
	[30462] = 86,
	[30464] = 87,
	[30465] = 87,
	[30466] = 86,
	[30467] = 87,
	[30468] = 87,
	[30469] = 87,
	[30470] = 90,
	[30471] = 90,
	[30472] = 90,
	[30473] = 90,
	[30474] = 90,
	[30475] = 90,
	[30476] = 90,
	[30477] = 90,
	[30478] = 90,
	[30479] = 90,
	[30480] = 87,
	[30484] = 86,
	[30485] = 86,
	[30487] = 88,
	[30488] = 88,
	[30489] = 88,
	[30490] = 88,
	[30491] = 88,
	[30492] = 88,
	[30495] = 86,
	[30496] = 87,
	[30498] = 86,
	[30499] = 86,
	[30500] = 86,
	[30502] = 86,
	[30504] = 86,
	[30506] = 87,
	[30507] = 87,
	[30508] = 87,
	[30509] = 87,
	[30510] = 87,
	[30511] = 87,
	[30512] = 87,
	[30513] = 87,
	[30514] = 87,
	[30515] = 87,
	[30516] = 90,
	[30517] = 90,
	[30518] = 90,
	[30519] = 90,
	[30521] = 90,
	[30522] = 90,
	[30523] = 90,
	[30524] = 90,
	[30525] = 90,
	[30526] = 90,
	[30527] = 90,
	[30528] = 90,
	[30529] = 90,
	[30534] = 90,
	[30535] = 87,
	[30565] = 86,
	[30567] = 90,
	[30568] = 86,
	[30569] = 87,
	[30570] = 87,
	[30571] = 87,
	[30575] = 87,
	[30581] = 87,
	[30582] = 88,
	[30583] = 87,
	[30587] = 88,
	[30589] = 9,
	[30590] = 9,
	[30591] = 9,
	[30592] = 88,
	[30593] = 87,
	[30594] = 87,
	[30595] = 87,
	[30596] = 87,
	[30599] = 88,
	[30600] = 88,
	[30601] = 88,
	[30602] = 88,
	[30603] = 88,
	[30604] = 88,
	[30605] = 88,
	[30606] = 88,
	[30607] = 88,
	[30608] = 88,
	[30610] = 88,
	[30611] = 88,
	[30612] = 88,
	[30614] = 88,
	[30615] = 87,
	[30616] = 88,
	[30617] = 88,
	[30618] = 88,
	[30619] = 87,
	[30620] = 87,
	[30621] = 88,
	[30622] = 87,
	[30623] = 87,
	[30624] = 87,
	[30625] = 87,
	[30626] = 87,
	[30627] = 87,
	[30628] = 87,
	[30648] = 86,
	[30650] = 87,
	[30651] = 87,
	[30652] = 87,
	[30653] = 87,
	[30655] = 87,
	[30656] = 87,
	[30657] = 87,
	[30660] = 87,
	[30661] = 87,
	[30662] = 87,
	[30663] = 87,
	[30665] = 87,
	[30666] = 87,
	[30667] = 87,
	[30668] = 87,
	[30669] = 87,
	[30670] = 87,
	[30671] = 87,
	[30672] = 87,
	[30673] = 87,
	[30674] = 87,
	[30675] = 87,
	[30677] = 87,
	[30680] = 87,
	[30681] = 87,
	[30682] = 87,
	[30683] = 88,
	[30684] = 88,
	[30690] = 87,
	[30691] = 87,
	[30692] = 88,
	[30694] = 87,
	[30695] = 87,
	[30699] = 88,
	[30710] = 87,
	[30714] = 87,
	[30715] = 88,
	[30716] = 90,
	[30717] = 90,
	[30718] = 90,
	[30719] = 90,
	[30720] = 90,
	[30721] = 90,
	[30722] = 90,
	[30723] = 88,
	[30724] = 88,
	[30725] = 90,
	[30726] = 90,
	[30727] = 90,
	[30728] = 90,
	[30729] = 90,
	[30730] = 90,
	[30731] = 90,
	[30732] = 90,
	[30733] = 90,
	[30734] = 90,
	[30735] = 90,
	[30736] = 90,
	[30737] = 90,
	[30738] = 90,
	[30739] = 90,
	[30740] = 90,
	[30742] = 88,
	[30743] = 88,
	[30744] = 88,
	[30745] = 88,
	[30746] = 88,
	[30747] = 88,
	[30750] = 88,
	[30751] = 88,
	[30752] = 88,
	[30757] = 89,
	[30759] = 89,
	[30765] = 88,
	[30766] = 87,
	[30767] = 9,
	[30768] = 89,
	[30769] = 89,
	[30770] = 89,
	[30771] = 89,
	[30772] = 89,
	[30773] = 89,
	[30774] = 89,
	[30775] = 89,
	[30776] = 89,
	[30777] = 89,
	[30778] = 89,
	[30779] = 89,
	[30780] = 89,
	[30781] = 89,
	[30782] = 89,
	[30783] = 89,
	[30784] = 89,
	[30785] = 89,
	[30786] = 89,
	[30787] = 89,
	[30788] = 89,
	[30789] = 89,
	[30790] = 89,
	[30791] = 89,
	[30792] = 89,
	[30793] = 89,
	[30794] = 87,
	[30795] = 88,
	[30796] = 88,
	[30797] = 88,
	[30798] = 88,
	[30799] = 88,
	[30800] = 88,
	[30801] = 88,
	[30802] = 88,
	[30804] = 88,
	[30805] = 87,
	[30806] = 87,
	[30807] = 87,
	[30808] = 88,
	[30814] = 89,
	[30815] = 89,
	[30816] = 87,
	[30819] = 87,
	[30820] = 87,
	[30821] = 88,
	[30823] = 88,
	[30824] = 88,
	[30825] = 88,
	[30826] = 88,
	[30827] = 89,
	[30828] = 87,
	[30829] = 88,
	[30834] = 87,
	[30855] = 87,
	[30879] = 90,
	[30880] = 90,
	[30881] = 90,
	[30882] = 90,
	[30883] = 90,
	[30884] = 89,
	[30885] = 90,
	[30887] = 89,
	[30888] = 89,
	[30889] = 89,
	[30890] = 89,
	[30891] = 89,
	[30892] = 89,
	[30893] = 89,
	[30894] = 89,
	[30895] = 89,
	[30896] = 89,
	[30897] = 89,
	[30898] = 89,
	[30899] = 89,
	[30900] = 89,
	[30901] = 89,
	[30902] = 90,
	[30907] = 90,
	[30910] = 90,
	[30918] = 90,
	[30921] = 89,
	[30922] = 89,
	[30923] = 89,
	[30924] = 89,
	[30925] = 89,
	[30926] = 89,
	[30927] = 89,
	[30928] = 89,
	[30929] = 89,
	[30930] = 89,
	[30931] = 89,
	[30932] = 89,
	[30933] = 90,
	[30935] = 88,
	[30942] = 88,
	[30943] = 88,
	[30944] = 88,
	[30945] = 88,
	[30946] = 88,
	[30952] = 90,
	[30953] = 90,
	[30954] = 90,
	[30955] = 90,
	[30956] = 90,
	[30957] = 90,
	[30958] = 90,
	[30959] = 90,
	[30960] = 89,
	[30963] = 89,
	[30964] = 89,
	[30967] = 87,
	[30968] = 89,
	[30969] = 16,
	[30970] = 89,
	[30971] = 89,
	[30972] = 89,
	[30973] = 89,
	[30974] = 89,
	[30975] = 89,
	[30976] = 89,
	[30977] = 89,
	[30978] = 89,
	[30979] = 89,
	[30980] = 89,
	[30981] = 89,
	[30982] = 16,
	[30983] = 16,
	[30984] = 16,
	[30987] = 10,
	[30988] = 10,
	[30989] = 10,
	[30991] = 88,
	[30992] = 88,
	[30993] = 88,
	[30994] = 88,
	[30995] = 16,
	[30996] = 16,
	[30997] = 16,
	[30998] = 16,
	[30999] = 88,
	[31000] = 90,
	[31001] = 90,
	[31002] = 90,
	[31003] = 90,
	[31004] = 90,
	[31005] = 90,
	[31006] = 90,
	[31007] = 90,
	[31008] = 90,
	[31009] = 90,
	[31010] = 90,
	[31011] = 88,
	[31012] = 10,
	[31013] = 10,
	[31014] = 10,
	[31015] = 90,
	[31016] = 90,
	[31018] = 90,
	[31019] = 90,
	[31020] = 90,
	[31021] = 90,
	[31022] = 90,
	[31023] = 90,
	[31024] = 90,
	[31026] = 90,
	[31030] = 88,
	[31031] = 88,
	[31032] = 89,
	[31034] = 15,
	[31036] = 15,
	[31037] = 15,
	[31038] = 90,
	[31039] = 90,
	[31040] = 90,
	[31041] = 90,
	[31042] = 90,
	[31043] = 90,
	[31044] = 90,
	[31045] = 90,
	[31046] = 90,
	[31047] = 90,
	[31048] = 90,
	[31049] = 90,
	[31050] = 90,
	[31051] = 90,
	[31052] = 90,
	[31053] = 90,
	[31054] = 90,
	[31055] = 90,
	[31058] = 90,
	[31061] = 90,
	[31062] = 90,
	[31063] = 89,
	[31064] = 89,
	[31065] = 89,
	[31066] = 90,
	[31067] = 90,
	[31068] = 90,
	[31069] = 90,
	[31070] = 90,
	[31071] = 90,
	[31072] = 90,
	[31073] = 90,
	[31074] = 90,
	[31075] = 90,
	[31076] = 90,
	[31077] = 90,
	[31078] = 90,
	[31079] = 90,
	[31080] = 90,
	[31081] = 90,
	[31082] = 90,
	[31083] = 90,
	[31084] = 90,
	[31085] = 90,
	[31086] = 90,
	[31087] = 90,
	[31088] = 90,
	[31089] = 90,
	[31090] = 90,
	[31091] = 90,
	[31092] = 90,
	[31093] = 90,
	[31094] = 90,
	[31095] = 90,
	[31096] = 90,
	[31097] = 90,
	[31100] = 90,
	[31102] = 90,
	[31103] = 90,
	[31104] = 90,
	[31105] = 90,
	[31106] = 90,
	[31107] = 90,
	[31108] = 90,
	[31109] = 90,
	[31110] = 90,
	[31111] = 90,
	[31112] = 86,
	[31113] = 90,
	[31114] = 90,
	[31115] = 1,
	[31116] = 90,
	[31117] = 90,
	[31118] = 90,
	[31119] = 90,
	[31120] = 90,
	[31121] = 86,
	[31122] = 90,
	[31123] = 90,
	[31124] = 90,
	[31125] = 90,
	[31126] = 90,
	[31127] = 90,
	[31128] = 90,
	[31129] = 90,
	[31130] = 86,
	[31132] = 86,
	[31133] = 90,
	[31134] = 86,
	[31135] = 1,
	[31137] = 2,
	[31138] = 3,
	[31139] = 3,
	[31140] = 3,
	[31141] = 3,
	[31142] = 3,
	[31143] = 3,
	[31144] = 3,
	[31145] = 4,
	[31146] = 3,
	[31147] = 3,
	[31148] = 3,
	[31150] = 3,
	[31151] = 3,
	[31152] = 86,
	[31156] = 3,
	[31157] = 3,
	[31158] = 2,
	[31159] = 2,
	[31160] = 3,
	[31161] = 3,
	[31162] = 3,
	[31163] = 3,
	[31165] = 3,
	[31166] = 3,
	[31167] = 86,
	[31168] = 3,
	[31169] = 3,
	[31170] = 3,
	[31171] = 3,
	[31172] = 3,
	[31173] = 3,
	[31175] = 90,
	[31176] = 90,
	[31177] = 90,
	[31178] = 90,
	[31179] = 90,
	[31181] = 90,
	[31182] = 90,
	[31183] = 90,
	[31184] = 90,
	[31185] = 90,
	[31186] = 90,
	[31187] = 90,
	[31188] = 90,
	[31189] = 90,
	[31190] = 90,
	[31194] = 90,
	[31195] = 85,
	[31196] = 90,
	[31197] = 90,
	[31198] = 90,
	[31199] = 90,
	[31200] = 90,
	[31201] = 90,
	[31203] = 90,
	[31204] = 90,
	[31206] = 85,
	[31207] = 90,
	[31208] = 90,
	[31209] = 90,
	[31210] = 90,
	[31211] = 90,
	[31216] = 90,
	[31220] = 90,
	[31221] = 90,
	[31228] = 88,
	[31230] = 86,
	[31231] = 90,
	[31232] = 90,
	[31233] = 90,
	[31234] = 90,
	[31235] = 90,
	[31237] = 90,
	[31238] = 90,
	[31239] = 86,
	[31241] = 86,
	[31251] = 87,
	[31252] = 87,
	[31253] = 87,
	[31254] = 87,
	[31255] = 87,
	[31256] = 87,
	[31260] = 86,
	[31261] = 86,
	[31262] = 86,
	[31265] = 90,
	[31266] = 90,
	[31267] = 90,
	[31268] = 90,
	[31269] = 90,
	[31270] = 90,
	[31271] = 90,
	[31272] = 90,
	[31274] = 90,
	[31275] = 90,
	[31277] = 90,
	[31279] = 90,
	[31281] = 90,
	[31284] = 1,
	[31285] = 87,
	[31286] = 87,
	[31287] = 87,
	[31288] = 90,
	[31289] = 90,
	[31291] = 90,
	[31292] = 1,
	[31302] = 90,
	[31303] = 86,
	[31304] = 1,
	[31306] = 88,
	[31307] = 1,
	[31311] = 90,
	[31312] = 90,
	[31313] = 90,
	[31314] = 90,
	[31315] = 90,
	[31319] = 86,
	[31320] = 90,
	[31321] = 90,
	[31322] = 90,
	[31323] = 90,
	[31324] = 87,
	[31325] = 90,
	[31326] = 90,
	[31327] = 87,
	[31328] = 90,
	[31329] = 90,
	[31332] = 90,
	[31333] = 90,
	[31334] = 90,
	[31335] = 90,
	[31336] = 90,
	[31337] = 90,
	[31338] = 90,
	[31339] = 90,
	[31340] = 90,
	[31341] = 90,
	[31342] = 89,
	[31354] = 90,
	[31355] = 87,
	[31356] = 87,
	[31357] = 89,
	[31359] = 90,
	[31360] = 89,
	[31362] = 86,
	[31363] = 90,
	[31364] = 90,
	[31365] = 90,
	[31366] = 90,
	[31367] = 90,
	[31368] = 90,
	[31369] = 90,
	[31370] = 90,
	[31372] = 90,
	[31373] = 90,
	[31374] = 90,
	[31375] = 90,
	[31376] = 90,
	[31377] = 90,
	[31378] = 90,
	[31379] = 90,
	[31380] = 90,
	[31381] = 90,
	[31382] = 90,
	[31383] = 90,
	[31384] = 90,
	[31385] = 90,
	[31386] = 89,
	[31387] = 90,
	[31388] = 89,
	[31389] = 90,
	[31390] = 90,
	[31391] = 90,
	[31392] = 87,
	[31393] = 87,
	[31394] = 87,
	[31395] = 87,
	[31396] = 1,
	[31397] = 1,
	[31398] = 90,
	[31399] = 1,
	[31400] = 1,
	[31401] = 1,
	[31402] = 1,
	[31403] = 1,
	[31404] = 1,
	[31405] = 1,
	[31406] = 1,
	[31407] = 1,
	[31408] = 1,
	[31409] = 1,
	[31410] = 1,
	[31411] = 1,
	[31412] = 1,
	[31413] = 1,
	[31414] = 1,
	[31415] = 1,
	[31416] = 1,
	[31417] = 1,
	[31418] = 1,
	[31419] = 1,
	[31420] = 1,
	[31421] = 1,
	[31422] = 1,
	[31423] = 1,
	[31424] = 1,
	[31425] = 1,
	[31426] = 1,
	[31427] = 1,
	[31428] = 1,
	[31429] = 1,
	[31430] = 1,
	[31431] = 1,
	[31432] = 1,
	[31433] = 1,
	[31434] = 1,
	[31435] = 1,
	[31436] = 1,
	[31437] = 1,
	[31438] = 1,
	[31439] = 90,
	[31440] = 43,
	[31441] = 90,
	[31442] = 90,
	[31447] = 43,
	[31448] = 90,
	[31450] = 10,
	[31451] = 87,
	[31452] = 87,
	[31453] = 87,
	[31454] = 90,
	[31455] = 87,
	[31456] = 87,
	[31457] = 87,
	[31458] = 90,
	[31459] = 87,
	[31460] = 87,
	[31465] = 90,
	[31467] = 90,
	[31468] = 90,
	[31470] = 90,
	[31471] = 90,
	[31472] = 90,
	[31473] = 90,
	[31474] = 90,
	[31475] = 90,
	[31476] = 90,
	[31477] = 90,
	[31478] = 90,
	[31479] = 90,
	[31480] = 90,
	[31481] = 90,
	[31482] = 90,
	[31483] = 90,
	[31486] = 90,
	[31487] = 90,
	[31488] = 90,
	[31489] = 90,
	[31490] = 31,
	[31492] = 90,
	[31493] = 31,
	[31494] = 90,
	[31495] = 90,
	[31496] = 90,
	[31497] = 90,
	[31498] = 90,
	[31499] = 90,
	[31500] = 90,
	[31501] = 90,
	[31502] = 90,
	[31503] = 90,
	[31504] = 90,
	[31505] = 90,
	[31506] = 90,
	[31507] = 90,
	[31508] = 90,
	[31509] = 90,
	[31510] = 90,
	[31511] = 87,
	[31512] = 87,
	[31513] = 34,
	[31514] = 34,
	[31515] = 90,
	[31516] = 90,
	[31517] = 90,
	[31518] = 87,
	[31519] = 90,
	[31520] = 90,
	[31521] = 90,
	[31522] = 90,
	[31523] = 90,
	[31524] = 90,
	[31525] = 90,
	[31526] = 90,
	[31527] = 90,
	[31528] = 90,
	[31529] = 90,
	[31530] = 90,
	[31531] = 90,
	[31532] = 90,
	[31534] = 90,
	[31535] = 90,
	[31536] = 90,
	[31537] = 90,
	[31538] = 90,
	[31539] = 90,
	[31540] = 90,
	[31541] = 90,
	[31542] = 90,
	[31543] = 90,
	[31544] = 90,
	[31598] = 90,
	[31599] = 90,
	[31603] = 90,
	[31605] = 90,
	[31606] = 90,
	[31609] = 90,
	[31611] = 90,
	[31612] = 90,
	[31613] = 90,
	[31614] = 90,
	[31615] = 90,
	[31616] = 90,
	[31617] = 90,
	[31618] = 90,
	[31619] = 90,
	[31620] = 90,
	[31621] = 90,
	[31622] = 90,
	[31623] = 90,
	[31624] = 90,
	[31625] = 90,
	[31626] = 90,
	[31627] = 90,
	[31628] = 90,
	[31629] = 90,
	[31630] = 90,
	[31631] = 90,
	[31632] = 90,
	[31633] = 90,
	[31634] = 90,
	[31635] = 90,
	[31636] = 90,
	[31637] = 90,
	[31638] = 90,
	[31639] = 90,
	[31640] = 90,
	[31641] = 90,
	[31642] = 90,
	[31643] = 90,
	[31644] = 90,
	[31645] = 90,
	[31646] = 90,
	[31647] = 90,
	[31648] = 90,
	[31649] = 90,
	[31650] = 90,
	[31651] = 90,
	[31652] = 90,
	[31654] = 87,
	[31656] = 90,
	[31660] = 90,
	[31661] = 90,
	[31665] = 1,
	[31666] = 1,
	[31669] = 90,
	[31670] = 90,
	[31671] = 90,
	[31672] = 90,
	[31673] = 90,
	[31674] = 90,
	[31675] = 90,
	[31676] = 90,
	[31677] = 90,
	[31679] = 90,
	[31680] = 90,
	[31681] = 90,
	[31682] = 90,
	[31687] = 89,
	[31688] = 89,
	[31689] = 90,
	[31690] = 90,
	[31691] = 90,
	[31692] = 90,
	[31695] = 88,
	[31698] = 90,
	[31699] = 90,
	[31700] = 90,
	[31701] = 90,
	[31702] = 90,
	[31703] = 90,
	[31704] = 90,
	[31705] = 90,
	[31706] = 90,
	[31707] = 90,
	[31708] = 90,
	[31709] = 90,
	[31710] = 90,
	[31711] = 90,
	[31712] = 90,
	[31713] = 90,
	[31714] = 90,
	[31715] = 90,
	[31716] = 90,
	[31717] = 90,
	[31718] = 90,
	[31719] = 90,
	[31720] = 90,
	[31721] = 90,
	[31727] = 90,
	[31730] = 90,
	[31732] = 86,
	[31733] = 86,
	[31734] = 86,
	[31735] = 86,
	[31736] = 86,
	[31737] = 86,
	[31738] = 86,
	[31739] = 86,
	[31740] = 86,
	[31741] = 86,
	[31742] = 86,
	[31743] = 86,
	[31744] = 86,
	[31745] = 86,
	[31765] = 86,
	[31766] = 86,
	[31767] = 86,
	[31768] = 86,
	[31769] = 86,
	[31770] = 86,
	[31771] = 86,
	[31772] = 86,
	[31773] = 86,
	[31774] = 86,
	[31775] = 86,
	[31776] = 86,
	[31777] = 86,
	[31778] = 86,
	[31779] = 86,
	[31782] = 90,
	[31784] = 90,
	[31786] = 90,
	[31787] = 90,
	[31788] = 90,
	[31789] = 90,
	[31790] = 90,
	[31791] = 90,
	[31792] = 90,
	[31793] = 90,
	[31794] = 90,
	[31795] = 90,
	[31796] = 90,
	[31797] = 90,
	[31798] = 90,
	[31799] = 90,
	[31800] = 90,
	[31801] = 90,
	[31802] = 90,
	[31803] = 90,
	[31804] = 90,
	[31805] = 90,
	[31808] = 90,
	[31809] = 90,
	[31810] = 90,
	[31811] = 90,
	[31820] = 90,
	[31847] = 90,
	[31853] = 86,
	[31863] = 1,
	[31864] = 1,
	[31865] = 1,
	[31866] = 1,
	[31867] = 1,
	[31868] = 1,
	[31869] = 1,
	[31876] = 90,
	[31877] = 90,
	[31886] = 90,
	[31894] = 89,
	[31895] = 90,
	[31936] = 90,
	[31937] = 90,
	[31938] = 90,
	[31941] = 90,
	[31942] = 90,
	[31943] = 90,
	[31945] = 87,
	[31946] = 90,
	[31947] = 90,
	[31948] = 90,
	[31949] = 90,
	[31959] = 90,
	[31978] = 86,
	[31988] = 90,
	[31998] = 90,
	[31999] = 86,
	[32000] = 90,
	[32001] = 90,
	[32002] = 90,
	[32003] = 90,
	[32004] = 90,
	[32005] = 90,
	[32006] = 90,
	[32007] = 90,
	[32018] = 87,
	[32019] = 87,
	[32030] = 90,
	[32035] = 87,
	[32038] = 87,
	[32045] = 87,
	[32097] = 90,
	[32098] = 90,
	[32099] = 90,
	[32105] = 90,
	[32108] = 90,
	[32109] = 90,
	[32112] = 1,
	[32113] = 1,
	[32115] = 90,
	[32116] = 90,
	[32118] = 90,
	[32119] = 90,
	[32120] = 90,
	[32121] = 90,
	[32122] = 90,
	[32123] = 90,
	[32126] = 90,
	[32127] = 90,
	[32128] = 90,
	[32130] = 90,
	[32131] = 90,
	[32132] = 90,
	[32133] = 90,
	[32134] = 90,
	[32135] = 90,
	[32136] = 90,
	[32137] = 90,
	[32138] = 90,
	[32139] = 90,
	[32140] = 90,
	[32141] = 90,
	[32142] = 90,
	[32143] = 90,
	[32144] = 90,
	[32145] = 90,
	[32146] = 90,
	[32147] = 90,
	[32148] = 90,
	[32149] = 90,
	[32150] = 90,
	[32151] = 90,
	[32152] = 90,
	[32153] = 90,
	[32154] = 90,
	[32155] = 90,
	[32156] = 90,
	[32157] = 90,
	[32158] = 90,
	[32159] = 90,
	[32161] = 90,
	[32162] = 90,
	[32163] = 90,
	[32164] = 90,
	[32165] = 90,
	[32166] = 90,
	[32167] = 90,
	[32168] = 90,
	[32169] = 90,
	[32170] = 90,
	[32171] = 90,
	[32172] = 90,
	[32181] = 90,
	[32182] = 90,
	[32183] = 90,
	[32184] = 90,
	[32185] = 90,
	[32186] = 90,
	[32189] = 90,
	[32190] = 90,
	[32191] = 90,
	[32192] = 90,
	[32193] = 90,
	[32194] = 90,
	[32197] = 90,
	[32198] = 90,
	[32199] = 90,
	[32200] = 90,
	[32201] = 90,
	[32204] = 90,
	[32205] = 90,
	[32206] = 90,
	[32207] = 90,
	[32208] = 90,
	[32209] = 90,
	[32212] = 90,
	[32213] = 90,
	[32214] = 90,
	[32215] = 90,
	[32216] = 90,
	[32217] = 90,
	[32218] = 90,
	[32219] = 90,
	[32220] = 90,
	[32221] = 90,
	[32222] = 90,
	[32223] = 90,
	[32224] = 90,
	[32225] = 90,
	[32226] = 90,
	[32227] = 90,
	[32228] = 90,
	[32230] = 90,
	[32232] = 90,
	[32233] = 90,
	[32234] = 90,
	[32235] = 90,
	[32236] = 90,
	[32237] = 90,
	[32238] = 90,
	[32242] = 90,
	[32243] = 90,
	[32244] = 90,
	[32246] = 90,
	[32247] = 90,
	[32248] = 90,
	[32249] = 90,
	[32250] = 90,
	[32251] = 90,
	[32252] = 90,
	[32254] = 90,
	[32255] = 90,
	[32256] = 90,
	[32257] = 90,
	[32258] = 90,
	[32259] = 90,
	[32260] = 90,
	[32261] = 90,
	[32262] = 90,
	[32264] = 90,
	[32265] = 90,
	[32266] = 90,
	[32268] = 90,
	[32269] = 90,
	[32274] = 90,
	[32275] = 90,
	[32276] = 90,
	[32277] = 90,
	[32278] = 90,
	[32279] = 90,
	[32282] = 90,
	[32283] = 90,
	[32284] = 90,
	[32285] = 90,
	[32287] = 90,
	[32288] = 90,
	[32292] = 90,
	[32293] = 90,
	[32294] = 90,
	[32295] = 90,
	[32296] = 90,
	[32297] = 90,
	[32298] = 90,
	[32299] = 90,
	[32300] = 90,
	[32301] = 90,
	[32302] = 90,
	[32303] = 90,
	[32304] = 90,
	[32305] = 90,
	[32307] = 90,
	[32309] = 90,
	[32310] = 90,
	[32311] = 90,
	[32312] = 90,
	[32313] = 90,
	[32314] = 90,
	[32315] = 90,
	[32316] = 90,
	[32317] = 90,
	[32318] = 90,
	[32319] = 90,
	[32320] = 90,
	[32321] = 90,
	[32324] = 90,
	[32325] = 90,
	[32326] = 90,
	[32327] = 90,
	[32328] = 90,
	[32329] = 90,
	[32330] = 90,
	[32331] = 90,
	[32332] = 90,
	[32333] = 90,
	[32334] = 90,
	[32335] = 90,
	[32336] = 90,
	[32337] = 90,
	[32338] = 90,
	[32339] = 90,
	[32340] = 90,
	[32342] = 90,
	[32343] = 90,
	[32344] = 90,
	[32345] = 90,
	[32346] = 90,
	[32347] = 90,
	[32348] = 90,
	[32351] = 90,
	[32352] = 90,
	[32355] = 90,
	[32358] = 90,
	[32362] = 90,
	[32363] = 90,
	[32368] = 90,
	[32370] = 90,
	[32371] = 90,
	[32372] = 90,
	[32373] = 90,
	[32374] = 90,
	[32375] = 90,
	[32376] = 90,
	[32377] = 90,
	[32378] = 90,
	[32379] = 90,
	[32380] = 90,
	[32381] = 90,
	[32382] = 90,
	[32383] = 90,
	[32384] = 90,
	[32388] = 90,
	[32389] = 90,
	[32390] = 90,
	[32391] = 90,
	[32392] = 90,
	[32393] = 90,
	[32394] = 90,
	[32397] = 90,
	[32398] = 90,
	[32399] = 90,
	[32400] = 90,
	[32401] = 90,
	[32402] = 90,
	[32403] = 90,
	[32404] = 90,
	[32405] = 90,
	[32406] = 90,
	[32408] = 90,
	[32409] = 90,
	[32410] = 90,
	[32411] = 90,
	[32412] = 90,
	[32413] = 90,
	[32414] = 90,
	[32416] = 90,
	[32417] = 90,
	[32418] = 90,
	[32419] = 90,
	[32420] = 90,
	[32421] = 90,
	[32423] = 90,
	[32426] = 90,
	[32427] = 90,
	[32429] = 90,
	[32430] = 90,
	[32431] = 90,
	[32432] = 90,
	[32433] = 90,
	[32444] = 1,
	[32446] = 90,
	[32448] = 90,
	[32449] = 90,
	[32450] = 90,
	[32451] = 90,
	[32452] = 90,
	[32455] = 90,
	[32457] = 90,
	[32460] = 90,
	[32467] = 90,
	[32468] = 90,
	[32469] = 90,
	[32470] = 90,
	[32471] = 90,
	[32472] = 90,
	[32474] = 90,
	[32476] = 90,
	[32485] = 90,
	[32489] = 90,
	[32491] = 90,
	[32492] = 90,
	[32493] = 90,
	[32494] = 90,
	[32495] = 90,
	[32505] = 90,
	[32506] = 90,
	[32507] = 90,
	[32517] = 90,
	[32518] = 90,
	[32519] = 90,
	[32520] = 90,
	[32521] = 90,
	[32522] = 90,
	[32523] = 90,
	[32524] = 90,
	[32525] = 90,
	[32526] = 90,
	[32527] = 90,
	[32528] = 90,
	[32529] = 90,
	[32530] = 90,
	[32531] = 90,
	[32532] = 90,
	[32533] = 90,
	[32535] = 90,
	[32536] = 90,
	[32537] = 90,
	[32538] = 90,
	[32539] = 90,
	[32540] = 90,
	[32541] = 90,
	[32542] = 90,
	[32543] = 90,
	[32544] = 90,
	[32545] = 90,
	[32546] = 90,
	[32547] = 90,
	[32548] = 90,
	[32549] = 90,
	[32550] = 90,
	[32551] = 90,
	[32552] = 90,
	[32553] = 90,
	[32554] = 90,
	[32555] = 90,
	[32556] = 90,
	[32557] = 90,
	[32558] = 90,
	[32559] = 90,
	[32560] = 90,
	[32561] = 90,
	[32562] = 90,
	[32563] = 90,
	[32564] = 90,
	[32565] = 90,
	[32567] = 90,
	[32568] = 90,
	[32570] = 90,
	[32571] = 90,
	[32572] = 90,
	[32573] = 90,
	[32574] = 90,
	[32575] = 90,
	[32576] = 90,
	[32577] = 90,
	[32578] = 90,
	[32579] = 90,
	[32580] = 90,
	[32581] = 90,
	[32582] = 90,
	[32583] = 90,
	[32584] = 90,
	[32585] = 90,
	[32586] = 90,
	[32587] = 90,
	[32588] = 90,
	[32589] = 90,
	[32590] = 90,
	[32591] = 90,
	[32592] = 90,
	[32593] = 90,
	[32594] = 90,
	[32595] = 90,
	[32596] = 90,
	[32597] = 90,
	[32598] = 90,
	[32599] = 90,
	[32600] = 90,
	[32601] = 90,
	[32602] = 90,
	[32605] = 90,
	[32606] = 90,
	[32607] = 90,
	[32608] = 90,
	[32609] = 90,
	[32610] = 90,
	[32611] = 90,
	[32613] = 90,
	[32614] = 90,
	[32615] = 90,
	[32616] = 90,
	[32617] = 90,
	[32621] = 90,
	[32622] = 90,
	[32626] = 90,
	[32627] = 90,
	[32628] = 90,
	[32629] = 90,
	[32631] = 90,
	[32632] = 90,
	[32633] = 90,
	[32634] = 90,
	[32635] = 90,
	[32636] = 90,
	[32637] = 90,
	[32638] = 90,
	[32639] = 90,
	[32640] = 90,
	[32641] = 90,
	[32642] = 90,
	[32643] = 90,
	[32644] = 90,
	[32645] = 90,
	[32646] = 90,
	[32647] = 90,
	[32648] = 90,
	[32649] = 90,
	[32650] = 90,
	[32652] = 90,
	[32653] = 90,
	[32654] = 90,
	[32655] = 90,
	[32656] = 90,
	[32657] = 90,
	[32658] = 90,
	[32659] = 90,
	[32666] = 1,
	[32676] = 90,
	[32677] = 90,
	[32678] = 90,
	[32679] = 90,
	[32680] = 90,
	[32681] = 90,
	[32682] = 90,
	[32683] = 85,
	[32684] = 90,
	[32685] = 90,
	[32686] = 90,
	[32687] = 90,
	[32688] = 90,
	[32689] = 90,
	[32690] = 90,
	[32691] = 90,
	[32692] = 90,
	[32693] = 90,
	[32694] = 90,
	[32695] = 90,
	[32697] = 90,
	[32698] = 90,
	[32700] = 90,
	[32701] = 90,
	[32703] = 90,
	[32704] = 90,
	[32706] = 90,
	[32707] = 90,
	[32708] = 90,
	[32709] = 90,
	[32710] = 93,
	[32711] = 93,
	[32712] = 93,
	[32713] = 93,
	[32714] = 93,
	[32715] = 93,
	[32716] = 93,
	[32720] = 90,
	[32721] = 90,
	[32722] = 90,
	[32724] = 90,
	[32725] = 1,
	[32726] = 85,
	[32727] = 90,
	[32728] = 90,
	[32729] = 90,
	[32730] = 90,
	[32731] = 90,
	[32732] = 90,
	[32733] = 90,
	[32744] = 90,
	[32745] = 90,
	[32746] = 90,
	[32747] = 90,
	[32748] = 90,
	[32749] = 90,
	[32750] = 90,
	[32751] = 90,
	[32752] = 90,
	[32753] = 90,
	[32754] = 90,
	[32755] = 90,
	[32756] = 90,
	[32758] = 90,
	[32805] = 90,
	[32806] = 90,
	[32807] = 90,
	[32816] = 90,
	[32836] = 90,
	[32837] = 90,
	[32838] = 90,
	[32839] = 90,
	[32840] = 90,
	[32841] = 90,
	[32842] = 90,
	[32843] = 90,
	[32844] = 90,
	[32845] = 90,
	[32846] = 90,
	[32847] = 90,
	[32848] = 90,
	[32849] = 90,
	[32850] = 90,
	[32851] = 90,
	[32852] = 90,
	[32853] = 90,
	[32854] = 90,
	[32855] = 90,
	[32856] = 90,
	[32857] = 90,
	[32858] = 90,
	[32859] = 90,
	[32861] = 90,
	[32870] = 90,
	[32873] = 90,
	[32874] = 90,
	[32890] = 1,
	[32891] = 1,
	[32893] = 90,
	[32894] = 90,
	[32897] = 90,
	[32898] = 90,
	[32899] = 90,
	[32900] = 90,
	[32901] = 90,
	[32919] = 90,
	[32922] = 90,
	[32923] = 90,
	[32924] = 90,
	[32942] = 90,
	[32943] = 90,
	[32944] = 90,
	[32945] = 90,
	[32974] = 90,
	[32975] = 90,
	[32976] = 90,
	[33018] = 90,
	[33020] = 90,
	[33021] = 90,
	[33022] = 90,
	[33024] = 90,
	[33025] = 90,
	[33026] = 90,
	[33027] = 90,
	[33047] = 90,
	[33087] = 90,
	[33088] = 90,
	[33089] = 1,
	[33090] = 1,
	[33091] = 1,
	[33092] = 1,
	[33093] = 1,
	[33094] = 1,
	[33095] = 1,
	[33096] = 1,
	[33097] = 1,
	[33098] = 90,
	[33100] = 90,
	[33104] = 90,
	[33105] = 90,
	[33107] = 90,
	[33109] = 90,
	[33117] = 90,
	[33118] = 90,
	[33133] = 90,
	[33134] = 90,
	[33136] = 90,
	[33138] = 90,
	[33139] = 90,
	[33146] = 90,
	[33147] = 90,
	[33156] = 90,
	[33160] = 90,
	[33161] = 90,
	[33211] = 90,
	[33225] = 90,
	[33226] = 90,
	[33228] = 90,
	[33229] = 90,
	[33230] = 90,
	[33231] = 90,
	[33232] = 90,
	[33233] = 90,
	[33234] = 90,
	[33235] = 90,
	[33236] = 90,
	[33238] = 90,
	[33239] = 90,
	[33248] = 90,
	[33249] = 90,
	[33250] = 90,
	[33332] = 90,
	[33333] = 90,
	[33334] = 90,
	[33335] = 90,
	[33336] = 90,
	[33337] = 90,
	[33338] = 90,
	[33340] = 90,
	[33341] = 90,
	[33342] = 90,
	[33343] = 90,
	[33354] = 90,
	[33358] = 90,
	[33374] = 90,
	[33375] = 90,
	[33376] = 90,
	[33377] = 90,
	[33378] = 90,
	[33379] = 90,
	[33602] = 90,
	[33603] = 90,
}
